<?php
/**
 * install.php
 *
 * script d'installation automatique de l'application IEW (tables MySQL et personnalisation)
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package		IEW
 * @author			Sylvain GODM <sylvain.godme@gmail.com>
 * @version		$LastChangedRevision$, $LastChangedDate$
 * @copyright		2004-2012 Sylvain GODM
 * @link			http://iew.free.fr
 * @license		GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

/**
 * Constante contenant le chemin complet du rpertoire d'installation IEW
 */	
if(!defined('IEW_DIR')) define('IEW_DIR',realpath(dirname(__FILE__)."/../").'/');
/**
 * On inclut la librairie contenant toutes les fonctions
 */	
require_once(IEW_DIR."librairie_fonctions.php");

// + des fonctions locales

function return_bytes ($size_str)
{
 /**
 * Permet de rcuprer la taille en octets quivalente  la chane retourne par ini_get()
 */
	
	switch (substr ($size_str, -1))
    {
        case 'M': case 'm': return (int)$size_str * 1048576;
        case 'K': case 'k': return (int)$size_str * 1024;
        case 'G': case 'g': return (int)$size_str * 1073741824;
        default: return $size_str;
    }
}

function verif_prerequis_php()
{
	/**
	 * Teste si les extensions PHP ncessaires sont disponibles
	 * Modifie l'affichage du rapport en consquence
	 */
	
	global $code_formulaire, $erreur_install;
	$tab_extensions = array("session","mysql","gd","ldap","mcrypt","imap","curl");
	$code_formulaire .="
    <h3>Vrification des extensions PHP ncessaires  IEW</h3>";
	$extensions = get_loaded_extensions(); // On rcupre toutes les extensions disponibles
	foreach ($tab_extensions as $value)
	{
		$code_formulaire .="
    	<p>Support de <i><strong>".$value."</strong></i> : ";
   
    	if (in_array($value,$extensions))
      	$code_formulaire .= "<span class='ok'>OK</span></p>";
    	else
    	{
      		$code_formulaire .= "<span class='wrong'>Non disponible</p>";
      		$erreur_install = 1; // extension indispensable
    	} 
	}
	return $erreur_install;
		
}

function imports_bcn($fichier, $table, $colonnes)
{
	/*
	 * importe des donnes en provenance de la BCN (Base Centrale des Nomenclature du Ministre de l'Education Nationale
	 *  partir de fichiers csv inclus dans le tarball IEW
	 * Les tables IEW correspondantes sont alimentes lors de l'installation
	 * 
	 * $fichier : contient le nom du fichier csv  importer
	 * $colonnes : tableau contenant le nom des colonnes de la table mysql  remplir
	 * $table : nom de la table mysql concerne
	 */
	
	if (file_exists(IEW_DIR."mysql/".$fichier))
	{
		$handle_file = fopen(IEW_DIR."mysql/".$fichier,"r");  //ouverture du fichier de donnes en lecture seule
	    if (!$handle_file)
	    {
      		$error_message = array("Impossible d'ouvrir le fichier $fichier ! Abandon de l'installation","");
      		affiche_erreurs($error_message);
      		exit;
    	}
    	// Lecture du fichier, extraction et formatage des donnes utiles vers la table correspondante
     	$buffer = fgets($handle_file, 1000); // la premire ligne est abandonne (contient le nom des champs) 
     	while (($buffer = fgets($handle_file, 1000)) !== FALSE)
     	{
     		// DEBUGG print $buffer."<br />";
     		$tableau = explode(";",$buffer);
     		if (isset($tableau[0]) && $tableau[0] != "") // vite une erreur E_NOTICE si on rencontre une ligne vide dans le csv
        	{
        		$i = 0;
        		$sql_values = "";
        		foreach ($colonnes as $value)
        		{
        			$$value = quote_smart(trim($tableau[$i]));
        			// DEBUGG print "$".$value." = ".$$value."<br />";
        			$sql_values .= "'".$$value."',";
        			// DEBUGG print $sql_values."<br />";
        			$i++;
        		}
        		// on retire la virgule terminale
        		$sql_values = rtrim($sql_values,",");
        		$sql = "INSERT INTO $table VALUES(".$sql_values.")";
            	if (!mysql_query($sql))
            	{
	              // DEBUGG print "La Commande SQL suivante a chou :<br />$sql<br />".mysql_errno(). ": " . mysql_error(). "<br />";
            	}
            	else 
            	{
            		// DEBUGG print $sql;
            	}
            	// DEBUGG print "<hr/>";
        	}
     	}
	}
	else
	{
		$error_message = array("Le fichier $fichier est absent. Certaines informations ne peuvent pas tre crites dans la base de donnes. Abandon de l'installation.","");
      	affiche_erreurs($error_message);
      	exit;
	}
}

$chemin_relatif = "../";


//**************************** Dbut de l'installation : Affichage de la licence et des conditions d'utilisation de l'application IntraEduWeb **********************************/
  // Si la licence n'a pas encore t accepte ou refuse
  if (!isset($_SESSION['accept_licence']))
  {
    $protocole = get_protocol_http($_SERVER['SCRIPT_URI']);
 /* echo "Protocole (serveur) :".$protocole."<br />Hte :".$_SERVER['HTTP_HOST']."<br />Racine IEW : ".IEW_DIR."<br />Referer :".$_SERVER['HTTP_REFERER']."<br />$"."_POST['licence_install'] : ".$_POST['licence_install']."
 <br />$"."_POST['accept_licence_value'] : ".$_POST['accept_licence_value']."<br />Chemin web vers licence :".$protocole.$_SERVER['HTTP_HOST'].$GLOBALS['racine']."copyright-fr.php"."<br />";exit;*/
    // Si la licence a t lue et soumise  l'acceptation ou au refus
    if (isset($_SERVER['HTTP_REFERER']) && strpos($_SERVER['HTTP_REFERER'],"copyright-fr.php") !== false && isset($_POST['licence_install'])) 
    {
      if ($_POST['accept_licence_value'] == "oui") // Si licence accepte
        $_SESSION['accept_licence'] = "oui"; // On enregistre a dans une variable de session
      else // si c'est refus, on arrte tout
      {
        $error_message = array("Vous avez <u><b>refus</b></u> les conditions d'utilisation de l'application IntraEduWeb. En consquence, cette application ne sera pas installe. L'installation est pour le moment abandonne. Si vous changez d'avis, vous pouvez <a href='".$GLOBALS['racine']."'>relire les conditions de licence</a> maintenant.","");
        debut_code_html("popup");
        affiche_erreurs($error_message);
        fin_code_html();
        exit;
      }
    }
    else // La licence n'a pas encore t affiche
    {
      header("Location:../copyright-fr.php");
    }
  }
    
debut_code_html("popup");

// Javascript doit tre activ ! Ceci fait partie du code source de la page mais ne sera affich que si le javascript est dsactiv dans le navigateur
echo "<noscript>";
$error_message=array("","");
affiche_erreurs($error_message);
$code_formulaire = "<br />Votre navigateur a dsactiv l'xcution de code JavaScript. <b>Vous ne pouvez pas</b> installer IntraEduWeb tant que vous ne paramtrerez pas votre navigateur pour que le JavaScript soit activ. Veuillez autoriser cette excution et puis <a href=''>rechargez</a> cette page.<br /><br />";
echo "<br /><center>";
squelette_formulaire_standard("75%","","install.php","<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"","","","","","","");
echo "</center><br /><br /><br /><br /><br /><br /><br /><br /><br /><br /><br /><br /><br /></noscript>";

// On teste si l'installation est dj faite
if (verif_install())
{
  if (!isset($_GET['overwrite']))
  {
    $error_message = array("<br /><p>IntraEduWeb est dj install ! Retournez  l'<a href='$chemin_relatif"."index.php'>accueil</a></p><br />
    <div align='justify'>Si vous voulez <strong>ECRASER</strong> l'installation existante et en faire une nouvelle, soyez conscient que vos donnes actuelles seront <strong>IRREMEDIABLEMENT PERDUES</strong>.<br />
    Vous pouvez souhaiter recommencer l'installation IntraEduWeb pour diverses raisons :<br />
    - la premire installation n'a pas t mene  terme (bug)<br />
    - vous tes dveloppeur et/ou bta-testeur et vous souhaiter tester le fonctionnement du script d'installation, ou tester la restauration d'une sauvegarde<br />
    - vous souhaitez repartir avec une application neuve pour une autre raison<br /></div>
    <br />
    <table border='0' width='100%'>
      <tr>
        <td width='50%' align='left'>
          <a href='".$_SERVER['PHP_SELF']."?soumettre=non_vide&etape=3&overwrite=oui'>[ECRASER l'installation existante (je perdrai TOUTES mes donnes)]</a>
        </td>
        <td width='50%' align='right'>
          <a href='$chemin_relatif"."index.php'>[Je prfre retourner  l'accueil du site actuel]</a>
        </td>
      </tr>
    </table>
    ","");
    affiche_erreurs($error_message);
    fin_code_html();
  exit;
  }
  else // L'utilisateur demande d'craser l'installation existante (overwrite=oui dans le message d'erreur prcdent)
  {
    // On efface l'indicateur (date d'installation) d'une installation existante
  $sql = "DELETE FROM installation";
  mysql_query($sql);
  $error_message = array("L'indicateur de la prsence d'une installation existante vient d'tre effac.<br />
  <a href='".$_SERVER['PHP_SELF']."?soumettre=non_vide&etape=3&overwrite=oui'>[Poursuivre la procdure d'installation]</a>","");
  affiche_erreurs($error_message);
  exit;
  }
}
else // L'installation n'est pas encore faite, alors on la fait !
{
    $erreur_install = 0; // a priori pas d'erreur (utilis rellement seulement pour l'tape prliminaire
  if (isset($_GET['soumettre'])) // si l'appel est fait avec une valeur pour la variable $soumettre dans l'URL
  { // Par exemple si l'utilisateur saute l'tape 4 (configuration mail) 
     //Alors pour viter une erreur NOTICE Undefined index, on initialise :
    $_POST['etape'] = ""; // Parce que normalement a passe par formulaire POST
    if (isset($_GET['overwrite']) && $_GET['overwrite'] == "oui") // s'il s'agit d'une installation crasant l'existant
      $_POST['etape'] = "3"; // On passe directement  l'tape 3
  }
  if (!isset($_POST['soumettre']) && !isset($_GET['soumettre'])) // Pas encore de formulaire envoy
  { // si tape 4 saute en nvoyant un formulaire vide alors $soumettre est passe par la mthode GET
    if (!isset($_SESSION['liste_variables'])) // si pas dfini (c'est le cas au premier chargement du script -1re tape-), on initialise
    { // cela permet d'viter les messages d'erreur NOTICE Undefined variable
      $_SESSION['liste_variables'] = array();
      // On initialise aussi les index de ce tableau (evite un NOTICE Undefined index)
      $_SESSION['liste_variables']['new_mysql_server'] = "";
      $_SESSION['liste_variables']['new_mysql_admin'] = "";
      $_SESSION['liste_variables']['new_mysql_admin_passwd'] = "";
      $_SESSION['liste_variables']['new_mysql_database'] = "";
    }
    //******************** Etape prliminaire : Vrification des pr-requis *******/
    $code_formulaire = "<br />
    <div class='titre_cadre_formulaire'><h2>Etape prliminaire : Vrification des pr-requis</h2></div>
    <div class='cadre_formulaire'>";
    // On vrifie les versions
    $webserver_version = "";
    $mysql_version = "";
    $code_formulaire .= affiche_version_environnement();
    
    // Les extensions PHP ncessaires
    verif_prerequis_php();
    
    // Les options de configuration PHP ncessaires
    $code_formulaire .= "
    <h3>Vrification des Pr-requis pour la configuration PHP</h3>";
    $code_formulaire .= "<p>file_uploads : ";
    $file_uploads = (bool) ini_get('file_uploads');
    if ($file_uploads) // doit tre On
      $code_formulaire .= "<span class='ok'>OK</span></p>";
    else
    {
      $code_formulaire .= "<span class='wrong'>Upload de fichier impossible ! (devrait tre  On)</span></p>";
      $erreur_install = 1; // option indispensable
    }
    $code_formulaire .= "<p>upload_max_filesize : ";
    if (return_bytes(ini_get("upload_max_filesize")) >= 2097152) // doit tre au moins 2 Mgas
      $code_formulaire .= "<span class='ok'>OK</span></p>";
    else
      $code_formulaire .= "<span class='wrong'>Taille maximale de fichier uploadable incorrecte ! (devrat tre 2M)</span></p>";
    // Les commandes systmes ncessaires au bon fonctionnement de l'application
    $code_formulaire .= "<h3>Vrification des excutables ncessaires</h3>";
    
    $exec_dir = "";
    $redirection = " >/dev/null"; // vitera un message  l'cran
    $code_formulaire .= "<p>
    <strong><i>gzip</i></strong> : ";
    $cmd = "gzip --version >/dev/null";
    // on xcute la commande
    // suivant le rsultat, on affiche un message
    exec($cmd,$output,$retval);
    if (isset($retval) && $retval == 0) // commande bien xcute (sur un serveur LINUX)
    {
      $code_formulaire .= "<span class='ok'>OK</span></p>";
    }
    else // Le serveur est peut-tre Windows, ou la commande n'est pas disponible
    {
      $code_formulaire .= "<span class='wrong'>La commande <i>gzip</i> ne peut pas te excute sur ce serveur&nbsp;!</span></p>";
      $erreur_install = 1; // option indispensable
    }
    $code_formulaire .= "<p>
    <strong><i>gunzip</i></strong> : ";
    $cmd = "gunzip --version >/dev/null";
    // on xcute la commande
    // suivant le rsultat, on affiche un message
    exec($cmd,$output,$retval);
    if (isset($retval) && $retval == 0) // commande bien xcute (sur un serveur LINUX)
    {
      $code_formulaire .= "<span class='ok'>OK</span></p>";
    }
    else // Le serveur est peut-tre Windows, ou la commande n'est pas disponible
    {
      $code_formulaire .= "<span class='wrong'>La commande <i>gunzip</i> ne peut pas te excute sur ce serveur&nbsp;!</span></p>";
      $erreur_install = 1; // option indispensable
    }
    $code_formulaire .= "<p>
    <strong><i>tar</i></strong> : ";
    $cmd = "tar --version >/dev/null";
    // on xcute la commande
    // suivant le rsultat, on affiche un message
    exec($cmd,$output,$retval);
    if (isset($retval) && $retval == 0) // commande bien xcute (sur un serveur LINUX)
    {
      $code_formulaire .= "<span class='ok'>OK</span></p>";
    }
    else // Le serveur est peut-tre Windows, ou la commande n'est pas disponible
    {
      $code_formulaire .= "<span class='wrong'>La commande <i>tar</i> ne peut pas te excute sur ce serveur&nbsp;!</span></p>";
      $erreur_install = 1; // option indispensable
    }
    
    $code_formulaire .= "<p>
    <strong><i>mysql</i></strong> : ";
    $cmd = $exec_dir."mysql --version".$redirection;
    // on xcute la commande
    // suivant le rsultat, on affiche un message
    exec($cmd,$output,$retval);
    if (isset($retval) && $retval == 0) // commande bien xcute (sur un serveur LINUX)
    {
      $code_formulaire .= "<span class='ok'>OK</span></p>";
    }
    else // la commande n'est pas disponible
    {
      $code_formulaire .= "<span class='wrong'>La commande <i>mysql</i> ne peut pas tre excute sur ce serveur&nbsp;!</span></p>";
      $erreur_install = 1; // option indispensable
    }
    $code_formulaire .= "<p>
    <strong><i>mysqldump</i></strong> : ";
    $cmd = $exec_dir."mysqldump --version".$redirection;
    // on xcute la commande
    // suivant le rsultat, on affiche un message
    exec($cmd,$output,$retval);
    if (isset($retval) && $retval == 0) // commande bien xcute (sur un serveur LINUX)
    {
      $code_formulaire .= "<span class='ok'>OK</span></p>";
    }
    else // la commande n'est pas disponible
    {
      $code_formulaire .= "<span class='wrong'>La commande <i>mysqldump</i> ne peut pas tre excute sur ce serveur&nbsp;!</span></p>";
      $erreur_install = 1; // option indispensable
    }
    $code_formulaire .= "<br /></div><br />";
    // Fin de vrification des pr-requis
    $code_formulaire .= "<input type='hidden' name='etape' value='1' />";
    if ($erreur_install != 0) // Pr-requis d'installation non satisfaits
    {
      $error_message = array("L'installation est interrompue car les pr-requis ne sont pas satisfaits. Veuillez consulter les dtails dans le rapport ci-dessous, et recharger la page aprs avoir satisfait le (ou les) pr-requis manquant(s)&nbsp;:<br />","");
      affiche_erreurs($error_message);
      $value_submit_button = ""; // Pas de bouton "Suivant" dans le formulaire
      $name_submit_button = "";
    }
    else // Les pr-requis sont satisfaits, on peut passer  l'tape suivante
    {
      $value_submit_button = "Suivant >>"; // Pas de bouton "Suivant" dans le formulaire
      $name_submit_button = "soumettre";
    }
    echo "<br /><center>";
    squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,$value_submit_button,$name_submit_button,"","","","","");  
    echo "</center>";
  }
  elseif ($_POST['etape'] == 1 || (isset($_GET['etape']) && $_GET['etape'] == 1))
  {
    //************************* Etape 1 : Configuration de la connexion MySQL *****************************/
    $code_formulaire = "<br />
    <div class='titre_cadre_formulaire'><h2>Etape 1 : Configuration de la connexion MySQL</h2></div>
    <div class='cadre_formulaire'>
     <br />
     <fieldset class='form_config'>
     	<legend>Serveur MySQL</legend>
     		<table border='0'>
       			<tr>
		         <td align='right'>
        		 	<label for='Form_Req_MySQL_Server_Name' accesskey='N'>Nom du serveur MySQL</label>
         		 </td>
         		 <td>
           			<input type='text' id='Form_Req_MySQL_Server_Name' name='new_mysql_server' tabindex='1' value='";
           			if ($_SESSION['liste_variables']["new_mysql_server"]!=="")
           			{
             			$code_formulaire .= $_SESSION['liste_variables']['new_mysql_server'];
           			}
           			else
           			{
             			$code_formulaire .= "localhost";
           			}
           			$code_formulaire .= "' />
         		 </td>
       			</tr>
       			<tr>
         			<td align='right'>
						<label for='Form_Req_MySQL_User_Name' accesskey='O'>Nom de login MySQL</label>
         			</td>
         			<td>
           				<input type='text' id='Form_Req_MySQL_User_Name' name='new_mysql_admin' tabindex='2' value='".$_SESSION['liste_variables']['new_mysql_admin']."' />
         			</td>
       			</tr>
       			<tr>
         			<td align='right'>
	           			<label for='Form_Req_MySQL_User_Passwd' accesskey='M'>Mot de passe</label>	
         			</td>
        	 		<td>
           				<input type='password' id='Form_Req_MySQL_User_Passwd' name='new_mysql_admin_passwd' tabindex='3' value='".$_SESSION['liste_variables']['new_mysql_admin_passwd']."' />
         			</td>
       			</tr>
		        <tr>
         			<td align='right'>
           				<label for='Form_Req_MySQL_Database_Name' accesskey='B'>Nom de la base de donnes :</label>
         			</td>
         			<td>
           				<input type='text' id='Form_Req_MySQL_Database_Name' name='new_mysql_database' tabindex='4' value='";
           				if ($_SESSION['liste_variables']['new_mysql_database']!=="")
           				{
             				$code_formulaire .= $_SESSION['liste_variables']['new_mysql_database'];
           				}
           				else
           				{
             				$code_formulaire .= ""; // par dfaut le champ du nom de la bdd est vide
           				}
           				$code_formulaire .= "' />
         			</td>
       			</tr>
     		</table>
     	</fieldset>
      	<br /></div><br />";
    	$code_formulaire .= "<input type='hidden' name='etape' value='2' />";
    	echo "<br /><center>";
    	squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF']."' name='mysql_config_form","<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");  
    	echo "</center>";
    echo "<script type='text/javascript'><!-- document.mysql_config_form.new_mysql_server.focus(); //--></script>";
  }
  elseif ($_POST['etape'] == 2)
  {
    $_SESSION['liste_variables'] = $_POST;
    //print_r($_SESSION['liste_variables']);
    //************************* Etape 2 : Vrification de la connexion MySQL *****************************/
    $code_formulaire = "<br />
    <div class='titre_cadre_formulaire'><h2>Etape 2 : Vrification de la connexion MySQL</h2></div>
    <div class='cadre_formulaire'>";
   $bd =@mysql_connect($_POST['new_mysql_server'],$_POST['new_mysql_admin'],$_POST['new_mysql_admin_passwd']);
   if (!$bd)
   {
     $error_message = array("Connexion au serveur de base de donnes <b>\"".$_POST['new_mysql_server']."\"</b> impossible. Ressayez ultrieurement ou <a href='".$_SERVER['PHP_SELF']."?soumettre=non_vide&etape=1'>Recommencez la configuration MySQL</a>.","");
     affiche_erreurs($error_message);
     exit;
   }
   $seldb=mysql_select_db($_POST['new_mysql_database']);
   if (!$seldb)
   {
     $error_message = array("La base de donnes <b>\"".$_POST['new_mysql_database']."\"</b> n'existe pas ou est inaccessible pour le moment. Veuillez ressayer ultrieurement ou <a href='".$_SERVER['PHP_SELF']."?soumettre=non_vide&etape=1'>Recommencez la configuration MySQL</a>.","");
     affiche_erreurs($error_message);
     exit;
   }
   // Si on arrive l, c'est que tout c'est bien pass
   $code_formulaire .= "<p><span class='ok'>La connexion au serveur MySQL a russi !</span></p><p>Vous pouvez passer  l'tape suivante.</p></div><br />";
   $code_formulaire .= "<input type='hidden' name='etape' value='3' />";
   echo "<br /><center>";
   squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
   echo "</center>";
  }
  elseif ($_POST['etape'] == 3)
  {
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    //print_r($_SESSION['liste_variables']);
    //************************* Etape 3 : Installation de la base de donnes *****************************/
    if (isset($_GET['overwrite']) && $_GET['overwrite']=="oui")
    {
      // On supprime toutes les donnes stockes dans des fichiers
     //echo "on supprime toutes les donnes dans ".$GLOBALS['stock_baselev']."<br />";
     // les deux dossiers suivants seront recrs  l'install
     rdel($GLOBALS['stock_baselev']."backup");
     rdel($GLOBALS['stock_baselev']."cahiers_textes");
     // Les autres dossiers doivent rester, mais dbarrasss des fichiers de donnes de l'installation prcdente
     delfile ($GLOBALS['stock_baselev'],$except=array(".htaccess","inc_connect.php")); // dossier de stockage principal dans l'installation prcdente
     delfile (IEW_DIR."data/",$except=array(".htaccess","inc_connect.php")); // Dossier de stockage principal par dfaut pour une nouvelle installation
     delfile($GLOBALS['stock_baselev']."fotoelev",$except=array("defaut.jpg","opposition_perso.jpg","blanc.jpg","base_foto.xcf"));
     delfile($GLOBALS['stock_baselev']."fotoprof",$except=array("defaut.jpg","opposition_perso.jpg","opposition_parentale.jpg","blanc.jpg","base_foto.xcf"));
     // On remet les fichiers ncessaires pour la nouvelle installation ou la post-installation
     copy(IEW_DIR."install/config_origine.php",IEW_DIR."data/config.php"); // celui-ci doit tre  la racine de l'arborescence web
     // fichier sql  excuter
     $sql_filename = "intraeduweb_overwrite.sql"; // il s'agit d'une rinstallation par dessus des tables existantes
    }
    else
      $sql_filename = "intraeduweb.sql"; // installation frache
    $fichier_creation_base = @fopen(IEW_DIR."mysql/$sql_filename","r");
    if (!$fichier_creation_base)
    {
      $error_message = array("Le fichier contenant les commandes d'installation de la base de donnes est introuvable ou ne peut tre ouvert. Vrifiez que le fichier ".IEW_DIR."mysql/$sql_filename existe bien sur le serveur IntraEduWeb avant de recharger cette page.","");
      affiche_erreurs($error_message);
      exit;
    }
    if (@mysql_connect($_SESSION['liste_variables']['new_mysql_server'],$_SESSION['liste_variables']['new_mysql_admin'],$_SESSION['liste_variables']['new_mysql_admin_passwd']) && @mysql_select_db($_SESSION['liste_variables']['new_mysql_database']))
    {
      $sql_brut = file_get_contents(IEW_DIR."mysql/$sql_filename");
      $sql_element = explode(";",$sql_brut);
      foreach ($sql_element as $sql)
      {
        $sql = stripslashes($sql); // au cas o file_get_contents ait addslash
        if (!mysql_query(trim($sql)) && trim($sql) != "" && !strstr(trim($sql),"/********"))
        {
          $error_message = array("La commande <b>$sql</b> contenue dans le fichier d'installation de la base de donnes n'a pas pu tre xcute avec succs. Abandon de l'installation","");
          affiche_erreurs($error_message);
          exit;
        }
      }
      $code_formulaire = "<br />
      <div class='titre_cadre_formulaire'><h2>Etape 3 : Installation de la base de donnes</h2></div>
      <div class='cadre_formulaire'>";
      $code_formulaire .= "<p><span class='ok'>La base de donne est installe et oprationnelle.</span></p><p>Vous pouvez passer  l'tape suivante.</p></div><br />";
      $code_formulaire .= "<input type='hidden' name='etape' value='4' />";
      echo "<br /><center>";
      squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
      echo "</center>";
    }
    else
    {
      $error_message = array("La connexion  la base de donnes est impossible. Abandon de l'installation.","");
      affiche_erreurs($error_message);
      exit;
    }
     
    /*On importe ici des donnes venant de fichiers externes
     C'est le cas des donnes de la table disciplines qui viennent d'un export de la BCN sous forme de fichier txt intgr au tarball IEW
	 Ce fichier est n_discipline_poste_.csv*/
	$fichier = "n_discipline_poste_.csv";
	$table = "disciplines_bcn";
	$colonnes = array("id_discipline","libelle_court", "libelle_long", "libelle_edition");
    imports_bcn($fichier, $table, $colonnes);
    
	/* C'est le cas aussi des donnes de la table corps_professeurs qui viennent d'un export de la BCN sous forme de fichier txt intgr au tarball IEW
	 Ce fichier est n_corps_profs_.csv */
    $fichier = "n_corps_personnel_.csv";
	$table = "corps_personnel";
	$colonnes = array("id_corps","libelle_court", "libelle_long", "libelle_edition");
    imports_bcn($fichier, $table, $colonnes);
    
    /* C'est le cas aussi des donnes de la table corps_professeurs qui viennent d'un export de la BCN sous forme de fichier txt intgr au tarball IEW
	 Ce fichier est n_grade_profs_.csv */
    $fichier = "n_grade_personnel_.csv";
	$table = "grades_personnel";
	$colonnes = array("id_grade","libelle_court", "libelle_long", "libelle_edition","id_corps");
    imports_bcn($fichier, $table, $colonnes);
    
  }
  elseif ($_POST['etape'] == 4 || (isset($_GET['etape']) && $_GET['etape'] == 4))
  {
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    // On initialise aussi quelques index de ce tableau (evite un NOTICE Undefined index)
    // Seulement si c'est la premire fois qu'on remplit le formulaire : dans le cas contraire, les variables gardent
    // leur valeur du premier POST (si appel etape 4 dans URL par mthode GET, on n'initialise pas)
    if ($_POST['etape'] == 4)
    {
      $_SESSION['liste_variables']['new_mail_server'] = "";
      $_SESSION['liste_variables']['new_url_mail_server'] = "";
      $_SESSION['liste_variables']['mail_port'] = "";
      $_SESSION['liste_variables']['protocol'] = "";
      $_SESSION['liste_variables']['test_login_mail'] = "";
      $_SESSION['liste_variables']['passwd'] = "";
    }
    //print_r($_SESSION['liste_variables']);
    //************************* Etape 4 : Configuration de la messagerie *****************************/
    $code_formulaire = "<br />
    <div class='titre_cadre_formulaire'><h2>Etape 4 : Configuration de la messagerie (facultative)</h2></div>
    <div class='cadre_formulaire'>";
    $code_formulaire .= "
    <br />
    <div align='justify'>Si vous voulez sauter cette tape, il vous suffit d'envoyer un formulaire vide. Vous passerez alors directement  l'tape&nbsp;6.</div>
    <fieldset class='form_config'>
     	<legend>Serveur MAIL</legend>  
    <table border=0>
       <tr>
         <td align='right'>
           <label for='Form_Mail_Server_Name' accesskey='N'>Nom de la machine hte (ex: pop.free.fr, imap.free.fr)</label>
         </td>
         <td>
           <input type='text' id='Form_Mail_Server_Name' name='new_mail_server' tabindex='1' value='".$_SESSION['liste_variables']['new_mail_server']."' />
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Mail_URL_Service' accesskey='U'>URL du service Webmail</label>
         </td>
         <td>
           <input type='text' id='Form_Mail_URL_Service' name='new_url_mail_server' tabindex='2' value='".$_SESSION['liste_variables']['new_url_mail_server']."' />
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Mail_Server_Port' accesskey='P'>Port</label>  
         </td>
         <td>
           <select id='Form_Mail_Server_Port' name='mail_port' size='1' tabindex='3'>
             <option>".$_SESSION['liste_variables']['mail_port']."</option>
             <option></option>
             <option>110</option>
             <option>143</option>
           </select>
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Mail_Server_Protocol' accesskey='R'>Protocole :</label>    
         </td>
         <td>
           <select id='Form_Mail_Server_Protocol' name='protocol' size='1' tabindex='4'>
             <option>".$_SESSION['liste_variables']['protocol']."</option>
             <option></option>
             <option>pop3</option>
             <option>imap</option>
           </select>
         </td>
       </tr>
     </table>
     </fieldset>
     <br />";
    
    	$code_formulaire .= "<fieldset class='form_config'>
    	<legend>Test MAIL</legend> 
     <table border=0>
       <tr>
         <td align='right'>
         	<label for='Form_Mail_User_Login' accesskey='L'>login d'un compte mail</label>     
         </td>
         <td>
           <input type='text' id='Form_Mail_User_Login' name='test_login_mail' tabindex='5' value='".$_SESSION['liste_variables']['test_login_mail']."' />
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Mail_User_Passwd' accesskey='A'>Mot de passe</label>   
         </td>
         <td>
           <input type='password' id='Form_Mail_User_Passwd' name='passwd' tabindex='6' value='".$_SESSION['liste_variables']['passwd']."' />
         </td>
       </tr>
     </table>
     </fieldset>
     <br />";
    
    $code_formulaire .= "</div><br /><input type='hidden' name='etape' value='5' />";
    echo "<br /><center>";
   squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF']."' name='mail_config_form","<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
   echo "</center>";
   echo "<script type='text/javascript'><!-- document.mail_config_form.new_mail_server.focus(); //--></script>";
  }
  elseif ($_POST['etape'] == 5)
  {
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    if (filled_out($_POST)) // Si le formulaire prcdent est bien rempli
    {
      //************************* Etape 5 : Vrification de la connexion au Serveur de Messagerie **********************/
      // On vrifie d'abord les entres de formulaires
      $checkdns_mailserver = checkdnsrr($_POST['new_mail_server'],"A"); // y-a-t-il une ip associe  l'hte ?
      $ipv4 = gethostbyname($_POST['new_mail_server']); // rcup l'ip
      if (!$checkdns_mailserver && $ipv4==$_POST['new_mail_server'])
      { // si vous n'tes pas sous Windows, vous pouvez utiliser directement la condition (!checkdnsrr($dom))
      	$error_message = "le nom d'hte '".$_POST['new_mail_server']."' est introuvable ou n'accepte pas les emails. Il est aussi possible que votre connexion rseau ou internet ne soit pas active; dans ce cas, passez l'tape de la configuration de la messagerie. Vous pourrez y revenir plus tard.";
        echo "<script type='text/javascript'>
              <!--
              alert('La rsolution DNS du nom d\'hte sur serveur mail n\'a pas abouti."."\\"."nVeuillez corriger SVP ! ".addslashes($error_message).".');
              window.location.href='install.php?soumettre=non_vide&etape=4';
              //-->
            </script>";
        exit;
      }
      $err = verif_url_syntax_exist($_POST['new_url_mail_server']);
      if ( $_POST['new_url_mail_server']!="" && $err!="")
      {
        echo "<script type='text/javascript'><!--
              alert('Vous n\'avez pas entr une adresse URL correcte pour le service webmail."."\\"."nVeuillez corriger SVP ! ".addslashes($err).".');
              window.location.href='install.php?soumettre=non_vide&etape=4';
            //--></script>";
        exit;
      }
      
      $passord_mail_test = trim(htmlspecialchars(addslashes($_SESSION['liste_variables']["passwd"])));
      $login_mail_test = trim(htmlspecialchars(addslashes($_SESSION['liste_variables']["test_login_mail"])));
      $code_formulaire = "<br />
      <div class='titre_cadre_formulaire'><h2>Etape 5 : Vrification de la connexion au Serveur de Messagerie</h2></div>
      <div class='cadre_formulaire'>";
      $_SESSION['liste_variables']["new_mail_protocol"] = ":".$_SESSION['liste_variables']["mail_port"]."/".$_SESSION['liste_variables']["protocol"]."/novalidate-cert";
      $nb_messages = verif_connexion_mail($_SESSION['liste_variables']["new_mail_server"],$_SESSION['liste_variables']["new_mail_protocol"],$login_mail_test,$passord_mail_test);
     	if (is_numeric($nb_messages))
      	{
        	$code_formulaire .=  "<p><span class='ok'>La connexion au serveur Mail a russi...</span></p><p>Vous avez <span class='ok'>".$nb_messages;
       		$code_formulaire .=  "</span> messages(s) non lu(s)</p></div><br />";
     	}
     	else // Si le serveur de messagerie n'a pas pu tre contact, la variable $nb_messages contient alors le message d'erreur
     	{
       		$error_message = array("<b>".$nb_messages.
       		"</b><br />Vous pouvez installer IntraEduWeb sans que la messagerie ne soit paramtre. Vous pourrez le faire plus tard si vous voulez utiliser cette fonctionnalit. <a href='".$_SERVER['PHP_SELF']."?soumettre=non_vide&etape=6'>Passez  l'tape suivante</a> ou <a href='".$_SERVER['PHP_SELF']."?soumettre=non_vide&etape=4'>Recommencez la configuration Mail</a>.","");
       		affiche_erreurs($error_message);
       		exit;
     	}	
      
     // on ne va garder que le nom de domaine (ex de pop.free.fr on gardera free.fr)
     // le nom complet d'hte n'tait ncessaire que pour la vrification de la connexion (sur un compte pop par ex)
     // mais pour la constitution future des adresses mail, il nous faut seulement le nom de domaine
     if (!preg_match("/^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])(\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])){3}$/",$_SESSION['liste_variables']["new_mail_server"]))
     {
     	$elements = preg_split("#\.#",$_SESSION['liste_variables']["new_mail_server"]);
     	$keep_elements = array_slice($elements,-2);// On ne garde que les 2 derniers lments qui constituent le nom de domaine mail
     	$mail_domain = "";
     	foreach ($keep_elements as $value) // on va reconsituer le nom de domaine mail
     	{
  			$mail_domain .= $value.".";
     	}
     	$mail_domain = substr($mail_domain,0,strlen($mail_domain)-1); // on retire le . final
     	$_SESSION['liste_variables']["new_mail_server"] = $mail_domain; // on l'enregistre dans la variable de session
     }
     // Si on arrive l, c'est que tout c'est bien pass
     $code_formulaire .= "<input type='hidden' name='etape' value='6' />";
     echo "<br /><center>";
     squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
     echo "</center>";
    }
    else
    {
      // L'tape 4 a t saute en envoyant un formulaire vide ou presque (pas de configuration du serveur de messagerie)
      echo "<script type='text/javascript'><!--
      var reponse = window.confirm('Le formulaire est incomplet. La messagerie ne sera pas configure (mais vous pourrez le faire ultrieurement). Cliquez sur OK pour continuer ou sur Annuler pour retourner au formulaire prcdent.');
      if (reponse)
      {
        window.location.href='install.php?soumettre=non_vide&etape=6';
      }
      else
      {
        window.location.href='install.php?soumettre=non_vide&etape=4';
      }
      //--></script>";
    }
  }
  elseif ($_POST['etape'] == 6 || (isset($_GET['etape']) && $_GET['etape'] == 6)) // $etape ne vient pas d'un POST mais directement de l'URL (si tape 4 saute)
  {
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    //print_r($_SESSION['liste_variables']);
    //************************* Etape 6 : Emplacement du dossier de stockage des donnes-fichiers **********************/
    $code_formulaire = "<br />
    <div class='titre_cadre_formulaire'><h2>Etape 6 : Emplacement du dossier de stockage des donnes-fichiers</h2></div>
    <div class='cadre_formulaire' style='text-align: justify;'>
      <p>IEW stocke une partie de ses donnes dans une base MySQL, mais une autre partie (par exemple, les fichiers joints aux cahiers de textes, les trombinoscopes,...) dans des fichiers. Il faut indiquer ici le chemin d'accs au dossier de stockage de ces donnes.</p><br />
    <h3>1) Si vous souhaitez tester IEW ou l'utiliser uniquement en intranet sans y accder depuis l'extrieur</h3>
    Laissez le rpertoire propos par dfaut (voir au bas du formulaire)<br />(IntraEduWeb est hberge sur une machine de votre rseau interne <strong>non accessible</strong> de l'extrieur)<br /><br />
    <h3>2) Si vous voulez utiliser IEW en extranet (accs depuis l'extrieur)</h3>
    Consultez IMPRATIVEMENT la documentation administrateur de l'application IEW. Il y est notamment conseill de crer un dossier de stockage situ en dehors de l'arborescence web pour des raisons de scurit.
	Vrifiez que le champ du formulaire contient le chemin absolu pour l'accs  ce dossier de stockage.
    <p>
     <font color='red'><b>Dans tous les cas o le serveur web est accessible depuis l'extrieur, il est impratif d'avoir un serveur apache scuris par SSL pour des raisons de scurit.</b></font>
    </p>
     <h3>Rpertoire de stockage :</h3>
     <fieldset class='form_config'>
     	<legend>Indiquez le chemin d'accs au rpertoire de stockage</legend> 
     <table border='0'>
       <tr>
         <td align='right'>
         	<label for='Form_Req_Data_Path' accesskey='C'>Chemin d'accs complet  ce rpertoire</label>
         </td>
         <td>
           <input type='text' id='Form_Req_Data_Path' name='new_stock_baselev' size='40' tabindex='1' value='".IEW_DIR."data/"."' />
         </td>
       </tr>
     </table>
     </fieldset>
      <br /></div><br />";
      $code_formulaire .= "<input type='hidden' name='etape' value='7' />";
     echo "<br /><center>";
     squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF']."' name='special_config_form","<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
     echo "</center>";
      echo "<script type='text/javascript'><!-- document.special_config_form.new_stock_baselev.focus(); //--></script>";
  }
  elseif ($_POST['etape'] == 7)
  {
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    //print_r($_SESSION['liste_variables']);
    //************************* Etape 7 : Vrification des droits d'accs aux fichiers spciaux **********************/
    $code_formulaire = "
    <br />
    <div class='titre_cadre_formulaire'><h2>Etape 7 : Vrification des droits d'accs au dossier de stockage des donnes-fichiers</h2></div>
    <div class='cadre_formulaire'>";
      // le chemin d'accs au dossier de stockage des donnes doit se teminer par un slash
      if (substr($_POST['new_stock_baselev'],-1,1)!="/")
        $_POST['new_stock_baselev'] .="/";
      $stock_baselev = $_POST['new_stock_baselev'];
      $error_message = array(verif_authdir_data($stock_baselev),"");
      if ($error_message[0] != "")
      {
        affiche_erreurs($error_message);
        exit;
      }
      else // si tout est ok, le droit d'criture est positionn
      {
      	if (substr($stock_baselev,-5,5)!="data/") // on vrifie que le nom du dossier fourni se termine par "data/"
   			$stock_baselev = $stock_baselev."data/"; // sinon on le rajoute
   		if (!is_dir($stock_baselev)) // et si le dossier data n'existe pas (possible si le dossier n'est pas elui propos par dfaut et si l'utilisateur n'a pas suvi la doc admin pour la cration de ce dossier de stockage des donnes fichiers) on le cre
   			mkdir($stock_baselev,0755);
   		if ($stock_baselev != IEW_DIR."data/") // Si le dossier de stockage est situ hors arborescence IEW
  		{
      		copyr(IEW_DIR."data/",$stock_baselev); // et on y copie rcursivement le contenu original du dossier data fourni avec l'application IEW
      		chmod_R($stock_baselev,0755);
  		}
      }
      $code_formulaire .= "<p>Les droits d'accs au rpertoire <span class='wrong'>".$_POST['new_stock_baselev']."</span> sont correctement rgls.</p><p>Vous pouvez passer  l'tape suivante.</p>";
    $code_formulaire .= "</div><br />";
    // on retransmet la variable $_POST['new_stock_baselev'] ventuellement modifie (avec un slash final)
    $code_formulaire .= "<input type='hidden' name='new_stock_baselev' value='".$_POST['new_stock_baselev']."' />";
    $code_formulaire .= "<input type='hidden' name='etape' value='8' />";
    echo "<br /><center>";
    squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
    echo "</center>";
  }
  elseif ($_POST['etape'] == 8 || (isset($_GET['etape']) && $_GET['etape'] == 8))
  {
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    //************************* Etape 8 : Choix de la mthode d'authentification **********************/
    $code_formulaire = "
    <br />
    <div class='titre_cadre_formulaire'><h2>Etape 8 : Configuration du systme d'authentification</h2></div>
    <div class='cadre_formulaire' style='text-align: justify;'>
    IEW permet l'identification unique SSO (<strong>S</strong>ingle <strong>S</strong>ign <strong>O</strong>n)  partir d'un serveur CAS. Il est aussi possible d'interroger directement un serveur LDAP (mais on perd la fonctionnalit SSO). Enfin, si vous ne disposez d'aucun systme d'authentification existant, choisissez le mode d'authentification native.<br />Le paramtrage de la mthode d'authentification choisie se fait  l'tape 9 (qui sera saute si vous choisissez l'authentification native).<br /><br />
	
    <input type='radio' id='rbtCas' name='auth_method' value='cas' checked='checked' />
	<label for='rbtCas'><strong>CAS</strong></label><br />
    
	Si vous disposez d'un serveur CAS (<strong>C</strong>entral <strong>A</strong>uthentication <strong>S</strong>ervice), vous pourrez configurer la connexion  ce serveur  l'tape suivante. C'est notamment le cas si vous installez IEW  sur un serveur Scribe<br /><br />
	
	<input type='radio' id='rbtldap' name='auth_method' value='ldap' disabled='disabled' />
	<label for='rbtldap'><strong>LDAP</strong></label><br />
    
	Si vos comptes utilisateurs existent dj dans un annuaire LDAP, vous pourrez configurer la connexion au serveur LDAP  l'tape suivante.<br />
	Ce choix n'a pas encore test en dehors d'un environnement scribe<br /><br />
	
	<input type='radio' id='rbtNative' name='auth_method' value='native' />
	<label for='rbtNative'><strong>Native (locale)</strong></label><br />
    
	IEW est  l'origine une application autonome capable de crer et de grer ses propres comptes utilisateurs (gnration automatique des identifiants et mots de passe, attribution de l'appartenance  un groupe ayant des droits particuliers).
    Si vous ne pouvez pas utiliser ldap, ou si vous souhaitez seulement <u>tester</u> IEW, vous choisirez ce mode d'authentification par dfaut.<br />Dans ce cas, vous serez redirig directement  l'tape 11 de l'installation<br /><br />";
    
    $code_formulaire .= "
    </div>
    <br />";
    $code_formulaire .= "<input type='hidden' name='etape' value='9' />";
    echo "<br /><center>";
    squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
    echo "</center>";
  }
  elseif ($_POST['etape'] == 9 || (isset($_GET['etape']) && $_GET['etape'] == 9))
  {
    // Ici sera pris en charge la configuration du type d'authentification choisie  l'tape prcdente
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    //print_r($_SESSION['liste_variables']);
	
    //************************* Etape 9 : Paramtrage de la mthode d'authentification choisie **********************/
    
    if ($_SESSION['liste_variables']['auth_method'] == "native" || $_SESSION['liste_variables']['auth_method'] == "lemonldap")
  	{
  		// La mthode d'authentification 'native' ne ncessite pas de paramtre => on passe directement  l'tape 11
      echo "<script type='text/javascript'><!--
      var reponse = window.confirm('Vous avez choisi la mthode d\'authentification ".strtoupper($_SESSION['liste_variables']['auth_method']).". En consquence, les tapes 9 et 10 (paramtrage et vrification des paramtres pour l\'authentification) seront sautes. Cliquez sur OK pour continuer (tape 11) ou sur Annuler pour retourner au formulaire prcdent.');
      if (reponse)
      {
        window.location.href='install.php?soumettre=non_vide&etape=11';
      }
      else
      {
        window.location.href='install.php?soumettre=non_vide&etape=8';
      }
      //--></script>";
  	}
  	else
  	{
    	if (isset($_POST['auth_method']))
    		$meth_auth = $_POST['auth_method'];
    	else
    		$meth_auth = $_SESSION['liste_variables']['auth_method'];
  		$code_formulaire = "
    	<br />
    	<div class='titre_cadre_formulaire'><h2>Etape 9 : Paramtrage de la mthode d'authentification choisie</h2></div>
    	<div class='cadre_formulaire'>
		<p>
			Vous avez choisi la mthode d'authentification <strong>".strtoupper($meth_auth)."</strong>. Veuillez renseigner les champs suivants :
    	</p>
		";
	    // 	On vrifie les entres du formulaire du choix de la mthode d'authentification
	    /*** LDAP : A REFAIRE ET A COMPLETER ***/
	    if ($_SESSION['liste_variables']['auth_method'] == "ldap") // si mthode ldap
	    {		
      		// Il faut le nom du serveur LDAP
			if ($_POST['etape'] == 9)
			{
				form_fieldset_config_ldap_default_values();
			}
			$code_formulaire .= form_fieldset_config_ldap();
    	}
    	elseif ($_SESSION['liste_variables']['auth_method'] == "cas")
    	{ 
    		// On initialise aussi quelques index de tableau (evite un NOTICE Undefined index)
		    // 	Lors du premier chargement de cette tape seulement $_POST['etape'] == 9, car si on y revient par exemple en cas de formulaire incomplet $_GET['etape'] == 10, il faut reprendre les valeurs dj postes
	    	if ($_POST['etape'] == 9)
	    	{
    			$_SESSION['liste_variables']['cas_server_name'] = "";
      			$_SESSION['liste_variables']['cas_server_port'] = "8443"; // Valeur par dfaut sur scribe
      			form_fieldset_config_ldap_default_values(); // charge les valeurs par dfaut des champs de formulaire pour la configuration d'accs  l'annuaire LDAP
    		}
    		//DEBUGG print_r($_SESSION['liste_variables']);
    		//DEBUGG echo "<br />";
    		//DEBUGG print_r($_POST);
	    	// Il faut le nom pleinement qualifi ou adresse IP du serveur CAS
    		$code_formulaire .= form_fieldset_config_cas(); // affiche les champs de formulaire  remplir pour la config d'accs au serveur CAS (SSO)
    		// Il faut quand mme le nom du serveur LDAP (pour rcuprer des attributs)
			$code_formulaire .= form_fieldset_config_ldap(); // affiche les champs de formulaire  remplir pour la config d'accs  l'annuaire LDAP
    	}
    	$code_formulaire .= "<br /><br />
    	</div>
    	<br />";
    	$code_formulaire .= "<input type='hidden' name='etape' value='10' />";
    	echo "<br /><center>";
    	squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
    	echo "</center>";
  	}   
  }
  elseif ($_POST['etape'] == 10 || (isset($_GET['etape']) && $_GET['etape'] == 10))
  {
  	$_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
  	
  		if (filled_out($_POST)) // Si le formulaire prcdent est bien rempli
    	{
  			$code_formulaire = "
    		<br />
    		<div class='titre_cadre_formulaire'><h2>Etape 10 : Vrification des paramtres pour l'authentification</h2></div>
    		<div class='cadre_formulaire'>
			";
  			switch($_SESSION['liste_variables']['auth_method'])
  			{
  				case 'ldap':
  					if ($_POST['ldap_server_name'] == "") // nom du serveur LDAP non fourni
      				{
        				echo "<script type='text/javascript'>
              			<!--
              			alert('Vous devez entrer le nom du serveur LDAP  contacter !');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			              //-->
    		        	</script>";
			        	exit;
	      			}
  					if ($_POST['ldap_server_port'] == "") // nom du serveur LDAP non fourni
      				{
        				echo "<script type='text/javascript'>
              			<!--
              			alert('Vous devez entrer le port d'coute du serveur LDAP !');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			              //-->
    		        	</script>";
			        	exit;
	      			}
  					if ($_POST['ldap_base_dn'] == "") // nom du serveur LDAP non fourni
      				{
        				echo "<script type='text/javascript'>
              			<!--
              			alert('Vous devez entrer la Base DN du serveur LDAP !');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			              //-->
    		        	</script>";
			        	exit;
	      			}
    	  			else // le nom du serveur LDAP et son port d'coute sont fournis : on vrifie la connexion
      				{
        				if (!@ldap_bind(ldap_connect($_POST['ldap_server_name'], $_POST['ldap_server_port']))) // Si connexion LDAP impossible
        				{
          					echo "<script type='text/javascript'>
              				<!--
              				alert('La connection au serveur LDAP en anonyme (sur le port 389) a chou ! Veuillez vrifier le nom du serveur ou votre connexion rseau.');
              				window.location.href='install.php?soumettre=non_vide&etape=9';
				            // -->
    		    		    </script>";
        		  			exit;
        				}
        				else // Tout est OK
        				{
          					$_SESSION['liste_variables']['ldap_server_name'] = $_POST['ldap_server_name'];
          					$_SESSION['liste_variables']['ldap_server_port'] = $_POST['ldap_server_port'];
          					$_SESSION['liste_variables']['ldap_base_dn'] = $_POST['ldap_base_dn'];
          					$code_formulaire .= "<p><span class='ok'>La connexion au serveur LDAP a russi !</span></p><p>Vous pouvez passer  l'tape suivante.</p>";
        				}
      				}
  					break;
  				
  				case 'cas':
  					if ($_POST['cas_server_name'] == "") // nom du serveur CAS non fourni
      				{
        				echo "<script type='text/javascript'>
              			<!--
              			alert('Vous devez entrer le nom du serveur CAS  contacter !');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			              //-->
    		        	</script>";
			        	exit;
	      			}
	      			if ($_POST['cas_server_port'] == "") // port du serveur CAS non fourni
	      			{
	      				echo "<script type='text/javascript'>
              			<!--
              			alert('Vous devez entrer le port d'coute du serveur CAS !');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			              //-->
    		        	</script>";
			        	exit;
	      			}
  					if ($_POST['ldap_server_name'] == "") // nom du serveur LDAP non fourni
      				{
        				echo "<script type='text/javascript'>
              			<!--
              			alert('Vous devez entrer le nom du serveur LDAP  contacter !');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			              //-->
    		        	</script>";
			        	exit;
	      			}
  					if ($_POST['ldap_server_port'] == "") // nom du serveur LDAP non fourni
      				{
        				echo "<script type='text/javascript'>
              			<!--
              			alert('Vous devez entrer le port d'coute du serveur LDAP !');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			              //-->
    		        	</script>";
			        	exit;
	      			}
  					if ($_POST['ldap_base_dn'] == "") // nom du serveur LDAP non fourni
      				{
        				echo "<script type='text/javascript'>
              			<!--
              			alert('Vous devez entrer la Base DN du serveur LDAP !');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			              //-->
    		        	</script>";
			        	exit;
	      			}
    	  			// Si on arrive ici, c'est que tous les champs requis sont remplis
    	  			// On vrifie d'abord la connexion au service CAS
    	  			$url = "https://".$_POST['cas_server_name'].":".$_POST['cas_server_port'];
    	  			$err = verif_url_syntax_exist($url);
  					if ($err!="")
      				{
        				echo "<script type='text/javascript'><!--
              			alert('Vous n\'avez pas entr un nom, une adresse IP ou un port correct pour contacter le serveur CAS."."\\"."nVeuillez corriger SVP ! ".addslashes($err).".');
              			window.location.href='install.php?soumettre=non_vide&etape=9';
			            //--></script>";
        				exit;
      				}
      				else // les infos de connexion au serveur CAS sont OK
      				{
      					$_SESSION['liste_variables']['cas_server_name'] = $_POST['cas_server_name'];
      					$_SESSION['liste_variables']['cas_server_port'] = $_POST['cas_server_port'];
      					$code_formulaire .= "<p><span class='ok'>La connexion au serveur SSO a russi !</span></p>";
      				}
  					if (!@ldap_bind(ldap_connect($_POST['ldap_server_name'], $_POST['ldap_server_port']))) // Si connexion LDAP impossible
        			{
          				echo "<script type='text/javascript'>
              			<!--
              			alert('La connection au serveur LDAP en anonyme (sur le port 389) a chou ! Veuillez vrifier le nom du serveur ou votre connexion rseau.');
				        window.location.href='install.php?soumettre=non_vide&etape=9';
              			// -->
    		    	    </script>";
        		  		exit;
        			}
        			else
        			{
          				$_SESSION['liste_variables']['ldap_server_name'] = $_POST['ldap_server_name'];
          				$_SESSION['liste_variables']['ldap_server_port'] = $_POST['ldap_server_port'];
          				$_SESSION['liste_variables']['ldap_base_dn'] = $_POST['ldap_base_dn'];
          				$code_formulaire .= "<p><span class='ok'>La connexion au serveur LDAP a russi !</span></p><p>Vous pouvez passer  l'tape suivante.</p>";
        			}
  					break;
	  			
	  		}
	  		$code_formulaire .= "
	    	</div>
	    	<br />";
	    	$code_formulaire .= "<input type='hidden' name='etape' value='11' />";
	    	echo "<br /><center>";
	    	squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Suivant >>","soumettre","","","","","");
	    	echo "</center>";
    	}
    	else
    	{
    		echo "<script type='text/javascript'>
           		  <!--
           	  	alert('Vous n\'avez pas rempli tous les champs du formulaire !');
          	  	window.location.href='install.php?soumettre=non_vide&etape=9';
		        // -->
    	 	  	</script>";
        	exit;
    	}
  }
  elseif ($_POST['etape'] == 11 || (isset($_GET['etape']) && $_GET['etape'] == 11))
  {
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    //print_r($_SESSION['liste_variables']);
    // On initialise aussi quelques index de ce tableau (evite un NOTICE Undefined index)
    // Lors du premier chargement de cette tape seulement $_POST['etape'] == 10, car si on y revient par exemple en cas de formulaire incomplet $_GET['etape'] == 10, il faut reprendre les valeurs dj postes
    if ($_POST['etape'] == 11)
    {
      $_SESSION['liste_variables']['new_nom_etablissement'] = "";
      $_SESSION['liste_variables']['new_adresse_etablissement'] = "";
      $_SESSION['liste_variables']['new_cp_etablissement'] = "";
      $_SESSION['liste_variables']['new_ville_etablissement'] = "";
      $_SESSION['liste_variables']['new_tel_etablissement'] = "";
      $_SESSION['liste_variables']['new_fax_etablissement'] = "";
      $_SESSION['liste_variables']['new_email_etablissement'] = "";
      $_SESSION['liste_variables']['new_nom_directeur_publication'] = "";
      $_SESSION['liste_variables']['new_email_directeur_publication'] = "";
      $_SESSION['liste_variables']['new_url_site_etablissement'] = "";
      $_SESSION['liste_variables']['new_admin_name'] = "";
      $_SESSION['liste_variables']['new_admin_passwd'] = "";
      $_SESSION['liste_variables']['new_admin_email'] = "";
      $_SESSION['liste_variables']['repeat_new_admin_passwd'] = "";
      $_SESSION['liste_variables']['new_message_pied_page'] = "";
    }
    
    //************************* Etape 11 : Informations sur l'tablissement **********************/
    
    $checked_clg = "";
    $checked_lyc = "";
    // On aura besoin du code javascript qui suit pour crypter en local le mot de passe admin
    echo "<script language=\"JavaScript\" type=\"text/javascript\" src=\"cryptpasswd_install.js\"></script>";
    if (isset($_SESSION['liste_variables']['new_type_etablissement']) && $_SESSION['liste_variables']['new_type_etablissement'] == "Collge")
      $checked_clg = "checked='checked'";
    elseif (isset($_SESSION['liste_variables']['new_type_etablissement']) && $_SESSION['liste_variables']['new_type_etablissement'] == "Lyce")
      $checked_lyc = "checked='checked'";
    $code_formulaire = "
    <br />
    <div class='titre_cadre_formulaire'><h2>Etape 11 : Informations sur l'tablissement</h2></div>
    <div class='cadre_formulaire'>
     <p class='info_importante'>La plupart des informations suivantes apparatront sur chaque page du site dans l'encadr suivant le sommaire et sur chaque pied de page.</p>
     <fieldset class='form_config'>
     	<legend>Nature de l'tablissement</legend>
     		<input type='radio' id='rbt-typetabCollege' name='new_type_etablissement' tabindex='1' value='Collge' $checked_clg />
     		<label for='rbt-typetabCollege'>Collge</label>
     		<input type='radio' id='rbt-typetabLycee' name='new_type_etablissement' tabindex='2' value='Lyce' $checked_lyc />
     		<label for='rbt-typetabLycee'>Lyce</label>
     </fieldset>
     <br />
     <fieldset class='form_config'>
     	<legend>Renseignements sur l'tablissement</legend>
     <table border=0>
       <tr>
         <td align='right'>
           <label for='Form_Req_Nom_Etablissement' accesskey='N'>Nom de l'tablissement</label>
         </td>
         <td>
           <input type='text' id='Form_Req_Nom_Etablissement' name='new_nom_etablissement' tabindex='3' value=\"".stripslashes($_SESSION['liste_variables']['new_nom_etablissement'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
           <label for='Form_Req_Adresse_Etablissement' accesskey='A'>Adresse</label>
         </td>
         <td>
           <input type='text' id='Form_Req_Adresse_Etablissement' name='new_adresse_etablissement' tabindex='4' value=\"".stripslashes($_SESSION['liste_variables']['new_adresse_etablissement'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Req_Code_postal_Etablissement' accesskey='C'>Code postal</label>
         </td>
         <td>
           <input type='text' id='Form_Req_Code_postal_Etablissement' name='new_cp_etablissement' tabindex='5' value=\"".stripslashes($_SESSION['liste_variables']['new_cp_etablissement'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
           <label for='Form_Req_Ville_Etablissement' accesskey='V'>Ville</label>
         </td>
         <td>
           <input type='text' id='Form_Req_Ville_Etablissement' name='new_ville_etablissement' tabindex='6' value=\"".stripslashes($_SESSION['liste_variables']['new_ville_etablissement'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Req_Tel_Etablissement' accesskey='T'>Tlphone</label>  
         </td>
         <td>
           <input type='text' id='Form_Req_Tel_Etablissement' name='new_tel_etablissement' tabindex='7' value=\"".stripslashes($_SESSION['liste_variables']['new_tel_etablissement'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Req_Fax_Etablissement' accesskey='F'>Fax</label>
         </td>
         <td>
           <input type='text' id='Form_Req_Fax_Etablissement' name='new_fax_etablissement' tabindex='8' value=\"".stripslashes($_SESSION['liste_variables']['new_fax_etablissement'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
           <label for='Form_Email_Etablissement' accesskey='E'>Email</label>
         </td>
         <td>
           <input type='text' id='Form_Email_Etablissement' name='new_email_etablissement' tabindex='9' value=\"".stripslashes($_SESSION['liste_variables']['new_email_etablissement'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
           <label for='Form_Req_Chef_Etablissement' accesskey='O'>Prnom NOM du Chef d'tablissement</label>
         </td>
         <td>
           <input type='text' id='Form_Req_Chef_Etablissement' name='new_nom_directeur_publication' tabindex='10' value=\"".stripslashes($_SESSION['liste_variables']['new_nom_directeur_publication'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
           <label for='Form_Email_Chef_Etablissement' accesskey='M'>Email du Chef d'tablissement :</label>
         </td>
         <td>
           <input type='text' id='Form_Email_Chef_Etablissement' name='new_email_directeur_publication' tabindex='11' value=\"".stripslashes($_SESSION['liste_variables']['new_email_directeur_publication'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_URL_Site_Etablissement' accesskey='U'>URL du site internet de l'tablissement</label>  
         </td>
         <td>
           <input type='text' id='Form_URL_Site_Etablissement' name='new_url_site_etablissement' tabindex='12' value=\"".stripslashes($_SESSION['liste_variables']['new_url_site_etablissement'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Req_Nom_Admin_IEW' accesskey='M'>Prnom NOM de l'Administrateur IEW</label>
         </td>
         <td>
           <input type='text' id='Form_Req_Nom_Admin_IEW' name='new_admin_name' tabindex='13' value=\"".stripslashes($_SESSION['liste_variables']['new_admin_name'])."\">
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Req_Passwd_Admin_IEW' accesskey='S'>Son mot de passe</label>
         </td>
         <td>
           <input type='password' id='Form_Req_Passwd_Admin_IEW' name='new_admin_passwd' tabindex='14' value='".$_SESSION['liste_variables']['new_admin_passwd']."' />
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Req_Repeat_Passwd_Admin_IEW' accesskey='T'>Rpter son mot de passe</label>  
         </td>
         <td>
           <input type='password' id='Form_Req_Repeat_Passwd_Admin_IEW' name='repeat_new_admin_passwd' tabindex='15' value='".$_SESSION['liste_variables']['repeat_new_admin_passwd']."' />
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Email_Admin_IEW' accesskey='D'>Adresse email de l'administrateur IEW</label>
         </td>
         <td>
           <input type='text' id='Form_Email_Admin_IEW'name=' new_admin_email' tabindex='16' value='".$_SESSION['liste_variables']['new_admin_email']."' />
         </td>
       </tr>
       <tr>
         <td align='right'>
         	<label for='Form_Message_Pied_Page' accesskey='I'>Texte de pied de page</label>
         </td>
         <td>
           <textarea rows='4' id='Form_Message_Pied_Page' name='new_message_pied_page'>".stripslashes($_SESSION['liste_variables']['new_message_pied_page'])."</textarea>
         </td>
       </tr>
     </table>
     </fieldset>";
     $code_formulaire .= info_champs_obligatoires();
    $code_formulaire .= "</div><br /><input type='hidden' name='etape' value='fin' />
    <input type='hidden' name='md5_admin_passwd' />"; // Champ cach pour le cryptage MD5 du mot de passe de l'administrateur
    echo "<br /><center>";
    squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF']."' name='infos_etab_form' onsubmit='javascript:submit_pass();","<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"Terminer","soumettre","","","","","");
    echo "</center>";
    echo "<script type='text/javascript'><!-- document.infos_etab_form.new_nom_etablissement.focus(); //--></script>";
  }
  elseif ($_POST['etape'] == "fin")
  {
    $_SESSION['liste_variables'] = array_merge($_SESSION['liste_variables'],$_POST);
    //print_r($_SESSION['liste_variables']);
    // On vrifie les entres du formulaire d'informations sur l'tablissement
    // Les champs obligatoires sont-ils remplis ?
    $champs_obligatoires = array("$_POST[new_type_etablissement]","$_POST[new_nom_etablissement]","$_POST[new_adresse_etablissement]","$_POST[new_cp_etablissement]","$_POST[new_ville_etablissement]","$_POST[new_tel_etablissement]","$_POST[new_fax_etablissement]","$_POST[new_nom_directeur_publication]","$_POST[new_admin_name]","$_POST[md5_admin_passwd]");
    //echo "<br />";print_r($champs_obligatoires);echo "<br />";
    if (filled_out($champs_obligatoires)) // Si le formulaire prcdent est bien rempli
    {
      // On vrifie la validit du format de certaines informations envoyes par l'utilisateur
      // On vrifie que le code postal est bien du numrique, idem pour le tl et le fax, vrifier la validit des adresses emails etc..... 
      if (!is_numeric($_POST['new_cp_etablissement']) )
      {
        echo "<script type='text/javascript'>
              <!--
              alert('Le code postal est incorrect (ce champ est doit tre rempli exclusivement de chiffres (sans espace) ! Veuillez corriger cette valeur SVP !');
              window.location.href='install.php?soumettre=non_vide&etape=11';
              //-->
            </script>";
        exit;
      }
      // Ces lignes de codes permettent de vrifier la validit de l'adresse email de l'tablissement
      // Mais si celle-ci n'est pas valide ou si la connexion internet n'est pas active, le test de validit
      // chouera. Dans ce cas, il faut indiquer  l'utilisateur soit de vrifier l'adresse, soit de laisser le
      // champ correspondant vide pour que l'installation aille tout de mme  son terme
      if ($_POST['new_email_etablissement']!="" && !email_check($_POST['new_email_etablissement'], $error_message))
      {
        echo "<script type='text/javascript'>
              <!--
              alert('Vous n\'avez pas entr une adresse email correcte pour l\'tablissement."."\\"."nVeuillez corriger SVP ! ".addslashes($error_message).".');
              window.location.href='install.php?soumettre=non_vide&etape=11';
              //-->
            </script>";
        exit;
      }
      
      if ($_POST['new_email_directeur_publication']!="" && !email_check($_POST['new_email_directeur_publication'], $error_message))
      {
        echo "<script type='text/javascript'><!--
              alert('Vous n\'avez pas entr une adresse email correcte pour le Chef d\'tablissement."."\\"."nVeuillez corriger SVP ! ".addslashes($error_message).".');
              window.location.href='install.php?soumettre=non_vide&etape=11';
            //--></script>";
        exit;
      }
      $err = verif_url_syntax_exist($_POST['new_url_site_etablissement']);
      if ( $_POST['new_url_site_etablissement']!="" && $err!="")
      {
        echo "<script type='text/javascript'><!--
              alert('Vous n\'avez pas entr une adresse URL correcte pour le site d\'tablissement."."\\"."nVeuillez corriger SVP ! ".addslashes($err).".');
              window.location.href='install.php?soumettre=non_vide&etape=11';
            //--></script>";
        exit;
      }
      /*if ($_POST["md5_admin_passwd"] != $_POST["md5_repeat_admin_passwd"])
      {
        echo "<script type='text/javascript'><!--
              alert('Les champs de mot de passe de l\'administrateur IntraEduWeb ne sont pas identiques !');
              window.location.href='install.php?soumettre=non_vide&etape=10';
            //--></script>";
        exit;
      }*/
      if ($_POST['new_admin_email']!="" && !email_check($_POST['new_admin_email'], $error_message))
      {
        echo "<script type='text/javascript'><!--
              alert('Vous n\'avez pas entr une adresse email correcte pour l\'Administrateur IEW."."\\"."nVeuillez corriger SVP ! ".addslashes($error_message).".');
              window.location.href='install.php?soumettre=non_vide&etape=11';
            //--></script>";
        exit;
      }
      // tout a t vrifi et c'est OK
      // Formatage du numro de tlphone + fax (00 00 00 00 00)
      $_SESSION['liste_variables']['new_tel_etablissement'] = numtel($_SESSION['liste_variables']['new_tel_etablissement']);
      $_SESSION['liste_variables']['new_fax_etablissement'] = numtel($_SESSION['liste_variables']['new_fax_etablissement']);
      // Formatage du nom + prnom de l'administrateur IntraEduWeb
      $fragment_nom = array();
      $fragment_nom = explode(" ",$_SESSION['liste_variables']['new_admin_name']);
      $admin_nom = strtoupper($fragment_nom[1]); // formate le nom en majuscules
      $admin_prenom = strtoupper(substr($fragment_nom[0],0,1)).strtolower(substr($fragment_nom[0],1,strlen($fragment_nom[0]))); // formate la 1re lettre du prnom en majuscule
      $_SESSION['liste_variables']['new_admin_name'] = $admin_prenom." ".$admin_nom;
      // Formatage du nom + prnom du directeur de publication
      $fragment_nom = explode(" ",$_SESSION['liste_variables']['new_nom_directeur_publication']);
      $directeur_nom = strtoupper($fragment_nom[1]); // formate le nom en majuscules
      $directeur_prenom = strtoupper(substr($fragment_nom[0],0,1)).strtolower(substr($fragment_nom[0],1,strlen($fragment_nom[0]))); // formate la 1re lettre du prnom en majuscule
      $_SESSION['liste_variables']['new_nom_directeur_publication'] = $directeur_prenom." ".$directeur_nom;
    }
    else
    {
      echo "<script type='text/javascript'><!--
              alert('Certains champs obligatoires ne sont pas remplis !');
              window.location.href='install.php?soumettre=non_vide&etape=11';
            //--></script>";
      exit;
    }
        
    //************************* Etape finale : criture du fichier de configuration **********************/
    
    // On rcupre d'abord toutes les variables
    foreach(array_keys($_SESSION['liste_variables'])as $cle)
    {
      $$cle = $_SESSION['liste_variables']{$cle};
      //echo "$".$cle." = ".$$cle."<br />";
    }
    $include_install = true; // c'est un flag pour l'include qui suit
    
    // L'ordre des include est important : 
    /**
     * Le fichier conf_dir.php va tre gnr  la racine IEW. Il contient le nom du dossier contenant les autres fichiers de configuration qui vont tre gnrs  partir des includes de modles
     */
    include("./templates/modele_conf_dir.php");
    /**
     * Le fichier config.php va tre rgnr
     */ 
    include("./templates/modele_config.php"); 
    
    /**
     * Paramtrage du fichier .htaccess pour la page erreur 404 propre  IntraEduWeb
     */
    include("./templates/modele_htaccess404.php"); // Le fichier .htaccess va tre rgnr

    // On va gnrer la cl de chiffrement utilis par l'algorithme de cryptage des infos sensibles
   // Mais il faut d'abord choisir l'algorithme et le mode de chiffrement qui seront utiliss

    // Dtermination des algorithmes disponibles sur ce serveur
    $algos = mcrypt_list_algorithms(); // retourne un tableau
    // Dtermination des modes de chiffrement disponibles sur ce serveur
    $modes = mcrypt_list_modes(); // retourne un tableau
    
    // Choix alatoire d'un couple algorithme/mode de chiffrement retournant la longueur du vecteur d'initialisation correspondant
    $iv_size = false;
    while (!$iv_size)
    {
      // Choix alatoire d'un algorithme
      $rand_key_algos = array_rand ($algos);
      // Choix alatoire d'un mode de chiffrement
      $rand_key_modes = array_rand ($modes);
      if (strtolower($modes[$rand_key_modes]) != "ecb") // le mode ECB est trop vulnrable aux attaques
      { // Dtermination de la longueur du vecteur d'initialisation en fonction du couple algorithme/mode de chiffrement
        $iv_size = @mcrypt_get_iv_size($algos[$rand_key_algos], $modes[$rand_key_modes]); // Ceci peut renvoyer une erreur : dans ce cas, on procde  un nouveau choix alatoire jusqu' ce que la fonction mycrypt_get_iv_size ne renvoie plus FALSE
      }
    }
    $algo = $algos[$rand_key_algos]; // voil l'algorithme choisi
    $mode = $modes[$rand_key_modes]; // // voil le mode choisi
    // On vrifie que la longueur du VI est =  la taille du bloc pour l'algo et le mode retenus
    $algo_block_size = mcrypt_get_block_size($algo,$mode);
    /*
    echo "Algorithme de cryptage retenu :".$algo;
    echo "<br />Mode :".$mode;
    echo "<br />Taille de VI trouve par mcrypt_get_iv_size() :".$iv_size." octets";
    echo "<br />Taille de VI trouve par mcrypt_get_block_size() :".$algo_block_size." octets";
     */
    if ($iv_size != $algo_block_size) // si ce n'est pas le cas
    {
    	// On remplace $iv_size par la taille de bloc adquate
    	$iv_size = $algo_block_size;
    }
    // calcul des longueurs max de la cl
    $key_size = mcrypt_module_get_algo_key_size($algo);
    // cration d'un IV alatoire de la bonne longueur
    // on peut mettre n'importe quoi dans $iv du moment qu'il est de la bonne longueur
    $iv = mcrypt_create_iv($iv_size, MCRYPT_RAND);
    $iv = str_replace(chr(34),"a",$iv); // On remplace ventuellement le guillemet double par un "a" car cette chane sera mise entre guillemets doubles dans k.php (on vite ainsi une erreur du parser PHP)
    // de mme, certains codes ascii (infrieurs  32) peuvent poser des problmes et gnrer des warnings
    // Unexpected character in input : (ASCII=22) par exemple, ce qui provoque ensuite des warnings sur les fonctions mcrypt_encrypt() et mcrypt_decrypt(). Donc il faut les remplacer par des chr(32+x) avec x>0
    // Mais il faut
    for ($i=0;$i<strlen($iv);$i++)
    {
      $character = substr($iv,$i,1);
      if (ord($character)<32)
        $iv = str_replace($character,chr(ord($character)+32),$iv);
    }
    // Au cas o, si la longueur de $iv n'est plus gale  celle de $iv_size (c'est dj arriv en dbuggant)
    while (strlen($iv) != $iv_size)
    {  
      $iv = substr($iv,0,strlen($iv)-1); // On retire un cc  la fin
    }
    //  ce stade, on peut encore avoir des guillemets double rapparus dans $iv
    $iv = str_replace(chr(34),"a",$iv); // on les remplace par "a"
    //echo "<br />Taille du VI aprs traitement sur les caractres spciaux (doit tre la mme que prcdemment) :".strlen($iv);
    // cration alatoire d'une cl secrte de cryptage/dcryptage et mise  longueur
    $cle = sha1(time());
    $crypt_key = substr($cle, 0, $key_size);
    /**
     * On peut maintenant enregistrer la cl de chiffrement et le vecteur d'initialisation de l'algorithme dans le fichier k.php 
     */
    include("./templates/modele_k.php");
    /**
     * On enregistre l'identifiant et le mot de passe MySQL (vont tre chiffrs) dans le fichier inc_connect.php
     */
    include("./templates/modele_inc_connect.php");
	/**
	 * Pour accder  la constante CONF_DIR dans ce qui suit
	 */
    include("../conf_dir.php");
    
    /* On Cre deux fichiers de commande shell pour un backup/restore de la base de donnes
    // Pourquoi ? Parce que la fonction exec() sur une commande comprenant des arguments, pipes et redirection
    // engendre un problme d'xcution si la safe_mode est activ (dans ce cas les caractres | et > sont chapps
    // et par exemple la commande myqldump -uuser -ppassword --opt iew_database | gzip /repertoire_de_stockage_iew/backup/iew_database.sql.gz ne peut s'excuter correctement (PHP applique obligatoirement la fonction escapeshellcmd() ce qui chappe les caractres cits plus haut), alors que cette mme commande s'excute parfaitement lorsque le safe_mode est off*/
    // Ces fichiers doivent tre placs manuellement par l'administrateur du serveur hbergeant IEW dans un rpertoire spcifi par la directive safe_mode_exec_dir et placs en droits 750 (c'est dcrit dans la documentation administrateur)
    
    // Les paramtres $1 et $2 contiennent l'identifiant et le mot de passe de l'utilisateur MySQL ayant accs  la base de donnes IEW 
    // Pour des raisons de scurit, ces informations n'apparatront pas en clair dans le script de commande
    // mais seront fournis par la commande exec() du script c_sauvegarde.php ou c_restauration au moment de l'appel de ces scripts de commande

    // $3 contient le nom de la base de donnes IEW
    // $4 contient le nom du fichier de sortie
    $bkup_script = fopen(CONF_DIR."bkup-iew.sh","w");
    $contenu = "#!/bin/bash\n";
    $contenu .= "mysqldump --default-character-set=latin1 -u$1 -p$2 --opt $3 | gzip > $4";
    fwrite($bkup_script,$contenu);
    fclose($bkup_script);
    chmod(CONF_DIR."bkup-iew.sh",0750); //rendu excutable pour l'utilisateur apache
    
    // $1 : nom du fichier de sauvegarde de la base
    // Les paramtres $2 et $3 contiennent l'identifiant et le mot de passe de l'utilisateur MySQL ayant accs  la base de donnes IEW 
    // $4 contient le nom de la base de donnes IEW  restaurer
    $restore_script = fopen(CONF_DIR."restore-iew.sh","w");
    $contenu = "#!/bin/bash\n";
    $contenu .= "gunzip < $1 | mysql -u$2 -p$3 $4";
    fwrite($restore_script,$contenu);
    fclose($restore_script);
    chmod(CONF_DIR."restore-iew.sh",0750); // rendu excutable pour l'utilisateur apache

  // FIN DE L'INSTALLATION

  if (connexion_mysql() && select_database())
  {
    // On inscrit la date d'installation (vite d'xcuter  nouveau le script d'install)
    $sql = "INSERT INTO installation VALUES(NOW());";
    mysql_query($sql);
    // On enregistre dans la base de donne la version qui est installe
    $sql = "INSERT INTO version VALUES('".trim(file_get_contents(IEW_DIR."VERSION"))."');";
    mysql_query($sql);
    // Pendant qu'on est connect, on enregistre le NOM et le prnom de l'administrateur IntraEduWeb
    $password = trim(htmlspecialchars($_SESSION['liste_variables']["md5_admin_passwd"]));
    $mdp = $password; // pas besoin de crypter md5 c'est dj fait sur le client au moment du post
    // Le nom et le prnom de l'administrateur IntraEduWeb n'est pas enregistr dans la base de donnes
    // (mais il l'est dans le fichier config.php) car cela empche la cration future d'un membre du personnel
    // portant les mmes nom et prnom (l'admin est en principe un membre du personnel !)
    $sql = "UPDATE login SET mot_pass='".quote_smart($mdp)."' WHERE nomlogin='admin-iew'";
    if (!mysql_query($sql))
    {
      $error_message = array("Le processus d'installation n'a pu se finaliser car la dernire requte MySQL n'a pu s'excuter. Veuillez recharger cette page en utilisant le bouton &lt;Actualiser&gt; de votre navigateur.","");
      affiche_erreurs($error_message);
      exit;
    }
  }
  else // Si la connexion choue ici, c'est srement parce que les fichiers contenant les identifiants de connexion qui viennent d'tre gnrs n'ont pas t rechargs dans les fonctions connexion_mysql() && select_database(). Donc en fait l'installation s'est faite correctement si l'inscription de la date d'install dans la base de donnes a eu lieu
  // Ce problme semble se poser uniquement lorsque le dossier de stockage des fichiers spciaux est situ en dehors de l'arborescence web...
  // Toute la dernire tape est alors renouvelle (mais a marche) en rechargeant la page.
  {
    $error_message = array("Pour terminer le processus d'installation vous devez recharger cette page en utilisant le bouton &lt;Actualiser&gt; de votre navigateur.","");
    affiche_erreurs($error_message);
    exit;
  }
  $code_formulaire = "
  <br />
  <div class='titre_cadre_formulaire' align='center'><h2>Etape finale</h2></div>
  <div class='cadre_formulaire' align='center'>
    <div align='justify'><br />Vous avez termin la configuration de IntraEduWeb. Sur la page suivante, vous devrez vous connecter en utilisant l'identifiant <font color='red'><b>admin-iew</b></font> et <u>votre mot de passe d'administrateur IntraEduWeb</u>. <a href='".$chemin_relatif."index.php?log=locale'>Rendez-vous sur la page d'accueil de l'application</a><br /></div>
  </div><br />";
  echo "<br /><center>";
  squelette_formulaire_standard("75%","post",$_SERVER['PHP_SELF'],"<h1>Procdure d'installation IntraEduWeb</h1>",$code_formulaire,"","","","","","","");
  echo "</center>";
  }
} // else (if verif_install)

fin_code_html();
?>