<?php 
/**
 * fonctions_edt.php
 *
 * Regroupe les fonctions utilises pour la fonctionnalit EDT (Emplois du temps)
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	$LastChangedRevision$, $LastChangedDate$
 * @copyright	2004-2013 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

function ecart_minutes_2_horaires($h1,$h2)
{
	/**
	 * Renvoit l'cart en minutes sparant 2 horaires sous forme hh."h".mm
	 * IL EST IMPORTANT QUE LES HEURES ET LES MINUTES SOIENT REPRESENTEES AVEC 2 CHIFFRES ! (pour le bon fonctionnement de la fonction min())
	 * 
	 * @param $h1 : premier horaire
	 * @param $h2 : deuxime horaire
	 * 
	 * @return $diff_min : cart en minutes entre les 2 horaires
	 */
	// Pour que le calcul soit fiable h1 doit tre l'horaire le + ancien => on fait du min et du max pour s'en assurer :
	$details_h1 = explode("h",min($h1,$h2)); // $details_h1[0] contient la partie heure, $details_h1[1] contient la partie minute
	$details_h2 = explode("h",max($h1,$h2));
	$compl = 60 - intval($details_h1[1]); // complment  60 min (tjs positif)
	$diff_h = abs(intval($details_h1[0]) - intval($details_h2[0])); // cart horaire (tjs entier)
	$compl_60 = intval($details_h2[1]) - 60; // complment  60 min (tjs ngatif)
	$duree_diff_h_en_min = $diff_h * 60; // cart horaire en minutes
	$duree_diff_min = $compl + $compl_60;
	$diff_min = $duree_diff_h_en_min + $duree_diff_min;
	// DEBUGG var_dump($details_h1,$details_h2,$compl,$diff_h,$compl_60,$duree_diff_h_en_min,$duree_diff_min,$diff_min);
	return $diff_min;
}

function is_edt_import()
{
	/**
	 * Teste si les EDT ont t imports
	 * 
	 * @return true si les EDT ont t imports ou false si les EDT n'ont pas t imports
	 */
	$sql = "SELECT COUNT(*) as nb_cours FROM cours";
	$resultat = mysql_query($sql);
	if ($resultat)
	{
		$ligne = mysql_fetch_array($resultat);
		if ($ligne["nb_cours"] == 0)
		{
			$error_message = array("Les emplois du temps n'ont pas t imports dans l'application. La fonctionnalit n'est pas disponible.<br />Veuillez contacter l'<a href=\"mailto:".email_encode($admin_email)."\">administrateur <abbr title='IntraEduWeb'>IEW</abbr></a> ","");
			affiche_erreurs($error_message);
			return false; 
		}
		else
			return true;
	}
	else 
	{
		$error_message = array("En raison d'un probable problme avec le serveur de base de donnes, Il n'a pas t possible de savoir si les emplois du temps ont t import.<br />Veuillez revenir sur cette page ultrieurement","");
		affiche_erreurs($error_message);
		return false;
	}
}

function recup_horaires_debut_cours()
{
	/**
	 * Trouve les horaires de dbut de cours et les stocke dans un tableau
	 */
	
	$horaires_sql = array(); // variable locale, important  signaler
	
	// on cherche toutes les heures de dbut de cours
	$sql = "SELECT distinct heure_debut FROM cours ORDER BY heure_debut";
	$resultat = mysql_query($sql);
	while ($ligne = mysql_fetch_array($resultat))
	{
		$horaires_sql[] = $ligne['heure_debut'];
	}
	$sql = "SELECT distinct heure_debut FROM cours_diff ORDER BY heure_debut";
	$resultat = mysql_query($sql);
	$horaires_sql_diff = array(); // initialis car si ces horaires n'existent pas le array_merge effectu + bas gnre une erreur
	while ($ligne = mysql_fetch_array($resultat))
	{
		$horaires_sql_diff[] = $ligne['heure_debut'];
	}
	
	$horaires_sql = array_unique(array_merge($horaires_sql,$horaires_sql_diff));
	sort($horaires_sql);
	return $horaires_sql;
}

function horaires_print($horaires_hhmm)
{
	/**
	 * Prend un tableau d'horaire au format hhmm et le renvoie au format hh.h.mm pour affichage dans les plannings notamment EDT ou cahier d'appel
	 * 
	 * @param $horaires_hhmm (array)
	 * @return $horaires_print
	 */
	
	$horaires_print = array(); // variable locale, important  signaler
	
	$nblignes = count($horaires_hhmm);
	for ($i=1;$i<$nblignes+1;$i++) // on boucle sur les lignes du tableau d'affichage
	{
		$horaires_print[$i] = substr($horaires_hhmm[$i-1],0,2)."h".substr($horaires_hhmm[$i-1],-2);
	}
	return $horaires_print;
}

function recup_horaires_edt()
{
	/**
	 * Trouve les horaires de l'tablissement pour les afficher dans l'edt
	 * et les stocke dans 3 tableaux (variables globales) :
	 * - $horaires_sql contient les horaires au format brut hhmm (tels quels dans la base de donnes)
	 * - $horaires_print contient les horaires au format hh."h".mm (pour afficher les horaires)
	 * - $horaires_recrees contenant (si dfinis) les horaires de dbut des rcrations (si on veut voir ces pauses dans les EDT)
	 */
	
	global $horaires_sql,$horaires_print,$horaires_recrees;
	
	$horaires_sql = recup_horaires_debut_cours();
	
	// on rcupre les horaires des pauses (rcrations, pause djeuner)
	$sql = "SELECT * FROM horaires_pauses";
	$resultat = mysql_query($sql);
	$ligne = mysql_fetch_array($resultat);
	$horaires_pauses = array(); // initialis car si les horaires de pause n'existent pas le array_merge effectu + bas gnre une erreur
	if (!is_null($ligne['debut_recree_matin']) && $ligne['debut_recree_matin'] != "")
	{
		$horaires_pauses[] = $ligne['debut_recree_matin'];
		$horaires_recrees[] = $ligne['debut_recree_matin'];
	}
	if (!is_null($ligne['debut_pause_dej']) && $ligne['debut_pause_dej'] != "")
		$horaires_pauses[] = $ligne['debut_pause_dej'];
	if (!is_null($ligne['debut_recree_aprem']) && $ligne['debut_recree_aprem'] != "")
	{
		$horaires_pauses[] = $ligne['debut_recree_aprem'];
		$horaires_recrees[] = $ligne['debut_recree_aprem'];
	}
	
	$horaires_sql = array_unique(array_merge($horaires_sql,$horaires_pauses));
	sort($horaires_sql);
	
	// et l'horaire de fin du dernier cours
	$sql = "SELECT max(fin_cours) as h_fin FROM horaires_edt";
	$resultat = mysql_query($sql);
	$ligne = mysql_fetch_array($resultat);
	$horaires_sql[] = $ligne['h_fin'];
	$horaires_print = horaires_print($horaires_sql);
	// DEBUGG print "Tableaux des horaires";var_dump($horaires,$horaires_print,$horaires_sql);
}

function recup_durees_cours()
{
	/**
	 * Trouve toutes les dures possibles des cours (dtermines lors de l'import de EDT_vers_STS_RNE_AAAA.xml)
	 * 
	 *  @return $durees_cours : contient les dures au format hhmm
	 */
	$sql = "SELECT distinct duree FROM cours ORDER BY duree";
	$resultat = mysql_query($sql);
	while ($ligne = mysql_fetch_array($resultat))
	{
		$durees_cours[] = $ligne['duree'];
	}
	return $durees_cours;
}
?>