<?php
/**
 * fonctions_fichiers.php
 *
 * regroupe des fonctions de traitement de fichiers et/ou de rpertoires
 * mais aussi des fonctions de formatage HTML comme les squelettes de formulaires, de liens...
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package		IEW
 * @author			Sylvain GODM <sylvain.godme@gmail.com>
 * @version		$LastChangedRevision$, $LastChangedDate$
 * @copyright		2004-2012 Sylvain GODM
 * @link			http://iew.free.fr
 * @license		GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

function rdel($path)
{
    // $path est le chemin relatif au fichier php

    // on vrifie d'abord que le nom du repertoire contient "/"  la fin,
    // sinon on le lui rajoute
    if ($path[strlen($path)-1] != "/")
        $path .= "/";

    if (is_dir($path))
    {
        $d = opendir($path);

        while ($f = readdir($d))
        {
            if ($f != "." && $f != "..")
            {
                $rf = $path . $f; // chemin relatif au fichier php
                if (is_dir($rf))
                    rdel($rf);
                else
                    unlink($rf);
            }
        }
        
        closedir($d);

        rmdir($path);
    }
}

function delfile($dir,$except)
{
	// on vrifie d'abord que le nom du repertoire contient "/"  la fin,
    	// sinon on le lui rajoute
    	if ($dir[strlen($dir)-1] != "/")
        $dir .= "/";
	// Efface tous les fichiers d'un dossiers sauf celui pass en paramtre $except
	$id_dir = opendir($dir); 
	while($element = readdir($id_dir)) 
	{
		// On n'efface seulement les fichiers, pas les rpertoires (pour les rpertoires, utiliser la fonction rmdirr()
		if (is_array($except))
		{
			//print_r($except); echo "<br />";
			if ($element != "." && $element != ".." && !in_array($element,$except) && !is_dir($dir.$element))
				unlink($dir.$element);
		}
		else
		{
			if ($element != "." && $element != ".." && $element != $except && !is_dir($dir.$element))
				unlink($dir.$element);
		}
	}
      closedir($id_dir);
}

function copy_dir ($dir2copy,$dir_paste,$except)
{
  /**************************************************
  **
  **            [ FONCTION copy_dir ]
  **
  **            Par Jrmy Dombier - Utilisation libre
  **
  **            Copie un dossier vers un autre 
  **
  **            Modifi par Sylvain GODM pour IEW
  **            ajout du paramtre $except (pour le dossier ou fichier  exclure)
  **            $except 
  **
  **************************************************/
  $erreur = "";  
// On vrifie si $dir2copy est un dossier
  if (is_dir($dir2copy))
  {
    // Si oui, on l'ouvre
    if ($dh = opendir($dir2copy))
    { 
      // On liste les dossiers et fichiers de $dir2copy
      while (($file = readdir($dh)) !== false)
      {
        // Si le dossier dans lequel on veut coller n'existe pas, on le cr
        if (!is_dir($dir_paste)) 
          mkdir ($dir_paste, 0755);
        // S'il s'agit d'un dossier, on relance la fonction rcursive
        // Mais le nom du dossier ne doit pas commencer par le contenu de $except
        if (is_dir($dir2copy.$file) && $file != '..'  && $file != '.' && substr($file,0,strlen($except))!= $except) 
          copy_dir ( $dir2copy.$file.'/' , $dir_paste.$file.'/', $except );
        // S'il sagit d'un fichier, on le copie simplement
        elseif($file != '..'  && $file != '.' && substr($file,0,strlen($except))!= $except)
        {
          if (!copy ( $dir2copy.$file , $dir_paste.$file ))
            $erreur .= "Le fichier $dir2copy$file n'a pas pu tre copi dans $dir_paste$file<br />";
        }
      }
      // On ferme $dir2copy
      closedir($dh);
    }
  }
return $erreur;
}

function chargerClasse($classe) 
{
  /**
   * Pour l'Autoload de classe, charge la classe requise
   * 
   * @param $classe : le nom de la classe  rechercher et  charger
   * 
   * Ceci suppose que les classes soient dans le rpertoire 'classes' du dossier parent
   * 'controleurs' ou 'modeles' ou 'vues' du dossier parent 'nom_du_module' lui-mme ayant pour dossier parent 'modules' !!
   */
	
	$init_dir = IEW_DIR."modules/"; // chercher dans cette partie de l'arborescence
	$pointeur_modules = opendir($init_dir);
    while ($entree_module = readdir($pointeur_modules)) // lit chaque entre du rpertoire 'modules' (niveau 1)
    {
       if ($entree_module != "." && $entree_module != "..")
       {
        	$chemin_entree_module = $init_dir . $entree_module; // ex : IEW_DIR."modules/cdt"
       		if (is_dir($chemin_entree_module))
        	{
        		$pointeur_sous_module = opendir($chemin_entree_module);
        		while ($entree_sous_module = readdir($pointeur_sous_module)) // lit chaque entre du rpertoire 'modules'/'nom_du_module' (niveau 2) : on y trouve les rpertoires MVC
    			{
    				if ($entree_sous_module != "." && $entree_sous_module != "..")
       				{
    					$chemin_entree_sous_module = $chemin_entree_module . "/" . $entree_sous_module;
    					if (is_dir($chemin_entree_sous_module)) // on en cherche que le rpertoire 'classes'
       					{ 
       						$pointeur_mvc = opendir($chemin_entree_sous_module);
       						while ($entree_mvc = readdir($pointeur_mvc)) // lit chaque entre du rpertoire 'modules'/'nom_du_module'/controleurs ou modeles ou vues (niveau 3) : on y trouve le rpertoire 'classes'
       						{
       							if ($entree_mvc != "." && $entree_mvc != "..")
       							{
       								$chemin_entree_mvc = $chemin_entree_sous_module . "/" . $entree_mvc;
       								if (is_dir($chemin_entree_mvc) && $entree_mvc == "classes")
       								{
       									$pointeur_classes = opendir($chemin_entree_mvc);
       									while ($entree_classe = readdir($pointeur_classes)) // lit les entres du rpertoire 'classes'
       									{
       										if ($entree_classe != "." && $entree_classe != "..")
       										{
       											if ($entree_classe == $classe . ".php") // la classe cherche est trouve
       											{
       												$found_dir = $chemin_entree_mvc;
       												$succes = true;
       												require_once $found_dir . "/" . $classe . ".php"; // On inclut la classe correspondante au paramtre pass.
       												return; // on sort de la fonction
       											}
       										}
       									}
       								}
       							}
       						}
       					}  
       				}
    			}
        	}       
       }
    }
}
?>