<?php
/**
 * fonctions_mail.php
 *
 * regroupe les fonctions de courrier
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package		IEW
 * @author			Sylvain GODM <sylvain.godme@gmail.com>
 * @version		$LastChangedRevision$, $LastChangedDate$
 * @copyright		2004-2012 Sylvain GODM
 * @link			http://iew.free.fr
 * @license		GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */
 
/**
 * Constante contenant le chemin complet du rpertoire d'installation IEW
 */	
if(!defined('IEW_DIR')) define('IEW_DIR',realpath(dirname(__FILE__)."/../").'/');

/**
 * permet de vrifier que la connexion au serveur de mail fonctionne
 *
 * @param string $mail_server
 * @param integer $mail_protocol
 * @param string $login
 * @param string $passwd
 * @return le nombre de messages sur le serveur de mail
 */
function verif_connexion_mail($mail_server,$mail_protocol,$login,$passwd)
{
  //echo "@imap_open(\"{".$mail_server.$mail_protocol."}INBOX\", $login, $passwd)";
  $mbox = imap_open("{".$mail_server.$mail_protocol."}INBOX", "$login", "$passwd");
  if ($mbox) // Le serveur de messagerie a pu tre contact et la connexion a russi
  {
    $check = imap_mailboxmsginfo($mbox);
    if ($check)
    {
    	$nb_messages = $check->Unread;
    }
  	else
  	{
  		return "Impossible d'accder aux infos de la mailbox : ".imap_last_error();
  	}
    imap_close($mbox);
    return $nb_messages; // Renvoie le nombre de nouveaux messages (non lus) : valeur numrique
  }
  else
  {
    //message d'erreur, la valeur retourne est une chane de caractres (non numrique)
    return "Le serveur de messagerie est pour le moment inaccessible";
  }
}

/**
 * cette fonction permet de vrifier, pour l'utilisateur connect, si des nouveaux messages sont arrivs dans sa bote aux lettres
 * Il faut pour cela un serveur de messagerie interne et le nom de login IntraEduweb doit tre le nom du compte utilisateur de la
 * messagerie. Si on prvoit une messagerie externe, il faudra modifier du code et crer des tables supplmenatires pour y inscrire
 * les comptes de courrier de l'utilisateur
 *
 * @return le nombre de nouveaux mails ou un message d'erreur
 */
function verif_nouveaux_messages()
 {
   global $mail_server;
   global $mail_protocol;
   global $valid_login;
   global $passwd;
   
   if ($mail_server != "") // La configuration mail est faite
   {
    $mbox = @imap_open("{".$mail_server.$mail_protocol."}INBOX", "$valid_login", "$passwd");
    if ($mbox) // Le serveur de messagerie a pu tre contact et la connexion a russi
    {
     $nb_messages = imap_num_recent($mbox);
     @imap_close($mbox);
     return $nb_messages; // Renvoie le nombre de nouveaux messages (non lus) : valeur numrique
    }
    else
    {
     //message d'erreur, la valeur retourne est une chane de caractres (non numrique)
     return "Le serveur de messagerie est pour le moment inaccessible";
    }
   }
   else
   { 
    return "La messagerie n'est pas encore configure";
   }
 }

/**
 * permet de vrifier la validit d'une adresse email
 *
 * @param string $email
 * @param string $error_message
 * @return true|false
 */ 
function email_check($email, &$error_message) 
{
  $error_message="";
  if ($email == "")
  {
    $error_message = "L'email est vide";
    return false;
  }
  if (!preg_match("/^[-a-z0-9\._]+@[-a-z0-9\.]+\.[a-z]{2,4}$/i", $email))
  {
    $error_message = "Le format de l'email n'est pas valide";
    return false;
  }
  list($nom, $dom) = explode("@", $email); // On rcupre le nom de domaine dans la variable $dom
  if (!stristr($_SERVER['SERVER_SOFTWARE'],"win")) // Si on n'est pas sous windows pour apache
  { // par exemple sous linux
    if (!checkdnsrr($dom,"MX"))
    { 
      $error_message = "<div align='justify'>le nom de domaine <font color='black'><b>$dom</b></font> de l'adresse email n'existe pas. Il est aussi possible que votre connexion internet ne soit pas active; dans ce cas, laissez le champ correspondant du formulaire vide et cliquez sur le bouton de validation. Vous pourrez (si c'est possible) y revenir plus tard. Si vous retombez  nouveau sur ce type de message, c'est que l'adresse email et la connexion internet sont indispensables&nbsp;: vous devez alors rsoudre ce problme.</div>";
      return false;
    }
  }
  else // si apache tourne sous windows
  {
    // la fonction getmxrr de php n'est pas dispo sous windows : on la cre
    function getmxrr($hostname, &$mxhosts)
    {
      $mxhosts = array();
      exec('nslookup -type=mx '.$hostname, $result_arr);
      foreach($result_arr as $line)
      {
        if (preg_match("/.*mail exchanger = (.*)/", $line, $matches))
         $mxhosts[] = $matches[1];
      }
      return( count($mxhosts) > 0 );
    }
    // Si cette fonction choue
    if (!getmxrr($dom, $mxhosts))
    { 
      $error_message = "le nom de domaine <font color='black'><b>$dom</b></font> de l'adresse email n'existe pas. Il est aussi possible que votre connexion internet ne soit pas active; dans ce cas, laissez le champ correspondant du formulaire vide et cliquez sur le bouton de validation. Vous pourrez y revenir plus tard.";
      return false;
    }
  }
  return true;
}

/**
 * permet d'nevoyer un email avec fichier attach
 *
 * @param string $destinataire
 * @param string $sujet
 * @param string $corps
 * @param string $expediteur
 * @param string $chemin_fichier_attache
 * @deprecated
 */
function envoi_mail($destinataire,$sujet,$corps,$expediteur,$chemin_fichier_attache)
{
	// Cette classe va se charger de formater notre message au format MIME, en attachant optionnellement un ou plusieurs fichiers.
	require_once("mime_mail.class.php");

	/****** UTILISATION DE LA CLASSE MIME_MAIL (documentation) ****************************
		// On commence par mettre dans une variable le fichier  attacher.
    		$fichier       = @fread(fopen("logo.jpg", "r"), filesize("logo.jpg"));

    		// On cr une instance de cette classe
    		$mail	       = new mime_mail();
    		// Dfinition des destinataires.
    		$email         = "trash@phpteam.net";
    		$mail->to      = $email;
    		// Titre du message
    		$mail->subject = "E-mail avec un fichier attach";
    		// Dfinition du corps du message
    		$corps         = "Bonjour monsieur,\n Ci-joint le logo de phpteam.net";
    		$mail->body    = $corps;
    		// Dfinition de l'e-mail de l'expediteur ( paramtre optionnel )
    		$mail->from    = "toto@toto.org";
    		// Dfintion des enttes supplementaires ( paramtres optionnels )
    		$entetedate    = date("D, j M Y H:i:s -0700");
    		$entetemail .= "X-Mailer: PHP/" . phpversion() . "\n";
    		$entetemail .= "Date: ";
    		$mail->headers = "$entetemail";
    		// Dfinition du fichier attache ( paramtre optionnel )
    		$mail->attach("$fichier", "logo.jpg");
    		// On envoi le message
    		$mail->send();
    	*********************************************************************************/

	// On commence par mettre dans une variable le fichier  attacher.
    	$fichier = @fread(fopen("$chemin_fichier_attache", "r"), filesize("$chemin_fichier_attache"));

	// On cr une instance de cette classe
	$mail= new mime_mail();
	// Dfinition des destinataires.
	$mail->to = $destinataire;
	// Titre du message
	$mail->subject = $sujet;
	// Dfinition du corps du message
	$mail->body = $corps;
	// Dfinition de l'e-mail de l'expediteur ( paramtre optionnel )
    	$mail->from = $expediteur;
    	// Dfintion des enttes supplementaires ( paramtres optionnels )
    	$entetedate    = date("D, j M Y H:i:s -0700");
    	$entetemail .= "X-Mailer: PHP/" . phpversion() . "\n";
    	$entetemail .= "Date: ".$entetedate;
    	$mail->headers = "$entetemail";
    	// Dfinition du fichier attache ( paramtre optionnel )
    	$mail->attach("$fichier", "$chemin_fichier_attache");
    	// On envoie le message
    	$mail->send();
}

/**
 * Renvoie un lien si il existe vers le service webmail configur par l'administrateur du site
 *
 * @return $lien
 */
function lien_messagerie()
{
  if ($GLOBALS['url_mail_server'] != "")
  {
    $lien = $GLOBALS['url_mail_server'];
    return $lien;
  }
  else 
  {
    $lien = $GLOBALS['chemin_relatif']."nomailserver.php";
    return $lien;
  } 
}

/**
 * De nombreux robots parcourent le web  la recherche d'adresses email  spammer. Un moyen pour lutter
 * efficacement contre ce spam est le cryptage de vos adresses e-mail.
 * Cette petite fonction PHP permet de le faire trs simplement: dans le code du script appelant mettre :
 * echo email_encode("email@votresite.com")
 *
 * @param string $string
 * @return la chane encode
 */
function email_encode($string)
{
  /*
  ;
  */
  $ret_string="";
  $len=strlen($string);
  for($x=0;$x<$len;$x++)
  {
    $ord=ord(substr($string,$x,1));
    $ret_string.="&#$ord;";
  }
  return $ret_string;
}
?>