<?php
/**
 * librairie_fonctions.php
 *
 * regroupe toutes les fonctions communes utilises pour les scripts de l'application
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package		IEW
 * @author			Sylvain GODM <sylvain.godme@gmail.com>
 * @version		$LastChangedRevision$, $LastChangedDate$
 * @copyright		2004-2012 Sylvain GODM
 * @link			http://iew.free.fr
 * @license		GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

if(!defined('SESSION_NAME')) define('SESSION_NAME','IEW');
session_name(SESSION_NAME);
session_start();

if(!defined('IEW_DIR')) define('IEW_DIR',realpath(dirname(__FILE__)).'/');
// Inclusion du fichier de configuration
if (!file_exists(IEW_DIR."conf_dir.php")) // On va chercher la constante CONF_DIR dans conf_dir.php gnr  l'installation et qui contient le nom du dossier de stockage du fichier de configuration
  include(IEW_DIR."install/conf_dir-origine.php"); // utilis  l'installation
else
  include(IEW_DIR."conf_dir.php");
if (!file_exists(CONF_DIR."config.php"))
  require_once(IEW_DIR."install/config-origine.php"); // utilis  l'installation
else
  require_once(CONF_DIR."config.php");

if(!defined('DATA_DIR')) define('DATA_DIR', $GLOBALS['stock_baselev']);

// La vritable localisation des fonctions est dans le rpertoire lib

require_once(IEW_DIR."lib/fonctions_affichage.php");
require_once(IEW_DIR."lib/fonctions_bdd.php");
require_once(IEW_DIR."lib/fonctions_dates.php");
require_once(IEW_DIR."lib/fonctions_formulaires.php");
require_once(IEW_DIR."lib/fonctions_authentification.php");
require_once(IEW_DIR."lib/fonctions_mail.php");
require_once(IEW_DIR."lib/fonctions_erreurs.php");
require_once(IEW_DIR."lib/fonctions_liens.php");
require_once(IEW_DIR."lib/fonctions_fichiers.php");
require_once(IEW_DIR."lib/fonctions_diverses.php");

// On peut y ajouter d'autres fonctions si ncessaire


// On initialise la connexion  la base de donnes
connexion_mysql(); // ces 2 lignes sont ncessaires pour le maintien du fonctionnement des scripts crs avant le 01/01/2014
select_database();

// la connexion  la BDD se fait maintenant en mode orient objet
spl_autoload_register('chargerClasse'); // d'abord l'autoload de classes

if (file_exists(CONF_DIR."inc_connect.php") && file_exists(CONF_DIR."k.php")) // vite que le script s'arrte ici lors de l'installation (car ces fichiers n'existant pas encore) : fixed anomalie #
{
	require(CONF_DIR."inc_connect.php"); // Contient les codes d'accs (crypts)  la base de donnes MySQL
	require(CONF_DIR."k.php"); // Contient la cl de cryptage dfinie  l'installation
	$user = mcrypt_decrypt($algo, $crypt_key, base64_decode($mysql_admin), $mode, $iv);
	$passwd = mcrypt_decrypt($algo, $crypt_key, base64_decode($mysql_admin_passwd), $mode, $iv);

	define('DEBUG_DB_ACCESS',false); // provisoire, en dev, permet de logger les erreurs d'accs aux donnes de la base ( relocaliser)

	$db = new Db($mysql_server, $user, $passwd, $mysql_database); // instanciation d'un objet reprsentant la connexion
}

// Ce script est ncessaire pour le suivi des connexions
include(IEW_DIR."suivi_connexion.php");

// ou des initialisations de variables
$contexte = ""; // Dfinit le contexte des pages permettant suivant la valeur de conditionner l'affichage du sommaire dans le squelette
$chemin_relatif = ""; // Dfinit les rpertoires suprieurs  remonter pour accder au dossier images (contient ./ ou ../ ou ../../ etc)
$nb_messages = "";

// ou encore, le sytme de contrle du format d'affichage des pages (imprimable ou normal)

/* pour cela, on cherche l'existence d'une variable de session $_SESSION['nouveau_script']
Ceci, dans le but de savoir si le script  l'origine de l'appel au script courant est lui-mme ou un autre script
Si c'est lui-mme, alors il y a peut-tre eu un changement de format (si l'utilisateur a cliqu sur l'icne reprsentant le format imprimable de la page) et dans ce cas, il faut rcuprer les donnes du tableau $_POST (s'il est non vide) : c'est ce que font les squelettes de page (principal.php et imprimable.php).
Si ce n'est pas lui-mme, alors il faut dsenregistrer la variable $_SESSION['nouveau_script'] car sinon les valeurs d'un $_POST sur un autre script sont conservs puisque recharges par les squelettes de page  partir de $_SESSION['nouveau_script']


C'est le seul moyen que j'ai trouv pour l'instant pour transmettre des variables POST vers le format imprimable des pages. A charge pour le script de tester suivant l'existence de $_GET[imprimable'] ce qu'il doit faire c'est--dire prendre directement les valeurs de $_POST ou celles de $_SESSION['post_imprimable']

En ce qui concerne le tableau $_GET, il est automatiquement rcupr par les squelettes  travers la fonction recup_get_url() de faon  retransmettre les mmes paramtres entre les deux formats (normal et imprimable) de page

ATTENTION : il faut que les scripts utilisant les sessions dmarrent une session par session_start() AVANT que librairie_fonctions.php ne soit appele
*/
if (!isset($_SESSION['nouveau_script'])) // Si le script de session actuel n'est pas dfini
{
  $_SESSION['nouveau_script'] = $_SERVER['PHP_SELF']; // on lui affecte le nom du script actuel
}
else // si le script de session actuel est dfini
{
  if ($_SERVER['PHP_SELF'] == $_SESSION['nouveau_script']) // Si le script de session est le script excut actuellement
  {
    // Cela veut dire que l'appel du script vient depuis lui-mme
    // tout d'abord, s'il y a eu un changement de format (normal vers imprimable ou l'inverse), alors la variable imprimable est fournie dans l'url. Dans ce cas, il faut pouvoir rcuprer le tableau $_POST s'il existe (mais si l'utilisateur a cliqu sur le lien format imprimable (ou normal), ces valeurs ne sont pas transmises par POST, on a donc pris le soin au pralable, aprs toute soumission d'un formulaire de copier le tableau $_POST dans la variable de session $_SESSION['post_imprimable'], on assure ainsi sa transmission d'un format de page  l'autre)
    if (isset($_GET['imprimable']) && isset($_SESSION['post_imprimable'])) // si changement de format
    $_POST = $_SESSION['post_imprimable'];
    
    // Le script dcide de ce qu'il doit faire c'est--dire prendre directement les valeurs de $_POST ou celles de $_SESSION['post_imprimable']
    
  }
  elseif ($_SERVER['PHP_SELF'] != "/iew/je_suis_la.php" && $_SERVER['PHP_SELF'] != "/iew/prive/admin/prive/exit_archives.php" && $_SERVER['PHP_SELF'] != "/iew/prive/admin/prive/archives.php")  // Si l'appel vient d'ailleurs (sauf pour le heartbeat je_suis_la et la sortie des archives), on efface $_SESSION['post_imprimable'] qui ne sert plus, mais sera rinitialis (par les squelettes de page) en cas de POST sur la prochaine page
  {
    /* Les scripts qui n'affichent rien ou qui ne font que de la redirection de page ne doivent pas tre mmoriss dans les variables de session $_SESSION['ancien_cript'] ou $_SESSION['nouveau_cript'] : voir la doc dveloppeur pour + d'infos  ce sujet */
  	unset($_SESSION['post_imprimable']);
    $_SESSION['ancien_script'] = $_SESSION['nouveau_script']; // on mmorise le nom du script prcdent
    $_SESSION['nouveau_script'] = $_SERVER['PHP_SELF']; // le nouveau script est le script actuellement en excution
  }
}
?>