<?php 
/**
 * visas_ct.php
 *
 * Controleur pour la page de gestion des Visas de cahiers de textes
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	$LastChangedRevision$, $LastChangedDate$
 * @copyright	2004-2013 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

if(!defined('IEW_DIR')) define('IEW_DIR',realpath(dirname(__FILE__)."/../../../").'/');
// Inclusions
require_once(IEW_DIR."librairie_fonctions.php");

// Seuls les admin, la direction et les IPR ont droit d'accder aux pages de gestion des visas de cahiers de textes
$array_valid_user=array("1","6","11");
$error_message = check_valid_user($array_valid_user);

$chemin_relatif = "../../../"; // indique comment retrouver le rpertoire racine (pour le dossier 'images' par exemple)

//$contexte = "";
$titre_page = "Visas des cahiers de textes";
//$js = "";

$css = "visas.css";

// Accs aux donnes

function get_data_prof($id_prof, $last_pub_visa_service = false)
{
	/**
	 * Rcupre diverses donnes d'un professeur concernant ses cahiers de textes :
	 * - le dernier visa enregistr
	 * - la dernire sance de cahier de textes publie (niveau global, et au niveau de chaque service si $last_pub_visa_service vaut true
	 * - les taux de remplissage partiels (par service) ou globaux des cahiers de textes
	 * 
	 * @param $id_prof : identifiant numrique du professeur (id_individu)
	 * @param $last_pub_visa_service : paramtre optionnel (false par dfaut : on recherche la dernire publication et le dernier visa au niveau global, true s'il faut rechercher la dernire publication et le dernier visa au niveau de chaque service)
	 */
	
	global $db,$last_visas,$last_id_seances,$liste_services,$nb_total_jours_cours,$nb_total_seances_completees,$nb_jours_cours_deroules,$nb_seances_completees,$taux_partiel,$taux_global;
	
	$CdtVisamanager = new CdtVisaManager($db); // pas de donnes  transmettre pour l'instant, pas de CRUD prvu
	$CdtSeanceManager = new CdtSeanceManager($db);
	$ServiceProfesseurManager = new ServiceProfesseurManager($db);
	$EdtCoursManager = new EdtCoursManager($db);
	
	// On recherche le dernier Visa enregistr
	$last_visas[$id_prof] = $CdtVisamanager->getLastVisa($id_prof);
		
	// On recherche le dernier remplissage de sance dans CDT
	$last_id_seances[$id_prof] = $CdtSeanceManager->lastSeance($id_prof); // Renvoit un objet CdtSeance
		
	// et le taux de remplissage des CDT (sances) de ce prof
	$liste_services[$id_prof] = $ServiceProfesseurManager->getList($id_prof); // d'abord la liste des services d'enseignement de ce prof
	$nb_total_jours_cours[$id_prof] = 0;
	$nb_total_seances_completees[$id_prof] = 0;
		
	foreach ($liste_services[$id_prof] as $service_value) { // calcul du taux de remplissage partiel (par service)
		$id_enseignant_service = $service_value['id_enseignant_service'];
		$liste_cours = $EdtCoursManager->getListCoursEnseignantService($id_enseignant_service, $group_jour_cours = true);
		$nb_jours_cours_deroules[$id_prof][$id_enseignant_service] = $EdtCoursManager->getNbJoursCoursDeroules($liste_cours); // en fait c'est le nombre de jours de cours
		$nb_total_jours_cours[$id_prof] += $nb_jours_cours_deroules[$id_prof][$id_enseignant_service];
		$nb_seances_completees[$id_prof][$id_enseignant_service] = $CdtSeanceManager->getNbSeancesCompletees($id_prof,$id_enseignant_service);
		$nb_total_seances_completees[$id_prof] += $nb_seances_completees[$id_prof][$id_enseignant_service];
		if (isset($nb_jours_cours_deroules[$id_prof][$id_enseignant_service]) && $nb_jours_cours_deroules[$id_prof][$id_enseignant_service] !=0)
			$taux_partiel[$id_prof][$id_enseignant_service] = round(($nb_seances_completees[$id_prof][$id_enseignant_service]/$nb_jours_cours_deroules[$id_prof][$id_enseignant_service])*100);
		
		// la recherche suivante peut allonger la dure d'excution du script : c'est pourquoi on ne l'excute que pour l'interface professeur (pas l'interface globale)
		if ($last_pub_visa_service) {
			// On va aussi chercher la dernire publication pour ce service
			$last_id_seances[$id_prof][$id_enseignant_service] = $CdtSeanceManager->getlastSeanceService($id_prof,$id_enseignant_service);			
			// Et le dernier visa pour ce service
			$last_visas[$id_prof][$id_enseignant_service] = $CdtVisamanager->getLastVisaService($id_prof,$id_enseignant_service);
		}		
	}
		
	// Taux global de remplissage des CDT
	if (isset($nb_total_jours_cours[$id_prof]) && $nb_total_jours_cours[$id_prof] !=0)
		$taux_global[$id_prof] = round(($nb_total_seances_completees[$id_prof]/$nb_total_jours_cours[$id_prof])*100);
}

function get_data_structure($code_structure, $last_pub_visa_service = false)
{
	/**
	 * Rcupre diverses donnes d'une structure concernant ses cahiers de textes :
	 * - le dernier visa enregistr
	 * - la dernire sance de cahier de textes publie (niveau global, et au niveau de chaque service si $last_pub_visa_service vaut true
	 * - les taux de remplissage partiels (par service) ou globaux des cahiers de textes
	 * 
	 * @param $code_structure : identifiant numrique de la structure (code_structure)
	 * @param $last_pub_visa_service : paramtre optionnel (false par dfaut : on recherche la dernire publication et le dernier visa au niveau global, true s'il faut rechercher la dernire publication et le dernier visa au niveau de chaque service)
	 */
	
	global $db,$last_visas,$last_id_seances,$liste_services,$nb_total_jours_cours,$nb_total_seances_completees,$nb_jours_cours_deroules,$nb_seances_completees,$taux_partiel,$taux_global;
	
	$CdtVisamanager = new CdtVisaManager($db); // pas de donnes  transmettre pour l'instant, pas de CRUD prvu
	$CdtSeanceManager = new CdtSeanceManager($db);
	$ServiceEnseignementManager = new ServiceEnseignementManager($db);
	$ServiceProfesseurManager = new ServiceProfesseurManager($db);
	$EdtCoursManager = new EdtCoursManager($db);
	
	// On recherche le dernier Visa enregistr
	$last_visas[$code_structure] = $CdtVisamanager->getLastVisaStructure($code_structure);
		
	// On recherche le dernier remplissage de sance dans CDT
	$last_id_seances[$code_structure] = $CdtSeanceManager->lastSeanceStructure($code_structure); // Renvoit un objet CdtSeance
		
	// et le taux de remplissage des CDT (sances) pour cette structure
	$liste_services[$code_structure] = $ServiceEnseignementManager->getListServicesStructure($code_structure); // d'abord la liste des services d'enseignement lis  la structure
	$nb_total_jours_cours[$code_structure] = 0;
	$nb_total_seances_completees[$code_structure] = 0;
		
	foreach ($liste_services[$code_structure] as $service_value) { // calcul du taux de remplissage partiel (par service)
		$id_service = $service_value['id_service'];
		$liste_cours = $EdtCoursManager->getListCoursStructureService($id_service, $group_jour_cours = true);
		$nb_jours_cours_deroules[$code_structure][$id_service] = $EdtCoursManager->getNbJoursCoursDeroules($liste_cours); // en fait c'est le nombre de jours de cours
		$nb_total_jours_cours[$code_structure] += $nb_jours_cours_deroules[$code_structure][$id_service];
		
		// Pour avoir le nombre de sances publies, il faut connatre le ou les (en cas de co-enseignement) id_enseignant_service correspondant  l'id_service, et l'id_prof correspondant  chque service trouv
		$liste_enseignants_services = $ServiceProfesseurManager->getListServicesEnseignants($id_service);
		
		foreach ($liste_enseignants_services as $enseignant_service) {
			$id_enseignant_service = $enseignant_service['id_enseignant_service'];
			$id_prof = $enseignant_service['id_individu'];
			$nb_seances_completees[$code_structure][$id_service] += $CdtSeanceManager->getNbSeancesCompletees($id_prof,$id_enseignant_service); // on cumule les sances compltes par les diffrents profs pour le service
			$nb_total_seances_completees[$code_structure] += $nb_seances_completees[$code_structure][$id_service];
		}
		if (isset($nb_jours_cours_deroules[$code_structure][$id_service]) && $nb_jours_cours_deroules[$code_structure][$id_service] !=0)
			$taux_partiel[$code_structure][$id_service] = round(($nb_seances_completees[$code_structure][$id_service]/$nb_jours_cours_deroules[$code_structure][$id_service])*100);
		
		// la recherche suivante peut allonger la dure d'excution du script : c'est pourquoi on ne l'excute que pour l'interface dtaille (pas l'interface globale)
		if ($last_pub_visa_service) {
			// On va aussi chercher la dernire publication pour ce service
			$last_id_seances[$code_structure][$id_service] = $CdtSeanceManager->getLastSeanceServiceStructure($code_structure,$id_service);			
			// Et le dernier visa pour ce service
			$last_visas[$code_structure][$id_service] = $CdtVisamanager->getLastVisaServiceStructure($code_structure,$id_service);
		}		
	}
		
	// Taux global de remplissage des CDT
	if (isset($nb_total_jours_cours[$code_structure]) && $nb_total_jours_cours[$code_structure] !=0)
		$taux_global[$code_structure] = round(($nb_total_seances_completees[$code_structure]/$nb_total_jours_cours[$code_structure])*100);
}


function infos_visa($dernier_visa,$derniere_seance,$id_prof,$code_structure,$id_enseignant_service = null)
{
	/**
	 * Collecte des informations sur le dernier visa qui seront affiches avec les icnes de contrle adquates
	 * Utilise par toutes les vues
	 * 
	 * @param $dernier_visa : objet CdtVisa reprsentant le dernier visa
	 * @param $derniere_seance : objet CdtSeance reprsentant la dernire sance
	 * @param $id_prof : identifiant numrique du professeur concern par le visa (si fourni, $code_structure n'est pas fourni)
	 * @param $code_structure : identifiant de la structure concerne par le visa (si fourni, $id_prof n'est pas fourni)
	 * @param $id_enseignant_service : (optionnel) si fourni reprsente l'identifiant numrique du service d'un enseignant, sinon sera mis  0 pour reprsenter un visa global sur tous les services du professeur
	 * @return $infos_visa : informations  afficher + liens de contrle des visas
	 */
	
	$cible_lien = $GLOBALS['chemin_relatif']."modules/cdt/controleurs/visas_ct.php";
	$images_dir = $GLOBALS['chemin_relatif']."images/";
	
	if (isset($_GET['vue'])) { // Si le paramtre vue est prsent, il doit tre insr dans l'url cible des liens de contrle
		$param_vue = "vue=" . $_GET['vue'] . "&amp;";
		if ($_GET['vue'] == "prof") // pour une vue prof, il faut obligatoirement l'identifiant du prof dans l'URL
			$param_add_vue .= "id_prof=$id_prof&amp;";
		elseif ($_GET['vue'] == "structure")
			$param_add_vue .= "code_structure=$code_structure&amp;";
		$param_vue .= $param_add_vue;
	}
	else {
		$param_vue = ""; // Cas de l'interface globale des visas
	}
		
	if (is_null($id_enseignant_service)) { // Cas d'un visa global
		$id_enseignant_service = 0;
		$title_attr_apposer = "Apposer un Visa global (sur l'ensemble des cahiers de textes du professeur)";
	}
	else {
		$title_attr_apposer = "Apposer un Visa (sur le cahier de textes de ce service)";
	}
	
	
	if (is_object($dernier_visa)) { // Il existe un visa : on affiche sa date et les liens de contrle (supprimer, lever, rtablir, apposer un visa + rcent)
    	$fragments_datetime = explode(" ",$dernier_visa->date());
	    // Style particulier pour les visas globaux
    	if ($dernier_visa->id_enseignant_service() == 0) // C'est un visa global, on le met en vidence au surligneur
    		$visa_class = "class='visa_global"; // l'attribut class sera complt ci-dessous (au moins pour fermer le simple quote)
    	if ($dernier_visa->activation() == 0) { // Si le visa est lev temporairement, on barre le texte affichant la date d'apposition
    		if ($visa_class != "") // le style n'est pas vide : on ajoute une classe css
    			$visa_class .= " visa_inactif'";
    		else
       			$visa_class = "class='visa_inactif'";
    	}
    	elseif ($visa_class != "") { // Visa activ et style de visa global
    		$visa_class .= "'"; // on ferme la simple quote
    	}
	    // date d'apposition et autres infos : le tout est plac dans un div pour contrler l'apparence  l'affichage par css (visas.css)
		$infos_visa = "<div class='infos_visa_tab'>
		<span $visa_class>Le " . date_mysql_to_jjmmaaaa_tiret($fragments_datetime[0]) . "  " . $fragments_datetime[1]."</span><br />";
		// type de visa
		if ($dernier_visa->type() == "DIR") {
			$info_title_attr = "la Direction";
		}
		elseif ($dernier_visa->type() == "IPR") {
			$info_title_attr = "l'Inspection Pdagogique Rgionale";
		}
		$infos_visa .= "<img src='" . $images_dir . "visa_" . strtolower($dernier_visa->type()) . "t24x24.png' title=\"Visa de " . $info_title_attr . "\" alt='[Visa " . $dernier_visa->type() . "]' />";
		$infos_visa .= "<a href='" . $cible_lien . "?" . $param_vue . "action=supprimer&amp;id_visa=" . $dernier_visa->id_visa() . "'><img src='" . $images_dir . "delete.png' title='Supprimer ce Visa' alt='[Supprimer]' /></a>";
		if ($dernier_visa->activation() == 1)
			$infos_visa .= "<a href='" . $cible_lien . "?" . $param_vue . "action=lever&amp;id_visa=" . $dernier_visa->id_visa() . "'><img src='" . $images_dir . "redo.png' title='Lever temporairement ce Visa' alt='[Lever]' /></a>";
		else 
			$infos_visa .= "<a href='" . $cible_lien . "?" . $param_vue . "action=retablir&amp;id_visa=" . $dernier_visa->id_visa() . "'><img src='" . $images_dir . "restore.png' title='Rtablir ce Visa' alt='[Rtablir]' /></a>";
			// Si la date d'apposition du visa est plus ancienne que la dernire publication, proposer d'apposer un nouveau visa !
			if (is_object($derniere_seance)) {
				if ($fragments_datetime[0] < $derniere_seance->date())
					$infos_visa .= "<a href='" . $cible_lien . "?" . $param_vue . "action=apposer&amp;" . $param_add_vue . "id_enseignant_service=$id_enseignant_service&amp;code_structure=" . $derniere_seance->code_structure() . "&amp;id_groupe=" . $derniere_seance->id_groupe() . "&amp;last_id_ctexte=" . $derniere_seance->id_ctexte() . "'><img src='" . $images_dir . "add.png' title=\"$title_attr_apposer plus rcent\" alt='[Apposer]' /></a>";
			}
		$infos_visa .= "</div>";
	}
	elseif (is_object($derniere_seance)) { // Cas o il n'y a pas de visa : lien de contrle apposer uniquement
		$infos_visa .= "<a href='" . $cible_lien . "?" . $param_vue . "action=apposer&amp;" . $param_add_vue . "id_enseignant_service=$id_enseignant_service&amp;code_structure=" . $derniere_seance->code_structure() . "&amp;id_groupe=" . $derniere_seance->id_groupe() . "&amp;last_id_ctexte=" . $derniere_seance->id_ctexte() . "'><img src='" . $images_dir . "add.png' title=\"$title_attr_apposer\" alt='[Apposer]' /></a>";
	}
	return $infos_visa;
}

function infos_last_seance($derniere_seance)
{
	/**
	 * Collecte des informations sur la dernire sance de cahier de texte qui seront affiches
	 * Utilise par toutes les vues
	 * 
	 * @param $derniere_seance : objet CdtSeance reprsentant la dernire sance
	 * @return $infos_last_seance : informations  afficher
	 */
	if (is_object($derniere_seance)) {
  		$infos_last_seance = "Le " . date_mysql_to_jjmmaaaa_tiret($derniere_seance->date());
  		// Selon la vue demande, on prcise
  		if (isset($_GET['vue']) && $_GET['vue'] == "global_struct") {
  			// En vue de synthse sur les structures, il faudra afficher le nom du professeur et la matire
  			global $db;
  			$ProfesseurManager = new ProfesseurManager($db);
  			$id_prof = $derniere_seance->id_individu();
  			$infos_perso = $ProfesseurManager->get($id_prof);
  			$infos_last_seance .= "<br /><i>Par " . $infos_perso[0]['civilite'] . " " . $infos_perso[0]['prenom'] . " " . $infos_perso[0]['nom'] . "</i>";
  		}
    }
    return $infos_last_seance;
}

function progression_bar($percent)
{
	/**
	 * 
	 * Affiche la barre reprsentant le taux de remplissage du cahier de textes
	 * Utilise par toutes les vues
	 * 
	 * @param $percent : pourcentage  afficher
	 * @return $progression_bar : code HTML  afficher
	 */
	
	if (is_null($percent))
  			$percent = 0;
  	if ($percent > 50) {
  		$class = "new_progression";
  		if ($percent > 100) // cela arrive,  cause de problmes d'EDT
  			$percent = 100;
  	}
  	else 
  		$class = "progression";
	if ($percent == 0) // Dans ce cas, on ne voit rien dans la barre de progression  cause du style de la couleur de texte pour le % (blanc sur blanc)
		$progression_bar = "<span class='bar'><b>$percent %</b></span>"; // l c'est noir sur blanc : on voit le 0 %
	else // Le % est en blanc sur la couleur d'arrire plan dfinie dans la CSS
  		$progression_bar = "<span class='bar'>
				<span class='$class' style='width: $percent%'>
					<span title='$percent %' class='precent'>$percent%</span>
				</span>
			</span>";
	return $progression_bar;
}

function prepare_vue()
{
	/**
	 * Prpare les donnes  transmettre  la vue
	 * Slectionne la vue  utiliser
	 */
	
	global $db,$nomfichier,$liste_profs,$liste_structures,$infos_perso,$id_prof,$code_structure,$infos_structure;
	
	if (isset($_GET['vue']) && $_GET['vue'] == "prof") { // Interface dtail pour un professeur
		// Voici la vue du contenu qui sera affiche dans le corps de la page
		$nomfichier ="../vues/visas_prof.php";
		
		// intval renvoie la valeur numrique du paramtre ou 0 en cas d'chec
    	$id_prof = intval($_GET['id_prof']);
    	$erreur_id_prof_msg = "<br />Identifiant de professeur incorrect ! <a href='visas_ct.php'>[retour]</a>";
    	if ($id_prof != 0) {
    		// Rcupration infos perso (nom, prnom...)
    		$ProfesseurManager = new ProfesseurManager($db);
    		$infos_perso = $ProfesseurManager->get($id_prof);
    		if (empty($infos_perso)) // se produit si un id_prof dans l'url ne correspond  aucun prof existant
    		{
    			throw new Exception($erreur_id_prof_msg);
    		}
	   		// On rcupre les donnes concernant ses cahiers de textes
    		get_data_prof($id_prof,true); 
	    }
    	else {
    		throw new Exception($erreur_id_prof_msg);
    	}
	}
	elseif (isset($_GET['vue']) && $_GET['vue'] == "global_struct") { // Interface synthse structures
		if ($_SESSION['valid_group'] != "11") { // direction et admin mais pas IPR
			// On recherche toutes les structures
			$StructureManager = new StructureManager($db);
			$liste_structures = $StructureManager->getListStructures();
			// On rcupre les donnes concernant leurs cahiers de textes
			foreach ($liste_structures as $structure) { // pour chaque structure
				$code_structure = $structure['code_structure'];
				get_data_structure($code_structure);
			}
			// Voici la vue du contenu qui sera affiche dans le corps de la page
			$nomfichier ="../vues/visas_globaux_structures.php";
		}
		else {
			throw new Exception("Vous n'avez pas les droits ncessaires pour accder  cette page !");
		}
	}
	elseif (isset($_GET['vue']) && $_GET['vue'] == "structure") { // Interface dtail pour une structure
		if ($_SESSION['valid_group'] != "11") { // direction et admin mais pas IPR
			// Il faut vrifier le paramtre code_structure de l'url
			if (strlen($_GET['code_structure']) > 8) {
				throw new Exception("Le code_structure est erron !");
			}
			else {
				$code_structure = $_GET['code_structure'];
				// Infos sur la structure
				$StructureManager = new StructureManager($db);
				$StructureManager->read($code_structure); // lit les infos sur la structure
				$infos_structure = $StructureManager->variables;
				// On rcupre les donnes concernant les cahiers de textes de la structure
				get_data_structure($code_structure,true);
				// Voici la vue du contenu qui sera affiche dans le corps de la page
				$nomfichier ="../vues/visas_structure.php";
			}
		}
		else {
			throw new Exception("Vous n'avez pas les droits ncessaires pour accder  cette page !");
		}
		
	}
	else { // pas de paramtre vue (dfaut) => Interface synthse professeurs
	 
		// Voici la vue du contenu qui sera affiche dans le corps de la page
		$nomfichier ="../vues/visas_globaux.php";
	
		$ProfesseurManager = new ProfesseurManager($db);

		if ($_SESSION['valid_group'] != "11") { // direction et admin mais pas IPR
	
			// On recherche tous les professeurs
			$liste_profs = $ProfesseurManager->getList(); // renvoit un tableau
			// On rcupre les donnes concernant leurs cahiers de textes
			foreach ($liste_profs as $prof_value) { // pour chaque prof
				$id_prof = $prof_value['id_individu'];
				get_data_prof($id_prof);
			}
		}
		else { // cas des IPR
			// On recherche seulement les professeurs inspects
			foreach ($_SESSION['ipr_liste_id_individus_inspectes'] as $id_prof) {
				$prof = $ProfesseurManager->get($id_prof); // renvoit un tableau (contenant un seul lment mais qui est aussi un tableau)
				$liste_profs[] = $prof[0]; // on le range dans le tableau contenant la liste des profs
			}
			// On rcupre les donnes concernant leurs cahiers de textes
			foreach ($liste_profs as $prof_value) { // pour chaque prof
				$id_prof = $prof_value['id_individu'];
				get_data_prof($id_prof);
			}
		}
	}
}

function affiche_legende()
{
	/**
	 * Affiche une information sur la faon d'afficher les visas selon leur type (global ou de service)
	 * Utilise par toutes les vues
	 */
	$affiche_code = "<br />
	<center>
	<div class ='encadrer_justifie'>
		<b>Il existe 2 types de visa :</b>
		<ul>
			<li>Visa global : il est appos sur tous les cahiers de textes d'un enseignant (donc valable pour chaque service du professeur).
			<br />Ce type de visa apparat <span class='visa_global'>surlign en jaune</span>.</li>
			<li>Visa de service : il est appos sur un seul cahier de textes d'un enseignant (valable uniquement pour le service correspondant)</li>
		</ul>
		<b>Les visas levs temporairement</b> sont affichs <span class='visa_inactif'>en texte barr</span>.
	</div>
	</center>
	";
	return $affiche_code;
}

function addDelSuspendRestoreVisa($data_construct,$action,$id_visa = null)
{
	/**
	 * Appose, Supprime, Lve ou Rtabli un visa en utilisant un objet CdtVisaManager
	 * 
	 * @param $data_construct : donnes fournies  la construction de l'objet CdtVisaManager
	 * @param $action : action  entreprendre (apposer, supprimer, levr, rtablir)
	 * @param $id_visa : identifiant numrique du visa concern par l'action (null si action = apposer)
	 */
	
	global $db;
	$CdtVisaManager = new CdtVisaManager($db,null,$data_construct); // l'objet CdtVisaManager fourni des mthodes pour raliser l'action  entreprendre
	
	// si ce n'est pas un nouveau visa, il faut contrler l'identifiant de visa fourni
	if ($action != "apposer") {
		if (!isset($id_visa) || $id_visa == "") // normalement c'est dj contrl en amont, mais au cas o...
			throw new Exception("<br />Identifiant de visa incorrect ! <a href='visas_ct.php'>[retour]</a>");
		// on rcupre les infos du visa
		$CdtVisaManager->read($id_visa); // on a ainsi accs aux donnes du visa par la proprit "variables" = array de l'objet $CdtVisaManager
		// car on a besoin de connatre le type du visa pour contrler si on peut le supprimer, le lever ou le rtablir
		switch ($action) {
			case 'lever':
				$CdtVisaManager->leverVisa($id_visa);
				break;
			case 'retablir':
				$CdtVisaManager->retablirVisa($id_visa);
				break;
			case 'supprimer':
				$CdtVisaManager->supprimerVisa($id_visa);
				break;
		}
	}
	else { // c'est un nouveau visa  apposer
		$CdtVisaManager->apposerVisa(); // Un enregistrement est crit dans la table concerne par le manager dans la BDD
	}	
}

// Section principale du contrleur

try {
	if (isset($_GET['action'])) {
		if (isset($_GET['id_visa'])) { // si un id de visa est transmis dans l'URL, il faut le contrler
			$id_visa = intval($_GET['id_visa']);
    		if ($id_visa <= 0) {
    			throw new Exception("<br />Identifiant de visa incorrect ! <a href='visas_ct.php'>[retour]</a>");
    		}
		}
		switch ($_GET['action']) {
			
			case 'apposer':
				if ($_SESSION['valid_group'] == "1" || $_SESSION['valid_group'] == "6")
					$type = "DIR";
				elseif ($_SESSION['valid_group'] == "11")
					$type = " IPR";
				$donnees = array("id_visa" => NULL,
				"type" => $type,
				"id_pers" => intval($_SESSION['valid_id_user']),
				"date" => date('Y-m-d H:i:s'),
				"id_prof" => intval($_GET['id_prof']),
				"code_structure" => $_GET['code_structure'],
				"id_enseignant_service" => intval($_GET['id_enseignant_service']),
				"id_groupe" => intval($_GET['id_groupe']),
				"last_id_ctexte" => intval($_GET['last_id_ctexte']),
				"activation" => true);
				$CdtVisa = new CdtVisa($donnees); // cration d'un objet reprsentant un Visa, hydrat avec les donnes prcdentes (les setters auront permis de garantir l'intgrit des donnes)
				// on appose le visa
				addDelSuspendRestoreVisa($CdtVisa,'apposer',$id_visa = null);
				break;
			
			case 'supprimer':
				
				addDelSuspendRestoreVisa($CdtVisa,'supprimer',$id_visa);
				break;
			
			case 'lever':
				
				addDelSuspendRestoreVisa($CdtVisa,'lever',$id_visa);
				break;
			
			case 'retablir':
				
				addDelSuspendRestoreVisa($CdtVisa,'retablir',$id_visa);
				break;
		}
		prepare_vue(); 
	}
	else {
		prepare_vue();
	}
}
catch (Exception $e) {
  $msgErreur = $e->getMessage();
  $error_message[0] .= $msgErreur;
}

// Squelette de page utilis pour la vue
include(IEW_DIR.$GLOBALS['repertoire_theme']."imprimable.php");
?>