<?php 
/**
 * CdtSeanceManager.php
 *
 * Gestion des objets de la classe CdtSeance (CRUD et autres fonctionnalits)
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	$LastChangedRevision$, $LastChangedDate$
 * @copyright	2004-2014 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

require_once(IEW_DIR."modules/commun/modeles/classes/Crud.php");

class CdtSeanceManager extends Crud
{
	// paramtres ncessaires pour le CRUD
	protected $table = 'cahiers_textes';
	protected $pk = 'id_ctexte'; // cl primaire

	public function lastSeance($id_prof)
	{
		// trouve la dernire sance publie par le professeur (au niveau global)
		$last_seance = $this->db->query("SELECT * FROM cahiers_textes where id_individu='$id_prof' ORDER BY id_ctexte DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtSeance");
		return $last_seance; // Renvoit un objet CdtSeance
	} 
	
	public function lastSeanceStructure($code_structure)
	{
		// trouve la dernire sance publie dans un cahier de textes de la structure (au niveau global)
		$last_seance = $this->db->query("SELECT * FROM cahiers_textes where code_structure='$code_structure' ORDER BY id_ctexte DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtSeance");
		return $last_seance; // Renvoit un objet CdtSeance
	} 
	
	public function getlastSeanceService($id_prof,$id_enseignant_service)
	{
		// trouve la dernire sance publie par le professeur au niveau du service identifi par $id_enseignant_service
		$last_seance = $this->db->query("SELECT * FROM cahiers_textes as t1, services as t2, enseignants_services as t3 where t1.id_individu='$id_prof' AND t1.id_individu=t3.id_individu AND t1.code_matiere=t2.code_matiere AND t1.code_structure=t2.code_structure AND t2.id_service=t3.id_service AND t3.id_enseignant_service='$id_enseignant_service' ORDER BY id_ctexte DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtSeance");
		return $last_seance; // Renvoit un objet CdtSeance
	} 
	
	public function getLastSeanceServiceStructure($code_structure,$id_service)
	{
		// trouve la dernire sance publie par un professeur pour une structure au niveau du service identifi par $id_service
		$last_seance = $this->db->query("SELECT * FROM cahiers_textes as t1, services as t2 WHERE t1.code_structure='$code_structure' AND t1.code_structure=t2.code_structure AND t1.code_matiere=t2.code_matiere AND t2.id_service='$id_service' ORDER BY id_ctexte DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtSeance");
		return $last_seance; // Renvoit un objet CdtSeance
	}
	
	public function getNbSeancesCompletees($id_prof,$id_enseignant_service)
	{
		// Renvoie le nombre de sances remplies et publies dans un cahier de textes du prof
		$result = $this->db->query("SELECT count(id_ctexte) FROM cahiers_textes as t1, enseignants_services as t2, services as t3 where t1.id_individu='$id_prof' AND t1.id_individu=t2.id_individu AND t2.id_enseignant_service='$id_enseignant_service' AND t2.id_service=t3.id_service AND t1.code_matiere=t3.code_matiere AND t1.code_structure=t3.code_structure AND t1.publication=1");
		$nb_seance_pub = $result[0]['count(id_ctexte)'];
		return $nb_seance_pub;
	}
	
	public function getProfServiceAssoc($id_ctexte)
	{
		// Renvoie l'identifiant du professeur et l'identifiant de son service associ  la sance de cahier de textes identifie par $id_ctexte
		$result = $this->db->query("SELECT t1.id_individu,id_enseignant_service FROM cahiers_textes as t1, enseignants_services as t2, services as t3 where t1.id_ctexte='$id_ctexte' AND t1.id_individu=t2.id_individu AND t2.id_service=t3.id_service AND t1.code_matiere=t3.code_matiere AND t1.code_structure=t3.code_structure AND t1.publication=1");
		return $result;
	}
}
?>