<?php 
/**
 * CdtVisa.php
 *
 * Dfinition de la classe Visa pour reprsenter les visas des cahiers de textes
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	$LastChangedRevision$, $LastChangedDate$
 * @copyright	2004-2013 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

class CdtVisa extends Hydrator
{
	private  	$id_visa,
				$type,
				$id_pers,
				$date,
				$id_prof,
				$code_structure,
				$id_enseignant_service,
				$id_groupe,
				$last_id_ctexte,
				$activation;
	
	// Getters
	public function id_visa()
	{
		return $this->id_visa;
	}
	
	public function type()
	{
		return $this->type;
	}
	public function id_pers()
	{
		return $this->id_pers;
	}
	public function date()
	{
		return $this->date;
	}
	public function id_prof()
	{
		return $this->id_prof;
	}
	public function code_structure()
	{
		return $this->code_structure;
	}
	public function id_enseignant_service()
	{
		return $this->id_enseignant_service;
	}
	public function id_groupe()
	{
		return $this->id_groupe;
	}
	public function last_id_ctexte()
	{
		return $this->last_id_ctexte;
	}
	public function activation()
	{
		return $this->activation;
	}
	
	// Setters
	public function setId_visa($id_visa)
  	{
    	if (is_null($id_visa)) // Valeur null accepte en cas d'insertion (auto_increment) dans la BDD
    		return $this->id_visa = null;
  		if (!is_int($id_visa) || $id_visa <=0) {
    		trigger_error("Un identifiant de visa doit tre un entier positif non nul ou tre de type null !", E_USER_WARNING);
    		return;
    	}
  		$this->id_visa = $id_visa;
    }
    
	public function setType($type)
  	{
    	$type_values = array("DIR","IPR");
  		if (!in_array($type,$type_values)) {
  			trigger_error("L'attribut 'type' d'un visa doit tre 'DIR' ou 'IPR' !", E_USER_WARNING);
    		return;
  		}
  		$this->type = $type;
    }
	
	public function setId_pers($id_pers)
  	{
  		if (!is_int($id_pers) || $id_pers <=0) {
    		trigger_error("Un identifiant 'id_pers' doit tre un entier positif non nul !", E_USER_WARNING);
    		return;
    	}
  		$this->id_pers = $id_pers;
    }
    
    public function setDate($date)
  	{
    	if (!Check_DateTime($date)) {
    		trigger_error("La date doit tre dans un format DATETIME (AAAA-MM-JJ HH:MM:SS) valide !", E_USER_WARNING);
    		return;
    	}
    	$this->date = $date;
    }
    
    public function setId_prof($id_prof)
  	{
  		if (!is_int($id_prof) || $id_prof <=0) {
    		trigger_error("Un identifiant professeur doit tre un entier positif non nul !", E_USER_WARNING);
    		return;
    	}
  		$this->id_prof = $id_prof;
    }
    
    public function setCode_structure($code_structure)
  	{
    	if (!is_string($code_structure) || strlen($code_structure) > 8) {
    		trigger_error("Un code_structure doit tre une chane n'excdant pas 8 caractres !", E_USER_WARNING);
    		return;
    	}
  		$this->code_structure = $code_structure;
    }
    
	public function setId_enseignant_service($id_enseignant_service)
  	{
    	if (!is_int($id_enseignant_service) || $id_enseignant_service <0) {
    		trigger_error("Un identifiant de service d'un professeur doit tre un entier positif !", E_USER_WARNING); // La valeur zro est autorise (cas d'un visa global)
    		return;
    	}
  		$this->id_enseignant_service = $id_enseignant_service;
    }
    
    public function setId_groupe($id_groupe)
  	{
  		if (!is_int($id_groupe) || $id_groupe <0) {
    		trigger_error("Un identifiant de groupe doit tre un entier positif ou nul !", E_USER_WARNING);
    		return;
    	}
  		$this->id_groupe = $id_groupe;
    }
    
    public function setLast_id_ctexte($last_id_ctexte)
  	{
  		if (!is_int($last_id_ctexte) || $last_id_ctexte <=0) {
    		trigger_error("Un identifiant de cahier de textes doit tre un entier positif non nul !", E_USER_WARNING);
    		return;
    	}
  		$this->last_id_ctexte = $last_id_ctexte;
    }
    
	public function setActivation($activation)
  	{
  		if (!is_bool($activation)) {
    		trigger_error("L'attribut 'activation' d'un visa doit tre un boolen !", E_USER_WARNING);
    		return;
    	}
  		$this->activation = $activation;
    }

}
?>