<?php 
/**
 * CdtVisaManager.php
 *
 * Gestion des objets de la classe CdtVisa (CRUD et autres fonctionnalits)
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	$LastChangedRevision$, $LastChangedDate$
 * @copyright	2004-2013 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

require_once(IEW_DIR."modules/commun/modeles/classes/Crud.php");

class CdtVisaManager extends Crud
{
	// paramtres ncessaires pour le CRUD
	
	protected $table = 'visas_ct';
	protected $pk = 'id_visa'; // cl primaire
	
	// Mthodes en relation avec le CRUD
	
	public function apposerVisa()
	{
		/**
		 * ajoute un nouveau visa (utilise le CRUD create)
		 */
		
		$this->create();
	}
	
	public function leverVisa($id_visa)
	{
		/**
		 * modifie l'attribut activation -> 0 (= visa inactif)
		 * (utilise le CRUD update)
		 */
		
		// avant de lever le visa, il faut s'assurer que la personne qui le fait est du mme groupe que celle qui a appos le visa
		if (($this->__get("type") == "DIR" && ($_SESSION['valid_group'] == "1" || $_SESSION['valid_group'] == "6")) || ($this->__get("type") == "IPR" && $_SESSION['valid_group'] == "11")) {
			$this->__set("activation", false);
			$this->update($id_visa);	
		}
		else {
			throw new Exception("Vous n'avez pas les droits ncessaires pour lever ce visa !  <a href='visas_ct.php'>[retour]</a>");
		}
	}
	
	public function retablirVisa($id_visa)
	{
		/**
		 * modifie l'attribut activation -> 1 (= visa actif)
		 * (utilise le CRUD update)
		 */
		
		// avant de rtablir le visa, il faut s'assurer que la personne qui le fait est du mme groupe que celle qui a lev (donc aussi appos) le visa
		if (($this->__get("type") == "DIR" && ($_SESSION['valid_group'] == "1" || $_SESSION['valid_group'] == "6")) || ($this->__get("type") == "IPR" && $_SESSION['valid_group'] == "11")) {
			$this->__set("activation", true);
			$this->update($id_visa);	
		}
		else {
			throw new Exception("Vous n'avez pas les droits ncessaires pour rtablir ce visa !  <a href='visas_ct.php'>[retour]</a>");
		}
	}
	
	public function supprimerVisa($id_visa)
	{
		/**
		 * supprime le visa (utilise le CRUD delete)
		 * 
		 * @param $id_visa : identifiant numrique du visa  supprimer
		 */
		
		// avant de supprimer le visa, il faut s'assurer que la personne qui le fait est du mme groupe que celle qui a appos le visa
		if (($this->__get("type") == "DIR" && ($_SESSION['valid_group'] == "1" || $_SESSION['valid_group'] == "6")) || ($this->__get("type") == "IPR" && $_SESSION['valid_group'] == "11")) {
			$this->delete($id_visa);
		}
		else {
			throw new Exception("Vous n'avez pas les droits ncessaires pour supprimer ce visa !  <a href='visas_ct.php'>[retour]</a>");
		}
	}
	
	// Autres mthodes
	
	public function getLastVisa($id_prof) 
	{
		/**
		 * renvoie le dernier visa du cahier de texte d'un prof
		 * 
		 * @param $id_prof : identifiant numrique du professeur (id_individu)
		 * @return $last_visa : objet CdtVisa reprsentant le dernier visa trouv, null si rien trouv
		 */
		
		$last_visa = $this->db->query("SELECT * FROM visas_ct where id_prof='$id_prof' ORDER BY date DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtVisa");
		return $last_visa; // Renvoit un tableau d'objets CdtVisa (avec un seul lment)
	}
	
	public function getLastVisaStructure($code_structure)
	{
		/**
		 * renvoie le dernier visa du cahier de texte d'une structure
		 * 
		 * @param $code_structure : identifiant numrique de la structure (code_structure)
		 * @return $last_visa : objet CdtVisa reprsentant le dernier visa trouv, null si rien trouv
		 */
		
		$last_visa = $this->db->query("SELECT * FROM visas_ct where code_structure='$code_structure' ORDER BY date DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtVisa");
		return $last_visa; // Renvoit un tableau d'objets CdtVisa (avec un seul lment)
	}
	
	public function getLastVisaService($id_prof,$id_enseignant_service) 
	{
		/**
		 * renvoie le dernier visa d'un cahier de texte particulier (correspondant  un service) d'un prof
		 * 
		 * @param $id_prof : identifiant numrique du professeur (id_individu)
		 * @param $id_enseignant_service :  identifiant numrique d'un des services du professeur
		 * @return $last_visa : tableau d'objets CdtVisa (avec un seul lment : le visa recherch) ou tableau vide (si pas de visa trouv)
		 */
		
		$last_visa = $this->db->query("SELECT * FROM visas_ct where id_prof='$id_prof' AND id_enseignant_service='$id_enseignant_service' ORDER BY date DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtVisa");
		return $last_visa; // Renvoit un tableau d'objets CdtVisa (avec un seul lment)
	}
	
	public function getLastVisaServiceStructure($code_structure,$id_service)
	{
		/**
		 * renvoie le dernier visa d'un cahier de texte particulier (correspondant  un service) d'une structure
		 * 
		 * @param $code_structure : identifiant de la structure
		 * @param $id_service :  identifiant numrique d'un des services de la structure
		 * @return $last_visa : tableau d'objets CdtVisa (avec un seul lment : le visa recherch) ou tableau vide (si pas de visa trouv)
		 */
		
		$last_visa = $this->db->query("SELECT id_visa,t1.type,id_pers,date,id_prof,t1.code_structure,t1.id_enseignant_service,id_groupe,last_id_ctexte,activation FROM visas_ct as t1, services as t2, enseignants_services as t3 WHERE t1.code_structure='$code_structure' AND t1.id_enseignant_service=t3.id_enseignant_service AND t2.id_service=t3.id_service AND t2.id_service='$id_service' ORDER BY date DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtVisa");
		return $last_visa; // Renvoit un tableau d'objets CdtVisa (avec un seul lment)
	}
		
	public function getLastVisaGlobal($id_prof)
	{
		/**
		 * renvoie le dernier visa global pour un professeur
		 * 
		 * @param $id_prof : identifiant numrique du professeur (id_individu)
		 * @return $last_visa : tableau d'objets CdtVisa (avec un seul lment : le visa recherch) ou tableau vide (si pas de visa trouv)
		 */
		
		$last_visa = $this->db->query("SELECT * FROM visas_ct where id_prof='$id_prof' AND id_enseignant_service=0 ORDER BY date DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtVisa");
		return $last_visa; // Renvoit un tableau d'objets CdtVisa (avec un seul lment)
	}
	
	public function getLastVisaGlobalStructure($code_structure)
	{
		/**
		 * renvoie le dernier visa global pour une structure
		 * 
		 * @param $code_structure : identifiant de la structure
		 * @return $last_visa : tableau d'objets CdtVisa (avec un seul lment : le visa recherch) ou tableau vide (si pas de visa trouv)
		 */
		
		$last_visa = $this->db->query("SELECT * FROM visas_ct where code_structure='$code_structure' AND id_enseignant_service=0 ORDER BY date DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtVisa");
		return $last_visa; // Renvoit un tableau d'objets CdtVisa (avec un seul lment)
	}
	
	public function getVisaSeance($id_prof,$id_enseignant_service,$date_seance)
	{
		/**
		 *  Trouve le visa actif le + rcent associ au service de professeur
		 *  
		 *  @param $id_prof : identifiant numrique du professeur (id_individu)
		 *  @param $id_enseignant_service :  identifiant numrique du service d'un professeur. S'il vaut 0, un visa global est recherch
		 *  @param $date_seance : date de la sance publie sur laquelle on recherche un visa actif
		 *  
		 *  @return $visa : tableau d'objets CdtVisa (avec un seul lment : le visa recherch) ou tableau vide (si pas de visa trouv)
		 */
		
		// DEBUGG $sql = "SELECT * FROM visas_ct WHERE id_prof='$id_prof' AND id_enseignant_service='$id_enseignant_service' AND activation=true AND DATE(date)>'$date_seance' ORDER BY date DESC LIMIT 1";
		// DEBUGG var_dump($sql);
		// le visa doit tre + rcent que la sance
		$visa = $this->db->query("SELECT * FROM visas_ct WHERE id_prof='$id_prof' AND id_enseignant_service='$id_enseignant_service' AND activation=true AND DATE(date)>'$date_seance' ORDER BY date DESC LIMIT 1",null,PDO::FETCH_CLASS,"CdtVisa");
		return $visa; // Renvoit un tableau d'objets CdtVisa (avec un seul lment)
	}
	
	public function chercheVisaSeance($id_ctexte)
	{
		/**
		 * Recherche s'il existe un visa actif sur une sance de cahier de textes
		 * Si oui, renvoie le visa pour affichage
		 * 
		 * @param $id_ctexte : identifiant numrique de la sance de cahier de textes
		 * @return $visa : objet CdtVisa ou null (si pas de visa trouv) 
		 */
		
		$CdtSeanceManager = new CdtSeanceManager($this->db);
		$CdtSeanceManager->read($id_ctexte);
		$date_seance = $CdtSeanceManager->variables['date'];
		// DEBUGG var_dump($date_seance);
		
		// On rcupre l'id_individu et l'id_enseignant_service associs  la sance
		$prof_service = $CdtSeanceManager->getProfServiceAssoc($id_ctexte);
		
		// Si on a rcupr ces infos (ne sont pas rcupres si la sance n'est pas publie : dans ce cas, inutile de chercher un visa !)
		if (!empty($prof_service)) {
			$id_prof = $prof_service[0]['id_individu'];
			$id_enseignant_service = $prof_service[0]['id_enseignant_service'];
		
			// On cherche s'il existe un visa pour ce service (le + rcent possible) : le visa de service a priorit sur un visa global
			$visa_service = $this->getVisaSeance($id_prof,$id_enseignant_service,$date_seance);
			// DEBUGG var_dump($visa_service);
			if (is_object($visa_service[0]))
				return $visa_service[0];
			else { // pas de visa pour ce service : on cherche un visa global pour le prof
				$visa_global = $this->getVisaSeance($id_prof,0,$date_seance);
				if (is_object($visa_global[0])) // si on en a un, on le retourne
					return $visa_global[0];
			}
		}
	}
	
	public function afficheTamponVisa($id_ctexte,$icon_size = "large")
	{
		/**
		 * Affiche le tampon correspondant s'il existe un visa actif sur une sance de cahier de textes
		 * 
		 * @param $id_ctexte : identifiant numrique de la sance de cahier de textes
		 * @param $icon_size : taille du tampon (large - valeur par dfaut -, medium, small)
		 * @return $code_affichage_visa : code HTML contenant la balise img adquate 
		 */
		
		$code_affichage_visa = "";
		switch ($icon_size) {
			case 'medium':
				$size = "32x32";
				break;
			case 'small':
				$size = "24x24";
				break;
			default:  // large
				$size = ""; 
		}
		
		// Affichage du visa ventuel (DIR ou IPR : le plus rcent) : uniquement si la sance est dj renseigne
    	if ($id_ctexte != "") {
        	$visa = $this->chercheVisaSeance($id_ctexte);
        	if (is_object($visa)) {
        		$split_date = explode(" ",$visa->date());
        		$visa_date = date_mysql_to_jjmmaaaa_tiret($split_date[0]);
        		$visa_time = $split_date[1];
        		if ($visa->type() == "DIR")
        			$code_affichage_visa .= "<img style='margin:0.5em 0.5em;' src='".$GLOBALS['chemin_relatif']."images/visa_dirt$size.png' title='Dernier Visa de la direction le $visa_date  $visa_time' alt='[Visa]' />";
        		elseif ($visa->type() == "IPR")
        			$code_affichage_visa .= "<img style='margin:0.5em 0.5em;' src='".$GLOBALS['chemin_relatif']."images/visa_iprt$size.png' title='Dernier Visa IPR le $visa_date  $visa_time' alt='[Visa]' />";
        	}
        }
        return $code_affichage_visa;
	}
}
?>