<?php 
/**
 * Crud.php
 * 
 * Dfinition de la classe Crud pour la gestion centralise des requtes CRUD
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	$LastChangedRevision$, $LastChangedDate$
 * @copyright	2004-2014 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 * Il s'agit du'ne adaptation du code original de la classe Easy Crud  -  This class kinda works like ORM. Just created for fun :)
 * Author: Vivek Wicky Aswal. (https://twitter.com/#!/VivekWickyAswal)
 * original version : 0.1a 
 *	
*/

abstract class Crud {

	// stocke l'objet reprsentant la connexion  la Base de Donnes, initie dans librairie_fonctions.php
	protected $db; // protected pour tre accessible depuis les Managers hritant de la classe Crud

	protected $objet; // contiendra un objet hydrat pour le binding avec les requtes CRUD
	
	public $variables; // contiendra un tableau associatif (attribut=>valeur) pour le binding avec les requtes CRUD

	public function __construct($db,$data_array = array(),$data_object = null)
	{	// l'objet reprsentant la connexion  la Base de Donnes est pass en argument et ventuellement un tableau de donnes (attribut=>valeur)
		// ou un objet (mais pas les 2 en mme temps)
		// Le fait de pouvoir passer un objet permet de garantir que les valeurs sont intgres (puisque la valeur est contrle par un setter centralis dans la classe de l'objet)
		// Ce n'est pas le cas avec un tableau de donnes (attribut=>valeur) o il faut contrler les valeurs avant de passer le tableau en argument
		$this->setDb($db); // le constructeur va passer  l'instance l'objet reprsentant la connexion  la Base de Donnes
		if (!is_null($data_array) && !is_null($data_object)) { // on a fourni en mme temps un tableau de donnes et un objet au constructeur
			trigger_error("Un tableau et un objet ne peuvent pas tre simultanments utilis pour crer un objet Crud !", E_USER_WARNING);
    		return;
		}
		// objet ou array, de toutes faons il faudra un tableau associatif (attribut=>valeur) pour le binding avec les requtes CRUD => C'est $this->variables
		if (is_object($data_object)) { // dans le cas d'un objet pass au constructeur
			$this->objet = $data_object;
			$this->getListeProprietesToArray($data_object);	 // les proprits (et leur valeur) de l'objet sont passes dans le tableau $this->variables
		}
		else { // dans le cas d'un array pass au constructeur
			$this->variables  = $data_array;
		}
	}

	// setters
	
	public function setDb(DB $db)
  	{
	    $this->db = $db;
  	}
	
	// setter magique : la classe CRUD est une superclasse, c pas l qu'on dclarera des setters pour un attribut particulier
	public function __set($name,$value){
		if(strtolower($name) === $this->pk) {
			$this->variables[$this->pk] = $value;
		}
		else {
			$this->variables[$name] = $value;
		}
	}

	// getters : la classe CRUD est une superclasse, c pas l qu'on dclarera des getters pour un attribut particulier
	
	// getter magique
	public function __get($name)
	{	
		if(is_array($this->variables)) {
			if(array_key_exists($name,$this->variables)) {
				return $this->variables[$name];
			}
		}

		$trace = debug_backtrace();
		trigger_error(
		'Undefined property via __get(): ' . $name .
		' in ' . $trace[0]['file'] .
		' on line ' . $trace[0]['line'],
		E_USER_NOTICE);
		return null;
	}

	public function getListeProprietesToArray($data_object)
	{
		// Cette mthode recopie dans le tableau $this->variables les proprits (et leur valeur) de l'objet pass en paramtre au constructeur
		// Cela permet de fournir un tableau $this->variables fonctionnel sans avoir besoin de modifier davantage le code d'origine de la classe
		$reflect = new ReflectionClass($data_object);
		$props = $reflect->getProperties();
		foreach ($props as $prop) {
    		$key = $prop->getName();
			$this->variables[$key] = $data_object->$key();
		}
	}
	
	public function update($id = "0") {
		$this->variables[$this->pk] = (empty($this->variables[$this->pk])) ? $id : $this->variables[$this->pk];

		$fieldsvals = '';
		$columns = array_keys($this->variables);

		foreach($columns as $column)
		{
			if($column !== $this->pk)
			$fieldsvals .= $column . " = :". $column . ",";
		}

		$fieldsvals = substr_replace($fieldsvals , '', -1);

		if(count($columns) > 1 ) {
			$sql = "UPDATE " . $this->table .  " SET " . $fieldsvals . " WHERE " . $this->pk . "= :" . $this->pk;
			return $this->db->query($sql,$this->variables);
		}
	}

	public function create() { 
		$bindings   	= $this->variables;

		if(!empty($bindings)) {
			$fields     =  array_keys($bindings);
			$fieldsvals =  array(implode(",",$fields),":" . implode(",:",$fields));
			$sql 		= "INSERT INTO ".$this->table." (".$fieldsvals[0].") VALUES (".$fieldsvals[1].")";
		}
		else {
			$sql 		= "INSERT INTO ".$this->table." () VALUES ()";
		}

		return $this->db->query($sql,$bindings);
	}

	public function delete($id = "") {
		$id = (empty($this->variables[$this->pk])) ? $id : $this->variables[$this->pk];

		if(!empty($id)) {
			$sql = "DELETE FROM " . $this->table . " WHERE " . $this->pk . "= :" . $this->pk. " LIMIT 1" ;
			return $this->db->query($sql,array($this->pk=>$id));
		}
	}

	public function read($id = "") {
		$id = (empty($this->variables[$this->pk])) ? $id : $this->variables[$this->pk];

		if(!empty($id)) {
			$sql = "SELECT * FROM " . $this->table ." WHERE " . $this->pk . "= :" . $this->pk . " LIMIT 1";	
			$this->variables = $this->db->row($sql,array($this->pk=>$id));
		}
	}

	public function all(){
		return $this->db->query("SELECT * FROM " . $this->table);
	}
	
	public function min($field)  {
		if($field)
		return $this->db->single("SELECT min(" . $field . ")" . " FROM " . $this->table);
	}

	public function max($field)  {
		if($field)
		return $this->db->single("SELECT max(" . $field . ")" . " FROM " . $this->table);
	}

	public function avg($field)  {
		if($field)
		return $this->db->single("SELECT avg(" . $field . ")" . " FROM " . $this->table);
	}

	public function sum($field)  {
		if($field)
		return $this->db->single("SELECT sum(" . $field . ")" . " FROM " . $this->table);
	}

	public function count($field)  {
		if($field)
		return $this->db->single("SELECT count(" . $field . ")" . " FROM " . $this->table);
	}	
	
}
?>