<?php 
/**
 * EdtCoursManager.php
 *
 * Gestion des objets de la classe EdtCoursManager (CRUD et autres fonctionnalits)
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	$LastChangedRevision$, $LastChangedDate$
 * @copyright	2004-2014 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

require_once(IEW_DIR."modules/commun/modeles/classes/Crud.php");

class EdtCoursManager extends Crud
{
	// paramtres ncessaires pour le CRUD
	protected $table = 'cours';
	protected $pk = 'id_cours'; // cl primaire

	public function getListCoursEnseignantService($id_enseignant_service, $group_jour_cours = false)
	{
		/**
		 * Renvoie la liste des cours correspondant  un service enseignant (effectu par UN professeur)
		 * 
		 * @param $id_enseignant_service : identifiant numrique du service d'enseignement assur par le professeur
		 * @param $group_jour_cours : (optionnel) si vaut true, plusieurs heures de cours pour le mme service dans la mme journe et pour la mme alternance seront considrs comme un seul cours
		 * @return $liste_cours : liste des cours trouvs
		 */
		
		if ($group_jour_cours)
			$where_add = " GROUP BY code_jour ";
		else 
			$where_add = " ";
		$liste_cours = $this->db->query("SELECT * FROM cours WHERE id_enseignant_service='$id_enseignant_service'" . $where_add . "ORDER BY code_alternance,code_jour");
		return $liste_cours;
	}
	
	public function getListCoursStructureService($id_service, $group_jour_cours = false)
	{
		/**
		 * Renvoie la liste des cours correspondant  un service pour une structure
		 * 
		 * @param $id_service : identifiant numrique du service correspondant  une matire enseigne dans la structure
		 * @param $group_jour_cours : (optionnel) si vaut true, plusieurs heures de cours pour le mme service dans la mme journe et pour la mme alternance seront considrs comme un seul cours
		 * @return $liste_cours : liste des cours trouvs
		 */
		
		// d'abord, on rcupre les services des enseignants correspondant  ce service pour la structure
		$ServiceProfesseurManager = new ServiceProfesseurManager($this->db);
		$liste_enseignants_services = $ServiceProfesseurManager->getListServicesEnseignants($id_service);
		
		// on recherche les cours correspondants
		$liste_cours = array();
		foreach ($liste_enseignants_services as $enseignant_service) {
			$id_enseignant_service = $enseignant_service['id_enseignant_service'];
			$liste_cours = array_merge($liste_cours,$this->getListCoursEnseignantService($id_enseignant_service, $group_jour_cours));		
		}
		return $liste_cours;
	}
	
	public function getListCoursService($id_service, $group_jour_cours = false)
	{
		/**
		 * Renvoie la liste des cours correspondant  un service (=matire) pour une structure (effectu par UN OU PLUSIEURS professeur(s))
		 * 
		 * @param $id_service : identifiant numrique du service d'enseignement pour la matire
		 * @param $group_jour_cours : (optionnel) si vaut true, plusieurs heures de cours pour le mme service dans la mme journe et pour la mme alternance seront considrs comme un seul cours
		 * @return $liste_cours : liste des cours trouvs
		 */
		
		// Il faut d'abord la liste des enseignants_services correspondant  ce service
		$ServiceProfesseurManager = new ServiceProfesseurManager($this->db); 
		$liste_enseignants_services = $ServiceProfesseurManager->getListServicesEnseignants($id_service);
		
		// On va rcuprer la liste des cours correspondants
		$liste_cours = array();
		foreach ($liste_enseignants_services as $enseignant_service) {
			$id_enseignant_service = $enseignant_service['id_enseignant_service'];
			$liste_cours = array_merge($liste_cours,$this->getListCoursEnseignantService($id_enseignant_service, $group_jour_cours));
		}
		return $liste_cours;
	}
		
	public function getNbJoursCoursDeroules($liste_cours)
	{
		/**
		 * Renvoie le nombre de jours de cours couls pour un service d'enseignement depuis le dbut de l'anne scolaire jusqu' aujourd'hui
		 * 
		 * @param $liste_cours : tableau contenant la liste de cours correspondants au service
		 * @return $nb_cours_deroules : nombre de jours de cours ayant dj eu lieu pour ce service
		 */
				
		// On rcupre le nombre de jours de la semaine couls depuis la rentre
		if (!isset($_SESSION['nb_jours_ouvrables_ecoules']))
		{
			$nb_jours_ouvrables_ecoules = getNbJoursSemaineEcoules();
			$_SESSION['nb_jours_ouvrables_ecoules'] = $nb_jours_ouvrables_ecoules;
		}
		else 
			$nb_jours_ouvrables_ecoules = $_SESSION['nb_jours_ouvrables_ecoules'];
			
		$nb_cours_deroules = 0;
		
		foreach ($liste_cours as $value) { // un cours = un jour (compte tenu du GROUP BY dans la requte SQL de la mthode getListCoursEnseignantService() et du mode de fonctionnement des sances de cahier de textes : une sance = une journe, quelque soit le nombre de cours pour ce service dans la journe)
			// nombre de fois o s'est droul ce cours depuis la rentre
			$nb_cours_deroules_tab[$value['code_jour']] = $nb_jours_ouvrables_ecoules[$value['code_jour']];
			switch ($value['code_alternance']) {
				case "H":
					$nb_cours_deroules += $nb_cours_deroules_tab[$value['code_jour']]["Q1"] + $nb_cours_deroules_tab[$value['code_jour']]["Q2"];
					break;
				case "Q1":
					$nb_cours_deroules += $nb_cours_deroules_tab[$value['code_jour']]["Q1"];
					break;
				case "Q2":
					$nb_cours_deroules += $nb_cours_deroules_tab[$value['code_jour']]["Q2"];
					break;
			}
		}
		return $nb_cours_deroules;	// correspond au nombre de jours de cours drouls pour ce service
	}
}
?>