<?php
/**
 * c_upload_imports.php
 *
 * Ralise le tlchargement des fichiers XML de gestion administrative (sconet, sts)
 * 
 * Ce script s'xcute dans un iframe non affich
 * Les fichiers sont rcuprs du formulaire c_form_imports.php
 * Ils subissent des vrifications (de type, de taille, de scurit, de contenu)
 * et sont ensuite copis temporairement dans le dossier /data/importation
 * 
 *  La liste des fichiers tlchargs est conserve dans une variable de session 
 *  pour suppression ultrieure, aprs leur traitement
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package		IEW
 * @author			Sylvain GODM <sylvain.godme@gmail.com>
 * @version		$LastChangedRevision$, $LastChangedDate$
 * @copyright		2004-2012 Sylvain GODM
 * @link			http://iew.free.fr
 * @license		GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

if (!defined('IEW_DIR')) {
 	/**
 	 * Constante contenant le chemin complet du rpertoire d'installation IEW
 	 */	
	define('IEW_DIR',realpath(dirname(__FILE__).'/../../../').'/');
}

/**
 * On inclut la librairie complte des fonctions et les fichiers de config, et on dmarre la session PHP
 */
require_once(IEW_DIR."librairie_fonctions.php"); 


function test_upload_file($file,$key)
{
	/*
	 * Vrifie que le tlchargement d'un fichier xml ou zip par formulaire est valide et scure
	 * Si c'est un zip, dcompresse le fichier et supprime le zip original
	 *
	 * @param	$file : tableau associatif contenant les caractristiques du fichier tlcharg (nom, type, taille)
	 * @param	$key : cl courante du tableau $file (contient le nom du champ input du formulaire d'upload)
	 * @return	$err, vide si aucune erreur, renseign selon l'erreur sinon
	 */
	
	$err = "";
	// On vrifie si le nom est correct (sauf pour sts_emp et EDT_vers_STS dont les noms ne sont pas connus  l'avance car il contiennent une date)
	if ($key.".xml" != $file['name'] && "ExportXML_".$key.".zip" != $file['name'] && $key != "EDT_vers_STS_RNE_annee" && $key != "sts_emp_RNE_annee")
	{
		$err .= "Un fichier fourni n'a pas un nom correct : <b>".$file['name']."</b> au lieu de <b>$key.xml</b> ou <b>$key.zip</b>. Vrifiez le nom du fichier fourni pour le champ <b>$key.xml/zip</b>.<br />";
	}
	if ($file['size']==0)
	{
		$err .= "Le fichier ".$file['name']." tlcharg ne contient aucune donne. Vrifiez le nom du fichier et son contenu<br />";
		return $err;  	
	}
    if (!is_uploaded_file($file['tmp_name'])) // pour la scurit
    {
    	$err .= "Attention, le fichier ".$file['name']."  traiter est un fichier local du serveur est n'a pas t tlcharg  partir du client. Le script est interrompu pour des raisons de scurit.<br />";
    	return $err;
    }
   	// on vrifie maintenant le type xml
	if (!strstr($file['type'], 'text/xml') && !strstr($file['type'], 'application/zip') && !strstr($file['type'], 'application/x-zip-compressed')) 
	{
		$err .= "Attention, le fichier ".$file['name']."  traiter n'est pas un fichier xml ou zip ! Vrifiez l'extension du fichier et son contenu<br />";
		return $err;
	}
	// On copie le nouveau fichier sur le serveur dans le rpertoire de stockage avant son traitement
	if ( !move_uploaded_file($file['tmp_name'], $GLOBALS['stock_baselev']."importation/".$file['name']))
	{
		$err .= "Le fichier ".$file['name']." tlcharg n'a pas pu tre copi dans le dossier cible sur le serveur<br />";
		return $err;
    }
    elseif(strstr($file['type'], 'application/zip') || strstr($file['type'], 'application/x-zip-compressed'))  // Si c'est un zip, il faut le dcompresser
    {
   		$cmd = "unzip -o ".$GLOBALS['stock_baselev']."importation/".$file['name']." -d ".$GLOBALS['stock_baselev']."importation/"; // (option -o pour craser un fichier existant)
	    // on xcute la commande
    	// suivant le rsultat, on affiche un message
    	exec($cmd,$output,$retval);
    	if (isset($retval) && $retval == 0) // commande bien xcute (sur un serveur LINUX)
    	{
      		unlink($GLOBALS['stock_baselev']."importation/".$file['name']);// On peut supprimer le zip
    	}
    	else // la commande n'est pas disponible
    		$err .= "Attention, le fichier ".$file['name']." n'a pas pu tre dcompress !<br />";
      		
    }
    return $err; // pas d'erreur
}

// Evite un accs direct par l'appel de ce script directement dans l'url, genre http://racine_IEW/prive/admin/prive/c_upload_imports.php
// si le paramtre url 'validation' est dfini sur 'ajax', le script s'excutera sans contrle (peu de chance que l'utilisateur le sache...)
if (!isset($_GET['validation']) || $_GET['validation'] == "php") // cela signifie que javascript n'est pas activ si == php 
{
	// Le script en cours doit tre le script d'appel prvu (permet de s'assurer que les droits d'accs sont ok)
	if (!end_with_string($_SERVER['PHP_SELF'],"prive/admin/prive/upload_imports.php"))
	{
		$error_message = array("Vous tentez d'accder  un script qui n'est pas accessible directement  partir de l'URL... Utilisez les liens de navigation en <a href='".$GLOBALS['racine']."'>retournant  l'accueil</a> !","");
  		affiche_erreurs($error_message);
  		return; // fin du script
	}	
}

$error = NULL;

// On inclut le code du parser XML (XMLParser) : http://www.criticaldevelopment.net/xml/doc.php
	// Ceci fonctionne aussi bien en php4 qu'en php5 (simule les fonctions SimpleXML de php5 => Parsing d'un document XML vers un objet php)
	// Suivant la version de php, le code  inclure n'est pas le mme
	if (version_compare(phpversion(), "5.0.0", ">="))
    {
      // La version php installe est une version 5
      include(IEW_DIR."/lib/parser_php5.php");
    }
    else // La version PHP est une version 4
    {
      include(IEW_DIR."/lib/parser_php4.php");
    } 

// on vrifie que le dossier "importation" est cr, sinon on le cre
  		if (!file_exists($GLOBALS['stock_baselev']."importation"))
  		{
  			mkdir($GLOBALS['stock_baselev']."importation",0755);
  		}
		
		$tab_delfile = array(); // tableau destin  recevoir le nom des fichiers tlchargs et copis temporairement dans le rpertoire data : ces fichiers seront supprimsen fin de script
		// Contrle sur les fichiers du formulaire d'upload
		
		switch ($_GET['type'])
		{
			case "adm":
				foreach($_FILES as $file)
				{	
		  			// DEBUGG print "Le fichier d'upload  contrler est <strong>".$file['name']."</strong>";

					// Cas particulier du fichier EDT qui est facultatif
					if (key($_FILES) == "EDT_vers_STS_RNE_annee")
					{
						// on vrifie le tlchargement seulement s'il est fourni
						if (isset($file['tmp_name']) && $file['tmp_name'] != "")
						{
							$err = test_upload_file($file,key($_FILES));
							if ($err != "") // il y une erreur
							{
								$error .= $err."<br/>";
							}
							else // Si a marche on garde en mmoire le nom du fichier qu'il faudra supprimer  la fin de l'import 
    						{
	    						$tab_delfile[] = $file['name'];
    						}
						}
					}			
					elseif (!isset($file['tmp_name']) || $file['tmp_name'] == "") // Les autres fichiers par contre sont requis
    				{
      					$error .= "Le tlchargement du fichier <strong>".key($_FILES).".xml</strong> n'a pas pu s'effectuer. Vrifiez le contenu du champ de formulaire correspondant.<br/>";      			
		    		}
					else // si le fichier est fourni on vrifie le tlchargement
					{	
						$err = test_upload_file($file,key($_FILES));
						if ($err != "") // il y une erreur
						{
							$error .= $err;
						}
						else // Si a marche on garde en mmoire le nom du fichier qu'il faudra supprimer  la fin de l'import 
    					{
    						if (substr($file['name'],0,10) == "ExportXML_") // Si c'est zip qui a t tlcharg
							{
								$fragments = explode(".",$file['name']);
								$name_file = $fragments[0].".xml";
								$tab_delfile[] = substr($name_file,10,strlen($name_file)-9); // ce sera le fichier dcompress qui sera pris en compte	
							}
    						else 
    							$tab_delfile[] = $file['name'];
		    				// et on vrifie le contenu du fichier
    						if ($file['name'] == "Communs.xml" || $file['name'] == "ExportXML_Communs.zip")
    						{
    							$test_verif = verif_xmlfile("Communs.xml","bee_commun");
								if (is_array($test_verif)) // En cas d'erreur, un tableau $error_message est retourn
								{
									$error .= $test_verif[0]."<br/>";
								}
    						}
    						elseif ($file['name'] == "Nomenclature.xml" || $file['name'] == "ExportXML_Nomenclature.zip")
    						{
    							$test_verif = verif_xmlfile("Nomenclature.xml","bee_nomenclatures");
								if (is_array($test_verif)) // En cas d'erreur, un tableau $error_message est retourn
								{
									$error .= $test_verif[0]."<br/>";
								}
    						}
    						elseif ($file['name'] == "Structures.xml" || $file['name'] == "ExportXML_Structures.zip")
    						{
    							$test_verif = verif_xmlfile("Structures.xml","bee_structures");
								if (is_array($test_verif)) // En cas d'erreur, un tableau $error_message est retourn
								{
									$error .= $test_verif[0]."<br/>";
								}
    						}
    						elseif (substr($file['name'],0,7) == "sts_emp")
           					{
           		   				$test_verif = verif_xmlfile($file['name'],"sts_edt");
								if (is_array($test_verif)) // En cas d'erreur, un tableau $error_message est retourn
								{
									$error .= $test_verif[0]."<br/>";
								}
    						}
    						elseif (substr($file['name'],0,12) == "EDT_vers_STS")
           					{
           		   				$test_verif = verif_xmlfile($file['name'],"edt_sts");
								if (is_array($test_verif)) // En cas d'erreur, un tableau $error_message est retourn
								{
									$error .= $test_verif[0]."<br/>";
								}
    						}
		    				
    					}
					}
					next($_FILES);							
				}
				break;
				
			case "elev":
				foreach($_FILES as $file)
				{
					if (!isset($file['tmp_name']) || $file['tmp_name'] == "") // Les autres fichiers par contre sont requis
    				{
      					$error .= "Le tlchargement du fichier <strong>".key($_FILES).".xml</strong> n'a pas pu s'effectuer. Vrifiez le contenu du champ de formulaire correspondant.<br/>";      			
		    		}
		    		else 
		    		{
		    			$err = test_upload_file($file,key($_FILES));
						if ($err != "") // il y une erreur
						{
							$error .= $err;
						}
						else 
						{
							if (substr($file['name'],0,10) == "ExportXML_") // Si c'est zip qui a t tlcharg
							{
								$fragments = explode(".",$file['name']);
								$name_file = $fragments[0].".xml";
								$tab_delfile[] = substr($name_file,10,strlen($name_file)-9); // ce sera le fichier dcompress qui sera pris en compte	
							}
    						else 
    							$tab_delfile[] = $file['name'];// et on vrifie le contenu du fichier
    						if ($file['name'] == "ElevesAvecAdresses.xml" || $file['name'] == "ExportXML_ElevesAvecAdresses.zip")
    						{
    							$test_verif = verif_xmlfile("ElevesAvecAdresses.xml","bee_eleves");
								if (is_array($test_verif)) // En cas d'erreur, un tableau $error_message est retourn
								{
									$error .= $test_verif[0]."<br/>";
								}
    						}
    						elseif ($file['name'] == "ResponsablesAvecAdresses.xml" || $file['name'] == "ExportXML_ResponsablesAvecAdresses.zip")
    						{
    							$test_verif = verif_xmlfile("ResponsablesAvecAdresses.xml","bee_responsables");
								if (is_array($test_verif)) // En cas d'erreur, un tableau $error_message est retourn
								{
									$error .= $test_verif[0]."<br/>";
								}
    						}
						}
		    		}
		    		next($_FILES);
				}
				break;
			default:
				$error .= "Les paramtres dans l'url ont t modifis et ne sont pas ceux attendus !";
		}


		$_SESSION['tab_delfile'] = $tab_delfile; // sera accessible pour c_do_imports.php
		if (is_null($error) || $error == "") // si pas d'erreur
			$error = "OK"; // l'upload aura t un succs (voir upload_files_imports.js)
		
		// paramtre par dfaut 'validation' dans l'url  la soumission du formulaire
		// vaut 'php' par dfaut si javascript dsactiv (dgradation lgante) et 'ajax' si javascript activ (amlioration progressive)
		// sa valeur est modifie dans upload_files_imports.js dans la fonction uploadRun()
		if (isset($_GET['validation']) && $_GET['validation'] == "php") // cela signifie que javascript n'est pas activ 
		{
			if ($error != "OK")
			{
				$error .= "<p><a href='imports.php?type=".$_GET['type']."'>Rafficher le formulaire de tlchargement</a></p>";
				affiche_erreurs(array($error,""));
			}
			else
			{
				$ok_message = "Les fichiers ont bien t tlchargs ! <a href='do_imports_".$_GET['type'].".php' id='lanceur_import'>Lancer l'importation des donnes</a>";
				affiche_ok($ok_message);
			}
		}
?>
 
<script type="text/javascript">
<!-- 
        window.parent.window.uploadEnd("<?php echo $error; ?>");
//-->
</script>