<?php 
/**
 * c_ct_day.php
 *
 * Affiche le cahier de textes (entres publies) du jour d'un prof ou d'une classe
 * 
 * Ce fichier fait partie du projet IntraEduWeb (IEW)
 * 
 * @package	IEW
 * @author	Sylvain GODM <sylvain.godme@gmail.com>
 * @version	$LastChangedRevision$, $LastChangedDate$
 * @copyright	2004-2013 Sylvain GODM
 * @link	http://iew.free.fr
 * @license	GPL License version 3 (http://www.gnu.org/licenses/gpl.html)
 * @filesource
 * 
 */

function traite_titraille_ct_day($chaine_html) 
{
	/**
	 * Afin de garder une cohrence dans la hirarchie des titres
	 * dans les contenus de sance et travaux  faire, on cherche les balises de titres h1, h2 etc
	 * et on les descend de 3 niveaux (on peut ensuite vrifier avec le plugin headings map pour firefox
	 * que la hirarchie des tires est respecte.
	 * 
	 * Nanmoins, les balises de titre ayant chang, afin de ne pas modifier la mise en forme initiale
	 * le style d'origine est appliqu (par ex h4 class='like_h1' a les mmes proprits CSS que h1)
	 * 
	 * @param $chaine_html : code html  traiter
	 * @return $chaine : code html avec les remplacements effectus
	 */
	
	// h1 remplac par h4, h2 par h5, h3 par h6, h4 par h6 (on ne peut pas dcendre + bas que h6, cela signifie qu'il faut se limiter dans les entres de chaier de textes  trois niveaux de titres...), 
	$search_opened  = array("#<h5>#","#<h4>#","#<h3>#","#<h2>#","#<h1>#"); // h6 sera laiss tel quel
	$replace_opened  = array("<h6>","<h6>","<h6 class='like_h3'>","<h5 class='like_h2'>","<h4 class='like_h1'>"); // on formatera l'affichage comme les titres d'origine (pour les 3 premiers niveaux)
	$search_closed  = array("#</h5>#", "#</h4>#","#</h3>#", "#</h2>#", "#</h1>#");
	$replace_closed  = array("</h6>","</h6>","</h6>","</h5>","</h4>");
	$chaine = preg_replace($search_opened,$replace_opened,$chaine_html);
	$chaine = preg_replace($search_closed,$replace_closed,$chaine);
	return $chaine;
}

function display_date_prev_next($date)
{
	/** 
	 * Affiche les boutons de navigations jour suivant + jour prcdent
	 * 
	 *  @param $date : date en cours de consultation (format MySQL)
	 *  @param $nav : code d'affichage des boutons de navigation 
	 */
	
	$previous_day = strftime("%d-%m-%Y", strtotime("$date -1 day"));
	$next_day = strftime("%d-%m-%Y", strtotime("$date +1 day"));
	$url_get_params = recup_get_url($_GET);
    $fragments = explode("&amp;j=", $url_get_params);
	// Le 1er elt contient les paramtres avant le paramtre j : $fragments[0]
    $new_url_put_params = $fragments[0]."&amp;j=";
	$nav = "<div class='nav_left'>
    <a href='?".$new_url_put_params.$previous_day."'><img id='DayNavLeft' src='".$GLOBALS['chemin_relatif']."images/little_previous.png' alt='[Jour prcdent]' title='Consulter le carnet de bord du jour prcdent' /></a>
    </div>
    <div class='nav_right'>
    <a href='?".$new_url_put_params.$next_day."'><img id='DayNavRight' src='".$GLOBALS['chemin_relatif']."images/little_next.png' alt='[Jour suivant]' title='Consulter le carnet de bord du jour suivant' /></a>
    </div>";
	return $nav;
}

// Le script en cours doit tre le script d'appel prvu, avec les bons paramtres
// Il faut tre pass au moins une fois par un edt affich (initialisation de $_SESSION['planning_edt'])
if (end_with_string($_SERVER['PHP_SELF'],"prive/ct_day.php") && isset($_GET['categorie']) && isset($_SESSION['planning_edt']) && (isset($_GET['edt']) && $_GET['edt'] !="") && isset($_GET['j']))
{
	if ($_GET['categorie'] != "professeurs")
	{
		$error_message = array("La fonctionnalit 'Carnet de bord : cahier de textes du jour' n'est disponible qu' partir d'un emploi du temps professeur.","");
  		affiche_erreurs($error_message);
  		return; // fin du script
	}
	
	// 2me Contrle de scurit : les profs n'ont le droit d'accder qu' leur propre carnet de bord
	if ($_SESSION['valid_group'] == "3" && $_SESSION['identifiant_individu'] != $_GET['edt'])
	{
		$error_message = array("Vous ne pouvez consulter que votre propre carnet de bord, pas celui d'un autre professeur.","");
  		affiche_erreurs($error_message);
  		return; // fin du script
	}
	
	// date du jour 
	if (preg_match("#^[0-9]{1,2}-[0-9]{1,2}-([0-9]{4})$#", $_GET['j'])) // format jj-mm-aaaa ?
    	$date = convert_date_to_mysql($_GET['j'], "-"); // au format MySQL (pour les requtes dans la base de donnes)
    else 
    	$date = date('Y-m-d');
	
	$date_libelle_long = MySQLDateToExplicitDate($date); // format explicite pour affichage dans le titre de page
	
	// l'edt d'o on vient est celui d'une classe ou d'un prof ?
	$categorie = $_SESSION['planning_edt_infos']['categorie'];
	
	// on traite les incohrences entre les paramtres URL et les valeurs de $_SESSION['planning_edt_infos'] (cf anomalie #114)
	if ($categorie != $_GET['categorie'] || $_SESSION['planning_edt_infos']['edt'] != $_GET['edt'])
	{
		$error_message = array("Vous ne pouvez pas accder au carnet de bord souhait. Il est probable que vous ayez tent de recharger la page d'un carnet de bord d'un professeur aprs avoir consult un emploi du temps de classe (ou l'inverse).
		<br />Il faut repasser par un emploi du temps; Utilisez les liens de navigation  partir d'un emploi du temps (en-ttes de colonne pour choisir le jour) !","");
		affiche_erreurs($error_message);
		return; // fin du script
	}
	
	echo "<div id='content_ct_day'>"; // conteneur qui sera mis  jour en AJAX
	
	// Titre
	echo "<h1 id='titre1'>";
	if ($categorie == "classes") // on veut voir le carnet de bord d'une classe
	{
		$classe = $_GET['edt'];
		echo "Cahier de textes de $classe ";
	}
	elseif ($categorie == "professeurs") // on veut voir le carnet de bord d'un prof
	{
		$id_individu = $_GET['edt'];
		if ($_SESSION['identifiant_individu'] == $id_individu) // auto-consultation
			echo "Mon cahier de textes ";
		else // quelqu'un d'autre que le prof lui-mme (mais autoris)
		{
			// on rcupre la civilit + le nom du prof
			$sql = "SELECT civilite,nom FROM personnel WHERE id_individu='".quote_smart($id_individu)."'";
			$resultat = mysql_query($sql);
			if (mysql_num_rows($resultat) > 0)
			{
				$ligne = mysql_fetch_array($resultat);
				$civilite = $ligne['civilite'];
				$nom = $ligne['nom'];
				echo "Cahier de textes de $civilite $nom ";
			}
			else // au cas o le param URL edt ait t modifi manuellement vers une valeur inexistante
			{
				$error_message = array("Impossible de retrouver le professeur, identifiant non affect","");
  				affiche_erreurs($error_message);
  				return; // arrt du script
			} 
		}
			
	}
	echo "<br />$date_libelle_long</h1>";
	
	// DEBUGG var_dump($_SESSION['planning_edt_infos']);
	// DEBUGG var_dump($_SESSION['planning_edt']);
	
	// les cours du jour : il faut retrouver  partir du jour, la cl correspondante du tableau contenant l'edt
	$debut_semaine = debut_semaine($date);
	$diff_debt_sem_jour = date_difference($debut_semaine, $date);
	$nb_jours_diff = $diff_debt_sem_jour["d"];
	$cle = $nb_jours_diff + 1;
		
	/* Barre de navigation textuelle horizontale suprieure */
	
	// liens de navigation graphique (jour prcdent, jour suivant)
	echo display_date_prev_next($date);
	
	if (!isset($_SESSION['planning_edt']{$cle}) || $_SESSION['planning_edt']{$cle} == false) // si pas de cours aujourd'hui, on sort
	{
		echo "<br/>"; // sinon le div d'erreur chevauche les boutons de navigation graphique jour prcdent, jour suivant
		$error_message = array("Pas de cours le $date_libelle_long !","");
  		affiche_erreurs($error_message);
  		return;
	}
	else
		$cours = $_SESSION['planning_edt']{$cle};
		
	// Liens de navigation textuels
	echo "<div id='ct_day_CentralNavBar'><center><img id='loadAjax' src='../images/ajax-loader-linear.gif' alt='' /><span id='textNavBar'>Dbut du cours  : ";
	foreach(array_keys($cours) as $value)
	{
		$display_time_format = substr($value,0,2)."h".substr($value,-2);
		echo "<a href='#a$value'>[$display_time_format]</a>&nbsp;&nbsp;&nbsp;";
	}  
	echo "</span></center></div>";
	
	// Zone de notification de rponse AJAX, non affich par dfaut, mais contiendra les messages AJAX en cas de problme
	echo "<div id='add_msg'></div>";
		
	// Maintenant le dtail des cours
	$a = 0;
	foreach($cours as $key => $value)
	{
		$a++;
		if ($value != "") // les trous de l'edt sont ignors (certains "trous" sont reprsents par des valeurs vides, donc prsents dans le tableau cours, et d'autres ne sont pas reprsents dans le tableau $cours, donc non parcourus par la boucle)
		{
			// Rappel : cours au format "structure_complete#type_diff#id_cours#Code_matiere#matire<br />id_individu#nom_prof<br />salle%dure" (pour un planning de classe) et au format "structure_complete#type_diff#id_cours#Code_matiere#matire<br />nom_classe_ou_groupe<br />salle%dure" (pour un planning de Professeur)
			$frags = explode("#",$value);
			$code_matiere = $frags[3];
		
			// pour le libell de la matire  afficher
			$frag_mat = explode('<br />',$frags[5]);
			$libelle_edition_matiere = $frag_mat[0];
			
			if ($categorie == "classes")
			{
				$code_structure = quote_smart($classe);
				// identifiant du prof
				$id_individu = $frag_mat[1];
				// on rcupre la civilit + le nom du prof
				$sql = "SELECT civilite,nom FROM personnel WHERE id_individu='$id_individu'";
				$resultat = mysql_query($sql);
				$ligne = mysql_fetch_array($resultat);
				$civilite = $ligne['civilite'];
				$nom = $ligne['nom'];
				$titre_cours = "$libelle_edition_matiere ($civilite $nom)";
			}
			elseif ($categorie == "professeurs")
			{
				$code_structure = $frag_mat[1];
				$titre_cours = $code_structure." ($libelle_edition_matiere)";
			}
		
			// titre du cours
			$display_time_format = substr($key,0,2)."h".substr($key,-2);
			// on are l'affichage entre les sections de niveau 2
			if ($a > 1)
				$add_class = " title_nofirst";
			else 
				$add_class = "";
			echo "<h2 id='a$key' class='ct_day_title".$add_class."'>$display_time_format : $titre_cours</h2>";
		
			// on rcupre les entres de cahier de textes publies correspondant au cours
		
			// le TAF donn pour ce jour
			$sql1 = "SELECT id_afaire,afaire,t1.id_ctexte FROM a_faire as t1,cahiers_textes as t2 WHERE id_individu='$id_individu' AND pourle='$date' AND t1.id_ctexte=t2.id_ctexte AND code_structure='$code_structure' AND code_matiere='$code_matiere' AND id_sous_matiere='0' AND t1.publication='1'";
			//var_dump($sql1);
			$resultat1 = mysql_query($sql1);
			echo "<div class='frame_form2 rappel_travail_jour' align='left'>
        		<h3 class='ct_day_title_subsection' style='margin-bottom:0.5em;border-bottom:1px solid;'>Rappel du travail donn pour ce jour</h3>";
			if (mysql_num_rows($resultat1) > 0)
			{
				if (mysql_num_rows($resultat1) > 1) // +sieurs TAF => sous forme de liste  puces
				{
					$k = 1;
					$taf_jour = "<ul>";
					while ($ligne1 = mysql_fetch_array($resultat1))
					{
						// Quel jour a-t-on donn ce TAF ?
						$date_init_taf = date_mysql_to_jjmmaaaa_tiret(quelle_date_ctexte($ligne1['id_ctexte']));
						// lien de modif pour le prof "propritaire"
						if($id_individu == $_SESSION['identifiant_individu'])
							$lien_modif_taf = "<a class='ct_day_modif_entry' href='cahiers_textes.php?date=".$date_init_taf."&amp;set_classe=$code_structure&amp;matiere=$code_matiere#ancre_afaire".$ligne1['id_afaire']."' title='Modifier/Supprimer ce travail'><img src='".$GLOBALS['chemin_relatif']."images/kwrite24x24.png' alt='[Modifier/Supprimer ce Travail]' /></a>";
						
						// Affichage du visa ventuel (DIR ou IPR : le plus rcent) : uniquement si la sance est dj renseigne
   	  					global $db;
      					$CdtVisaManager = new CdtVisaManager($db);
      					$code_affichage_visa = $CdtVisaManager->afficheTamponVisa($ligne1['id_ctexte'],$icon_size = "medium");
      					if ($code_affichage_visa != "") { // il y a un visa  afficher
        					$lien_modif_taf = "<div style='float:right;position:relative;'>$code_affichage_visa</div>";;	// le visa remplace l'icne de modification : le TAF ne peut pas tre modifi
        				}
      					$taf_jour .= "<li><div class='title_taf_lightbox'>Travail $k (donn le $date_init_taf)  $lien_modif_taf</div>".traite_titraille_ct_day($ligne1['afaire'])."</li>";
						$taf_jour .= ct_cherche_docs_associes("id_afaire",$ligne1['id_afaire'],$code_structure,$libelle_edition_matiere);
						$k++;
					}
					$taf_jour .= "</ul>";
				}
				else // un seul TAF
				{
					$ligne1 = mysql_fetch_array($resultat1);
					// Quel jour a-t-on donn ce TAF ?
					$date_init_taf = date_mysql_to_jjmmaaaa_tiret(quelle_date_ctexte($ligne1['id_ctexte']));
					// lien de modif pour le prof "propritaire"
					if($id_individu == $_SESSION['identifiant_individu'])
						$lien_modif_taf = "<a class='ct_day_modif_entry' href='cahiers_textes.php?date=".$date_init_taf."&amp;set_classe=$code_structure&amp;matiere=$code_matiere#ancre_afaire".$ligne1['id_afaire']."' title='Modifier/Supprimer ce travail'><img src='".$GLOBALS['chemin_relatif']."images/kwrite24x24.png' alt='[Modifier/Supprimer ce Travail]' /></a>";
					
					// Affichage du visa ventuel (DIR ou IPR : le plus rcent) : uniquement si la sance est dj renseigne
   	  				global $db;
      				$CdtVisaManager = new CdtVisaManager($db);
      				$code_affichage_visa = $CdtVisaManager->afficheTamponVisa($ligne1['id_ctexte'],$icon_size = "medium");
      				if ($code_affichage_visa != "") { // il y a un visa  afficher
        				$lien_modif_taf = "<div style='float:right;position:relative;'>$code_affichage_visa</div>";;	// le visa remplace l'icne de modification : le TAF ne peut pas tre modifi
        			}
      				$taf_jour = "<div class='title_taf_lightbox'>(donn le $date_init_taf)  $lien_modif_taf</div>";
					$taf_jour .= traite_titraille_ct_day($ligne1['afaire']).ct_cherche_docs_associes("id_afaire",$ligne1['id_afaire'],$code_structure,$libelle_edition_matiere);
				}
				echo $taf_jour; 
			}
			else
				echo "<img src='".$GLOBALS['chemin_relatif']."images/warning.gif' alt='Alerte' /> <span class='rouge'>Aucun travail donn pour ce jour...</span>";
			echo "</div>";
			
			// Le contenu de sance
			$sql2 = "SELECT id_ctexte,activite,publication FROM cahiers_textes as t1 WHERE id_individu='$id_individu' AND date='$date' AND code_structure='$code_structure' AND code_matiere='$code_matiere' AND id_sous_matiere='0' AND t1.publication='1'";
			$resultat2 = mysql_query($sql2);
			echo "<div class='cadre_seance_ctx'>
        	<div class='titre_cadre_formulaire_gris'><h3 class='ct_day_title_subsection'>Contenu de la sance</h3></div>";
			if (mysql_num_rows($resultat2) > 0)
			{
				$ligne2 = mysql_fetch_array($resultat2);
				// lien de modif pour le prof "propritaire"
				if($id_individu == $_SESSION['identifiant_individu'])
				{	
					$date_contenu = date_mysql_to_jjmmaaaa_tiret(quelle_date_ctexte($ligne2['id_ctexte']));
					$lien_modif = "<a class='ct_day_modif_entry' href='cahiers_textes.php?date=".$date_contenu."&amp;set_classe=$code_structure&amp;matiere=$code_matiere#bandeau_nav_datecours_ctx' title='Modifier/Supprimer ce contenu de sance'><img src='".$GLOBALS['chemin_relatif']."images/kwrite24x24.png' alt='[Modifier/Supprimer ce contenu de sance]' /></a>";
				}
				else 
					$lien_modif = "";
				
				// Affichage du visa ventuel (DIR ou IPR : le plus rcent) : uniquement si la sance est dj renseigne
   	  			global $db;
      			$CdtVisaManager = new CdtVisaManager($db);
      			$code_affichage_visa = $CdtVisaManager->afficheTamponVisa($ligne2['id_ctexte']);
      			if ($code_affichage_visa != "") { // il y a un visa  afficher
        			$lien_modif = "<div style='float:right;position:relative;'>$code_affichage_visa</div>";	// le visa remplace l'icne de modification : l'entre de cahier de textes ne peut pas tre modifie
        		}
      			$contenu = traite_titraille_ct_day($ligne2['activite']).ct_cherche_docs_associes("id_ctexte",$ligne2['id_ctexte'],$code_structure,$libelle_edition_matiere);
			}
			else 
				$contenu = "<img src='".$GLOBALS['chemin_relatif']."images/warning.gif' alt='Alerte' /> <span class='rouge'>Contenu non renseign ou non publi...</span>";
			if ($id_individu == $_SESSION['identifiant_individu']) // affichage du lien de modif (pour le prof propritaire)
			{
				if ($lien_modif != "")
					echo $lien_modif;
				else 
				{
					$date_contenu = date_mysql_to_jjmmaaaa_tiret($date);
					echo "<a class='ct_day_modif_entry' href='cahiers_textes.php?date=".$date_contenu."&amp;set_classe=$code_structure&amp;matiere=$code_matiere#bandeau_nav_datecours_ctx' title='Modifier/Supprimer ce contenu de sance'><img src='".$GLOBALS['chemin_relatif']."images/kwrite24x24.png' alt='[Modifier/Supprimer ce contenu de sance]' /></a>";
				} 
			}
			echo "<div class='ct_day_contenu_seance'>$contenu</div>";
			echo "</div>";
		
			// Les TAF pour d'autres dates
			if (isset($ligne2['id_ctexte'])) // sont cherchs seulement si un contenu de sance existe
			{
				$sql3 = "SELECT pourle,id_afaire,afaire,publication FROM a_faire WHERE id_ctexte='".$ligne2['id_ctexte']."'";
				$resultat3 = mysql_query($sql3);
				echo "<br /><div class='cadre_afaire_entete' style='height: 1.5em;'>
	        	<h3 class='ct_day_title_subsection'>Travaux  faire</h3>
    	    	</div>
        		<div class='cadre_formulaire_gris cadre_afaire_corps'>";
				if (mysql_num_rows($resultat3) > 0)
				{
					if (mysql_num_rows($resultat3) > 1) // +sieurs TAF => sous forme de liste  puces
					{
						$k = 1;
						$taf_jour = "<ul>";
						while ($ligne3 = mysql_fetch_array($resultat3))
						{
							// Quel jour a-t-on donn ce TAF ?
							$date_init_taf = date_mysql_to_jjmmaaaa_tiret(quelle_date_ctexte($ligne2['id_ctexte']));
							// Pour quel jour ?
							$date_taf = date_mysql_to_jjmmaaaa_tiret($ligne3['pourle']);
							// lien de modif pour le prof "propritaire"
							if($id_individu == $_SESSION['identifiant_individu'])
								$lien_modif_taf = "<a class='ct_day_modif_entry' href='cahiers_textes.php?date=".$date_init_taf."&amp;set_classe=$code_structure&amp;matiere=$code_matiere#ancre_afaire".$ligne3['id_afaire']."' title='Modifier/Supprimer ce travail'><img src='".$GLOBALS['chemin_relatif']."images/kwrite24x24.png' alt='[Modifier/Supprimer ce Travail]' /></a>";
							
							// Affichage du visa ventuel (DIR ou IPR : le plus rcent) : uniquement si la sance est dj renseigne
   	  						global $db;
      						$CdtVisaManager = new CdtVisaManager($db);
      						$code_affichage_visa = $CdtVisaManager->afficheTamponVisa($ligne2['id_ctexte'],$icon_size = "medium");
      						if ($code_affichage_visa != "") { // il y a un visa  afficher
        						$lien_modif_taf = "<div style='float:right;position:relative;'>$code_affichage_visa</div>";;	// le visa remplace l'icne de modification : le TAF ne peut pas tre modifi
        					}
      						$taf_jour .= "<li><div class='title_taf_lightbox'>Travail $k (pour le $date_taf)  $lien_modif_taf</div>".traite_titraille_ct_day($ligne3['afaire'])."</li>";
							$taf_jour .= ct_cherche_docs_associes("id_afaire",$ligne3['id_afaire'],$code_structure,$libelle_edition_matiere);
							$k++;
						}
						$taf_jour .= "</ul>";
					}
					else // un seul TAF
					{
						$ligne3 = mysql_fetch_array($resultat3);
						// Quel jour a-t-on donn ce TAF ?
						$date_init_taf = date_mysql_to_jjmmaaaa_tiret(quelle_date_ctexte($ligne2['id_ctexte']));
						// Pour quel jour ?
						$date_taf = date_mysql_to_jjmmaaaa_tiret($ligne3['pourle']);
						// lien de modif pour le prof "propritaire"
						if($id_individu == $_SESSION['identifiant_individu'])
							$lien_modif_taf = "<a class='ct_day_modif_entry' href='cahiers_textes.php?date=".$date_init_taf."&amp;set_classe=$code_structure&amp;matiere=$code_matiere#ancre_afaire".$ligne3['id_afaire']."' title='Modifier/Supprimer ce travail'><img src='".$GLOBALS['chemin_relatif']."images/kwrite24x24.png' alt='[Modifier/Supprimer ce Travail]' /></a>";
						
						// Affichage du visa ventuel (DIR ou IPR : le plus rcent) : uniquement si la sance est dj renseigne
   	  					global $db;
      					$CdtVisaManager = new CdtVisaManager($db);
      					$code_affichage_visa = $CdtVisaManager->afficheTamponVisa($ligne2['id_ctexte'],$icon_size = "medium");
      					if ($code_affichage_visa != "") { // il y a un visa  afficher
        					$lien_modif_taf = "<div style='float:right;position:relative;'>$code_affichage_visa</div>";;	// le visa remplace l'icne de modification : le TAF ne peut pas tre modifi
        				}
      					$taf_jour = "<div class='title_taf_lightbox'>(pour le $date_taf)  $lien_modif_taf</div>";
						$taf_jour .= traite_titraille_ct_day($ligne3['afaire']).ct_cherche_docs_associes("id_afaire",$ligne3['id_afaire'],$code_structure,$libelle_edition_matiere);
					}
					echo $taf_jour; 
				}
				else
				{
					if ($id_individu == $_SESSION['identifiant_individu'])
						echo "<a class='ct_day_modif_entry' href='cahiers_textes.php?date=".$date_contenu."&amp;set_classe=$code_structure&amp;matiere=$code_matiere#ancre_afaire' title='Donner un travail  faire'><img src='".$GLOBALS['chemin_relatif']."images/kwrite24x24.png' alt='[Modifier/Supprimer ce contenu de sance]' /></a>";
					echo "<img src='".$GLOBALS['chemin_relatif']."images/warning.gif' alt='Alerte' /> <span class='rouge'>Pas de travail  faire pour d'autres dates...</span>";
				}
				echo "</div>";
				unset($ligne2['id_ctexte']); // sinon les mmes TAF seront affichs pour les autres cours alors que ce n'est pas en rapport
			}
			unset($lien_modif); // avant le prochain cours, sinon les liens de modifs ne seront pas en rapport avec ce qu'il faut
		}
	} 
	echo "</div>";
}
else // L'utilisateur essaie d'invoquer ce script directement dans l'URL (interdit)
{
  $error_message = array("Vous tentez d'accder  un script qui n'est pas accessible directement  partir de l'URL... Utilisez les liens de navigation  partir d'un emploi du temps (en-ttes de colonne pour choisir le jour) !","");
  affiche_erreurs($error_message);
}
?>